@@ -29,10 +29,11 @@
 #include <memory>
 #include <string>
 #include <tuple>
+#include <unordered_map>
 #include <utility>
 #include <vector>
 
-#include "mysql/group_replication.h"
+#include "mysqlshdk/libs/mysql/group_replication.h"
 #include "scripting/types.h"
 #include "scripting/types_cpp.h"
 #include "shellcore/shell_options.h"
@@ -44,6 +45,7 @@
 #include "modules/adminapi/common/cluster_types.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/group_replication_options.h"
+#include "modules/adminapi/common/instance_validations.h"
 #include "mysqlshdk/include/shellcore/shell_notifications.h"
 #include "mysqlshdk/libs/db/connection_options.h"
 #include "mysqlshdk/libs/db/mysql/session.h"
@@ -75,6 +77,10 @@ using Instance_md_and_gr_member =
 class Cluster_set_impl;
 class ClusterSet;
 
+namespace checks {
+enum class Check_type;
+}
+
 class Cluster_impl final : public Base_cluster_impl,
                            public shcore::NotificationObserver {
  public:
@@ -93,20 +99,16 @@ class Cluster_impl final : public Base_cluster_impl,
 
   Cluster_impl(const std::string &cluster_name, const std::string &group_name,
                const std::shared_ptr<Instance> &group_server,
+               const std::shared_ptr<Instance> &primary_master,
                const std::shared_ptr<MetadataStorage> &metadata_storage,
                mysqlshdk::gr::Topology_mode topology_type);
   virtual ~Cluster_impl();
 
   // API functions
   void add_instance(const Connection_options &instance_def,
-                    const cluster::Add_instance_options &options,
-                    Recovery_progress_style progress_style);
-
+                    const cluster::Add_instance_options &options);
   void rejoin_instance(const Connection_options &instance_def,
-                       const Group_replication_options &gr_options,
-                       bool interactive, bool skip_precondition_check,
-                       std::optional<bool> switch_comm_stack = false);
-
+                       const cluster::Rejoin_instance_options &options);
   void remove_instance(const Connection_options &instance_def,
                        const cluster::Remove_instance_options &options);
   shcore::Value describe();
@@ -242,6 +244,7 @@ class Cluster_impl final : public Base_cluster_impl,
   bool contains_instance_with_address(const std::string &host_port) const;
 
   mysqlsh::dba::Instance *acquire_primary(
+      bool primary_required = true,
       mysqlshdk::mysql::Lock_mode mode = mysqlshdk::mysql::Lock_mode::NONE,
       const std::string &skip_lock_uuid = "") override;
 
@@ -295,6 +298,34 @@ class Cluster_impl final : public Base_cluster_impl,
   std::tuple<std::string, std::vector<std::string>, bool> get_replication_user(
       const mysqlshdk::mysql::IInstance &target_instance) const;
 
+  /**
+   * Get mismatched recovery accounts.
+   *
+   * This function returns instances for which the recovery account name doesn't
+   * match with its server id.
+   *
+   * @return a list of {server_id, user} pairs, for each mismatch account
+   * found.
+   */
+  std::unordered_map<uint32_t, std::string> get_mismatched_recovery_accounts()
+      const;
+
+  /**
+   * Get unused recovery accounts / users.
+   *
+   * This function returns recovery accounts that exist but aren't being used
+   * in either instances of a given cluster. The list excludes mismatch
+   * accounts.
+   *
+   * @param mismatched_recovery_accounts the list of mismatched account (@see
+   * get_mismatched_recovery_accounts)
+   *
+   * @return the list of unused recovery accounts: pairs of {users/hosts}
+   */
+  std::vector<std::tuple<std::string, std::string>>
+  get_unused_recovery_accounts(const std::unordered_map<uint32_t, std::string>
+                                   &mismatched_recovery_accounts) const;
+
   /**
    * Get a session to a given instance of the cluster.
    *
@@ -444,8 +475,8 @@ class Cluster_impl final : public Base_cluster_impl,
 
   void query_group_wide_option_values(
       mysqlshdk::mysql::IInstance *target_instance,
-      mysqlshdk::utils::nullable<std::string> *out_gr_consistency,
-      mysqlshdk::utils::nullable<int64_t> *out_gr_member_expel_timeout) const;
+      std::optional<std::string> *out_gr_consistency,
+      std::optional<int64_t> *out_gr_member_expel_timeout) const;
 
   /**
    * Update the cluster members according to the removed instance.
@@ -484,6 +515,8 @@ class Cluster_impl final : public Base_cluster_impl,
    */
   void enable_super_read_only_globally() const;
 
+  void refresh_connections();
+
  public:
   // clusterset related methods
   const Cluster_set_member_metadata &get_clusterset_metadata() const;
@@ -503,7 +536,7 @@ class Cluster_impl final : public Base_cluster_impl,
   bool is_cluster_set_remove_pending() const { return m_cs_md_remove_pending; }
 
   std::shared_ptr<Cluster_set_impl> get_cluster_set_object(
-      bool print_warnings = false);
+      bool print_warnings = false) const;
 
   /**
    * Reset the password for the Cluster's replication account in use for the
@@ -517,6 +550,53 @@ class Cluster_impl final : public Base_cluster_impl,
 
   void update_replication_allowed_host(const std::string &host);
 
+  /*
+   * Enable skip_slave_start and configures the managed replication channel if
+   * the target cluster is a replica.
+   */
+  void configure_cluster_set_member(
+      const std::shared_ptr<mysqlsh::dba::Instance> &target_instance) const;
+
+  /**
+   * Recreate the recovery account for each Cluster member
+   *
+   * Required when using the 'MySQL' communication stack to ensure each active
+   * member of the Cluster will use its own recovery account instead of the one
+   * created whenever a new member joined since all possible seeds had to be
+   * updated to use that same account. This ensures distributed recovery is
+   * possible at any circumstance.
+   */
+  void restore_recovery_account_all_members() const;
+
+  /**
+   * Change the recovery user credentials of all Cluster members
+   *
+   * @param repl_account The authentication options of the recovery account
+   */
+  void change_recovery_credentials_all_members(
+      const mysqlshdk::mysql::Auth_options &repl_account) const;
+
+  /**
+   * Create a local recovery account for the target instance
+   *
+   * Required when using the 'MySQL' communication stack. The account is
+   * created locally only to the target instance and with binary logging
+   * disabled to not introduce errant transactions
+   */
+  void create_local_replication_user(
+      const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+      const Group_replication_options &gr_options);
+
+  void update_group_peers(
+      const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+      const Group_replication_options &gr_options, int cluster_member_count,
+      const std::string &self_address, bool group_seeds_only = false);
+
+  void check_instance_configuration(
+      const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+      bool using_clone_recovery, checks::Check_type checks_type,
+      bool already_member) const;
+
  protected:
   void _set_option(const std::string &option,
                    const shcore::Value &value) override;
@@ -529,6 +609,7 @@ class Cluster_impl final : public Base_cluster_impl,
   void init();
 
  private:
+  std::string get_replication_user_host() const;
   void verify_topology_type_change() const;
 
   std::weak_ptr<Cluster_set_impl> m_cluster_set;
