@@ -209,7 +209,8 @@ void Rescan::prepare() {
   }
 }
 
-void Rescan::check_mismatched_hostnames(shcore::Array_t instances) const {
+void Rescan::check_mismatched_hostnames_addresses(
+    shcore::Array_t instances) const {
   m_cluster->execute_in_members(
       [&instances](const std::shared_ptr<Instance> &instance,
                    const Instance_md_and_gr_member &info) {
@@ -219,6 +220,15 @@ void Rescan::check_mismatched_hostnames(shcore::Array_t instances) const {
             return true;
         }
 
+        bool grendpoint_valid = true;
+        try {
+          mysqlshdk::utils::split_host_and_port(info.first.grendpoint);
+        } catch (const std::invalid_argument &e) {
+          log_debug("Unable to parse endpoint: %s",
+                    info.first.grendpoint.c_str());
+          grendpoint_valid = false;
+        }
+
         auto address = instance->get_canonical_address();
 
         auto res = instance->query(
@@ -239,18 +249,21 @@ void Rescan::check_mismatched_hostnames(shcore::Array_t instances) const {
             info.second.uuid.c_str(), info.second.host.c_str(),
             info.second.port);
 
-        if (!mysqlshdk::utils::are_endpoints_equal(info.first.endpoint,
-                                                   address) ||
-            !mysqlshdk::utils::are_endpoints_equal(info.first.address,
-                                                   address)) {
-          instances->emplace_back(shcore::Value(shcore::make_dict(
-              "member_id", shcore::Value(instance->get_uuid()), "id",
-              shcore::Value(info.first.id), "label",
-              shcore::Value(info.first.label), "host",
-              shcore::Value(instance->get_canonical_address()), "old_host",
-              shcore::Value(info.first.endpoint))));
+        if (grendpoint_valid &&
+            mysqlshdk::utils::are_endpoints_equal(info.first.endpoint,
+                                                  address) &&
+            mysqlshdk::utils::are_endpoints_equal(info.first.address,
+                                                  address)) {
+          return true;
         }
 
+        instances->emplace_back(shcore::Value(
+            shcore::make_dict("member_id", shcore::Value(instance->get_uuid()),
+                              "id", shcore::Value(info.first.id), "label",
+                              shcore::Value(info.first.label), "host",
+                              shcore::Value(instance->get_canonical_address()),
+                              "old_host", shcore::Value(info.first.endpoint))));
+
         return true;
       },
       [](const shcore::Error &, const Instance_md_and_gr_member &) {
@@ -343,7 +356,7 @@ shcore::Value::Map_type_ref Rescan::get_rescan_report() const {
     }
   }
 
-  check_mismatched_hostnames(updated_instances);
+  check_mismatched_hostnames_addresses(updated_instances);
 
   // Add the missing_instances list to the result Map
   (*cluster_map)["unavailableInstances"] = shcore::Value(unavailable_instances);
@@ -584,13 +597,16 @@ void Rescan::update_metadata_for_instances(
           instance_map->get_string("member_id").c_str()));
     } else {
       // member address changed
-      console->print_info(
-          shcore::str_format("The instance '%s' is part of the cluster but its "
-                             "reported address has changed. "
-                             "Old address: %s. Current address: %s.",
-                             instance_address.c_str(),
-                             instance_map->get_string("old_host").c_str(),
-                             instance_map->get_string("host").c_str()));
+      if (instance_map->get_string("old_host") !=
+          instance_map->get_string("host")) {
+        console->print_info(shcore::str_format(
+            "The instance '%s' is part of the cluster but its "
+            "reported address has changed. "
+            "Old address: %s. Current address: %s.",
+            instance_address.c_str(),
+            instance_map->get_string("old_host").c_str(),
+            instance_map->get_string("host").c_str()));
+      }
 
       // update instance label if it's the default value
       if (instance_map->get_string("label") ==
@@ -645,10 +661,8 @@ void Rescan::ensure_view_change_uuid_set() {
   // support it
   if (m_cluster->get_lowest_instance_version() >= k_min_cs_version) {
     // Check if group_replication_view_change_uuid is already set on the cluster
-    view_change_uuid =
-        cluster_instance
-            ->get_sysvar_string("group_replication_view_change_uuid")
-            .get_safe();
+    view_change_uuid = cluster_instance->get_sysvar_string(
+        "group_replication_view_change_uuid", "");
 
     // If not set (AUTOMATIC), generate a new value and set it on all members
     if (view_change_uuid == "AUTOMATIC") {
@@ -656,7 +670,7 @@ void Rescan::ensure_view_change_uuid_set() {
       std::string view_change_uuid_persisted =
           cluster_instance
               ->get_persisted_value("group_replication_view_change_uuid")
-              .get_safe();
+              .value_or("");
 
       if (!view_change_uuid_persisted.empty() &&
           view_change_uuid_persisted != view_change_uuid) {
@@ -705,10 +719,8 @@ void Rescan::ensure_view_change_uuid_set_stored_metadata(
     if (view_change_uuid.empty()) {
       m_cluster->get_metadata_storage()->update_cluster_attribute(
           m_cluster->get_id(), "group_replication_view_change_uuid",
-          shcore::Value(
-              m_cluster->get_cluster_server()
-                  ->get_sysvar_string("group_replication_view_change_uuid")
-                  .get_safe()));
+          shcore::Value(m_cluster->get_cluster_server()->get_sysvar_string(
+              "group_replication_view_change_uuid", "")));
     } else {
       m_cluster->get_metadata_storage()->update_cluster_attribute(
           m_cluster->get_id(), "group_replication_view_change_uuid",
@@ -733,7 +745,7 @@ void Rescan::ensure_transaction_size_limit_stored_metadata() {
         m_cluster->get_id(), k_cluster_attribute_transaction_size_limit,
         shcore::Value(m_cluster->get_cluster_server()
                           ->get_sysvar_int(kGrTransactionSizeLimit)
-                          .get_safe()));
+                          .value_or(0)));
   }
 }
 
@@ -761,7 +773,7 @@ void Rescan::ensure_transaction_size_limit_consistency() {
             info.second.state != mysqlshdk::gr::Member_state::UNREACHABLE) {
           // Get the instance's value for transaction_size_limit
           int64_t instance_transaction_size_limit =
-              instance->get_sysvar_int(kGrTransactionSizeLimit).get_safe();
+              instance->get_sysvar_int(kGrTransactionSizeLimit).value_or(0);
 
           if (instance_transaction_size_limit !=
               cluster_transaction_size_limit) {
@@ -783,8 +795,7 @@ void Rescan::ensure_transaction_size_limit_consistency() {
                 instance.get(), mysqlshdk::config::k_dft_cfg_server_handler);
 
             cfg->set(kGrTransactionSizeLimit,
-                     mysqlshdk::utils::nullable<int64_t>(
-                         cluster_transaction_size_limit));
+                     std::optional<int64_t>(cluster_transaction_size_limit));
 
             cfg->apply();
           }
@@ -838,6 +849,10 @@ void Rescan::ensure_recovery_accounts_match() {
               return true;
             }
 
+            mysqlsh::current_console()->print_info(shcore::str_format(
+                "Fixing incorrect recovery account '%s' in instance '%s'",
+                recovery_user.c_str(), instance->descr().c_str()));
+
             // Generate and set a new password and update the replication
             // credentials
             m_cluster->reset_recovery_password(
@@ -917,40 +932,36 @@ shcore::Value Rescan::execute() {
 
   // Check if group_replication_view_change_uuid is set on the Cluster and all
   // of its members when running MySQL >= 8.0.27
-  {
-    if (m_is_view_change_uuid_supported) {
-      std::string view_change_uuid =
-          m_cluster->get_primary_master()
-              ->get_sysvar_string("group_replication_view_change_uuid")
-              .get_safe();
+  if (m_is_view_change_uuid_supported) {
+    auto view_change_uuid = m_cluster->get_primary_master()->get_sysvar_string(
+        "group_replication_view_change_uuid", "");
 
-      if (view_change_uuid == "AUTOMATIC") {
-        if (m_options.update_view_change_uuid.is_null()) {
-          console->print_warning(
-              "The Cluster is not configured to use "
-              "'group_replication_view_change_uuid', which is required "
-              "for InnoDB ClusterSet. Configuring it requires a full Cluster "
-              "reboot.");
-          if (m_options.interactive()) {
-            // Prompt the user to update the View Change UUID
-            if (console->confirm(
-                    "Would you like 'group_replication_view_change_uuid' to be "
-                    "configured automatically?",
-                    Prompt_answer::YES) == Prompt_answer::YES) {
-              ensure_view_change_uuid_set();
-            }
-          } else {
-            console->print_info(
-                "Use the 'updateViewChangeUuid' option to generate and "
-                "configure a value for the Cluster.");
+    if (view_change_uuid == "AUTOMATIC") {
+      if (m_options.update_view_change_uuid.is_null()) {
+        console->print_warning(
+            "The Cluster is not configured to use "
+            "'group_replication_view_change_uuid', which is required "
+            "for InnoDB ClusterSet. Configuring it requires a full Cluster "
+            "reboot.");
+        if (m_options.interactive()) {
+          // Prompt the user to update the View Change UUID
+          if (console->confirm(
+                  "Would you like 'group_replication_view_change_uuid' to be "
+                  "configured automatically?",
+                  Prompt_answer::YES) == Prompt_answer::YES) {
+            ensure_view_change_uuid_set();
           }
-        } else if (m_options.update_view_change_uuid.get_safe()) {
-          ensure_view_change_uuid_set();
+        } else {
+          console->print_info(
+              "Use the 'updateViewChangeUuid' option to generate and "
+              "configure a value for the Cluster.");
         }
-      } else {
-        // Ensures the value is stored in the metadata schema
-        ensure_view_change_uuid_set_stored_metadata();
+      } else if (m_options.update_view_change_uuid.get_safe()) {
+        ensure_view_change_uuid_set();
       }
+    } else {
+      // Ensures the value is stored in the metadata schema
+      ensure_view_change_uuid_set_stored_metadata();
     }
   }
 
@@ -1003,16 +1014,31 @@ shcore::Value Rescan::execute() {
     upgrade_comm_protocol();
   }
 
-  // Check for instances using a different account than its own for the recovery
-  // channel and do a reset+update of the credentials to ensure the right
-  // account is used. Finally, update the MD schema to store the right account
-  // in use.
+  // Check for instances using a different account than its own for the
+  // recovery channel and do a reset+update of the credentials to ensure the
+  // right account is used. Finally, update the MD schema to store the right
+  // account in use.
   //
-  // A member rejoining needs to be able to connect to itself and to all cluster
-  // members, as well as all cluster members need to be able to connect to the
-  // joining member.
+  // A member rejoining needs to be able to connect to itself and to all
+  // cluster members, as well as all cluster members need to be able to
+  // connect to the joining member.
   ensure_recovery_accounts_match();
 
+  // removes unused recovery accounts
+  for (const auto &[user, host] : m_cluster->get_unused_recovery_accounts(
+           m_cluster->get_mismatched_recovery_accounts())) {
+    try {
+      console->print_info(
+          shcore::str_format("Dropping unused recovery account: '%s'@'%s'",
+                             user.c_str(), host.c_str()));
+      m_cluster->get_primary_master()->drop_user(user, host, true);
+    } catch (...) {
+      console->print_warning(shcore::str_format(
+          "Error dropping recovery account '%s'@'%s': %s", user.c_str(),
+          host.c_str(), format_active_exception().c_str()));
+    }
+  }
+
   return shcore::Value();
 }
 
