@@ -52,7 +52,7 @@ Set_option::Set_option(Cluster_impl *cluster, const std::string &option,
   assert(cluster);
 }
 
-Set_option::~Set_option() {}
+Set_option::~Set_option() = default;
 
 void Set_option::ensure_option_valid() {
   /* - Validate if the option is valid, being the accepted values:
@@ -65,6 +65,7 @@ void Set_option::ensure_option_valid() {
    *     - expelTimeout
    *     - replicationAllowedHost
    *     - transactionSizeLimit
+   *     - ipAllowlist
    */
   if (k_global_cluster_supported_options.count(m_option) == 0 &&
       m_option != kClusterName && m_option != kDisableClone &&
@@ -81,24 +82,25 @@ void Set_option::ensure_option_valid() {
         "Please use the consistency option instead.");
   } else if (m_option == kClusterName) {
     // Validate if the clusterName value is valid
-    if (!m_value_int.is_null() || !m_value_bool.is_null()) {
+    if (!m_value_str.has_value()) {
       throw shcore::Exception::argument_error(
           "Invalid value for 'clusterName': Argument #2 is expected to be a "
           "string.");
-    } else {
-      mysqlsh::dba::validate_cluster_name(*m_value_str,
-                                          Cluster_type::GROUP_REPLICATION);
     }
+
+    mysqlsh::dba::validate_cluster_name(*m_value_str,
+                                        Cluster_type::GROUP_REPLICATION);
+
   } else if (m_option == kDisableClone) {
     // Validate if the disableClone value is valid
     // Ensure disableClone is a boolean or integer value
-    if (!m_value_str.is_null()) {
+    if (m_value_str.has_value()) {
       throw shcore::Exception::type_error(
           "Invalid value for 'disableClone': Argument #2 is expected to be a "
           "boolean.");
     }
   } else if (m_option == kReplicationAllowedHost) {
-    if (m_value_str.is_null() || m_value_str->empty()) {
+    if (!m_value_str.has_value() || m_value_str->empty()) {
       throw shcore::Exception::argument_error(
           "Invalid value for 'replicationAllowedHost': Argument #2 is expected "
           "to be a string.");
@@ -110,6 +112,11 @@ void Set_option::ensure_option_valid() {
     // and its automatically managed by the AdminAPI)
     throw shcore::Exception::runtime_error(
         "Option '" + m_option + "' not supported on Replica Clusters.");
+  } else if (m_option == kIpAllowlist) {
+    if (!m_value_str.has_value())
+      throw shcore::Exception::argument_error(
+          "Invalid value for 'ipAllowlist': Argument #2 is expected "
+          "to be a string.");
   }
 }
 
@@ -174,8 +181,6 @@ void Set_option::connect_all_members() {
   Connection_options cluster_cnx_opt =
       m_cluster->get_cluster_server()->get_connection_options();
 
-  auto console = mysqlsh::current_console();
-
   // Check if all instances have the ONLINE state
   for (const auto &instance_def : m_cluster->get_instances_with_state()) {
     // Instance is ONLINE, initialize and populate the internal cluster
@@ -199,7 +204,7 @@ void Set_option::connect_all_members() {
     } catch (const std::exception &err) {
       log_debug("Failed to connect to instance: %s", err.what());
 
-      console->print_error(
+      mysqlsh::current_console()->print_error(
           "Unable to connect to instance '" + instance_def.first.endpoint +
           "'. Please, verify connection credentials and make sure the "
           "instance is available.");
@@ -210,28 +215,23 @@ void Set_option::connect_all_members() {
 }
 
 void Set_option::ensure_option_supported_all_members_cluster() {
-  auto console = mysqlsh::current_console();
-
   log_debug("Checking if all members of the cluster support the option '%s'",
             m_option.c_str());
 
   for (const auto &instance : m_cluster_instances) {
-    std::string instance_address = instance->descr();
-
     // Verify if the instance version is supported
-    bool is_supported = is_option_supported(instance->get_version(), m_option,
-                                            k_global_cluster_supported_options);
+    if (is_option_supported(instance->get_version(), m_option,
+                            k_global_cluster_supported_options))
+      continue;
 
-    if (!is_supported) {
-      console->print_error(
-          "The instance '" + instance_address + "' has the version " +
-          instance->get_version().get_full() +
-          " which does not support the option '" + m_option + "'.");
+    mysqlsh::current_console()->print_error(
+        "The instance '" + instance->descr() + "' has the version " +
+        instance->get_version().get_full() +
+        " which does not support the option '" + m_option + "'.");
 
-      throw shcore::Exception::runtime_error(
-          "One or more instances of the cluster have a version that does not "
-          "support this operation.");
-    }
+    throw shcore::Exception::runtime_error(
+        "One or more instances of the cluster have a version that does not "
+        "support this operation.");
   }
 }
 
@@ -242,6 +242,9 @@ void Set_option::prepare() {
   // Validate if the option is valid
   ensure_option_valid();
 
+  // Must be able to connect to all members
+  connect_all_members();
+
   // Verify if all cluster members support the option
   // NOTE: clusterName and disableClone do not require this validation
   if (m_option != kClusterName && m_option != kDisableClone &&
@@ -251,8 +254,8 @@ void Set_option::prepare() {
     // Get the Cluster Config Object
     m_cfg = m_cluster->create_config_object();
 
-    if (m_option == kAutoRejoinTries && !m_value_int.is_null() &&
-        *m_value_int != 0) {
+    if (m_option == kAutoRejoinTries && m_value_int.has_value() &&
+        (*m_value_int != 0)) {
       auto console = mysqlsh::current_console();
       std::string warn_msg =
           "Each cluster member will only proceed according to its "
@@ -278,13 +281,14 @@ shcore::Value Set_option::execute() {
     std::string option_gr_variable =
         k_global_cluster_supported_options.at(m_option).option_variable;
 
-    console->print_info(
-        "Setting the value of '" + m_option + "' to '" +
-        (m_value_str.is_null() ? std::to_string(*m_value_int) : *m_value_str) +
-        "' in all cluster members ...");
+    console->print_info("Setting the value of '" + m_option + "' to '" +
+                        (!m_value_str.has_value()
+                             ? shcore::lexical_cast<std::string>(*m_value_int)
+                             : *m_value_str) +
+                        "' in all cluster members ...");
     console->print_info();
 
-    if (!m_value_str.is_null()) {
+    if (m_value_str.has_value()) {
       m_cfg->set(option_gr_variable, m_value_str);
     } else {
       m_cfg->set(option_gr_variable, m_value_int);
@@ -307,8 +311,9 @@ shcore::Value Set_option::execute() {
 
     console->print_info("Successfully set the value of '" + m_option +
                         "' to '" +
-                        ((m_value_str.is_null() ? std::to_string(*m_value_int)
-                                                : *m_value_str)) +
+                        ((!m_value_str.has_value()
+                              ? shcore::lexical_cast<std::string>(*m_value_int)
+                              : *m_value_str)) +
                         "' in the '" + m_cluster->get_name() + "' cluster.");
 
     return shcore::Value();
@@ -344,8 +349,7 @@ shcore::Value Set_option::execute() {
     } else if (m_option == kDisableClone) {
       // Ensure forceClone is a boolean or integer value
       std::string m_value_printable =
-          ((!m_value_bool.is_null() && *m_value_bool == true) ||
-           (!m_value_int.is_null() && *m_value_int >= 1))
+          m_value_bool.value_or(false) || (m_value_int.value_or(0) >= 1)
               ? "true"
               : "false";
 
@@ -353,13 +357,9 @@ shcore::Value Set_option::execute() {
                           m_value_printable + "' in the Cluster ...");
       console->print_info();
 
-      if (!m_value_int.is_null()) {
-        if (*m_value_int >= 1) {
-          update_disable_clone_option(true);
-        } else {
-          update_disable_clone_option(false);
-        }
-      } else if (!m_value_bool.is_null()) {
+      if (m_value_int.has_value()) {
+        update_disable_clone_option((*m_value_int >= 1));
+      } else if (m_value_bool.has_value()) {
         update_disable_clone_option(*m_value_bool);
       }
 
@@ -382,8 +382,6 @@ shcore::Value Set_option::execute() {
   return shcore::Value();
 }
 
-void Set_option::rollback() {}
-
 void Set_option::finish() {
   // Close all sessions to cluster instances.
   for (const auto &instance : m_cluster_instances) {
