@@ -107,11 +107,10 @@ inline bool set_ts(shcore::Dictionary_t dict, const std::string &prop,
 
 }  // namespace
 
-Status::Status(const Cluster_impl &cluster,
-               const mysqlshdk::utils::nullable<uint64_t> &extended)
+Status::Status(const Cluster_impl &cluster, std::optional<uint64_t> extended)
     : m_cluster(cluster), m_extended(extended) {}
 
-Status::~Status() {}
+Status::~Status() = default;
 
 void Status::connect_to_members() {
   auto ipool = current_ipool();
@@ -667,17 +666,22 @@ void Status::feed_metadata_info(shcore::Dictionary_t dict,
                                 const Instance_metadata &info) {
   (*dict)["address"] = shcore::Value(info.endpoint);
   (*dict)["role"] = shcore::Value("HA");
+
+  if (info.hidden_from_router) {
+    (*dict)["hiddenFromRouter"] = shcore::Value::True();
+  }
 }
 
-void Status::feed_member_info(
-    shcore::Dictionary_t dict, const mysqlshdk::gr::Member &member,
-    const mysqlshdk::utils::nullable<bool> &offline_mode,
-    const mysqlshdk::utils::nullable<bool> &super_read_only,
-    const std::vector<std::string> &fence_sysvars,
-    mysqlshdk::gr::Member_state self_state, bool is_auto_rejoin_running) {
+void Status::feed_member_info(shcore::Dictionary_t dict,
+                              const mysqlshdk::gr::Member &member,
+                              std::optional<bool> offline_mode,
+                              std::optional<bool> super_read_only,
+                              const std::vector<std::string> &fence_sysvars,
+                              mysqlshdk::gr::Member_state self_state,
+                              bool is_auto_rejoin_running) {
   (*dict)["readReplicas"] = shcore::Value(shcore::make_dict());
 
-  if (!m_extended.is_null() && *m_extended >= 1) {
+  if (m_extended.value_or(0) >= 1) {
     // Set fenceSysVars array.
     shcore::Array_t fence_array = shcore::make_array();
     for (const auto &sysvar : fence_sysvars) {
@@ -692,8 +696,7 @@ void Status::feed_member_info(
   // memberRole instance Role as reported by GR (Primary/Secondary)
   (*dict)["memberRole"] = shcore::Value(mysqlshdk::gr::to_string(member.role));
 
-  if ((!m_extended.is_null() && *m_extended >= 1) ||
-      member.state != self_state) {
+  if ((m_extended.value_or(0) >= 1) || member.state != self_state) {
     // memberState is from the point of view of the member itself
     (*dict)["memberState"] =
         shcore::Value(mysqlshdk::gr::to_string(self_state));
@@ -703,7 +706,8 @@ void Status::feed_member_info(
   (*dict)["status"] = shcore::Value(mysqlshdk::gr::to_string(member.state));
 
   // Set the instance mode (read-only or read-write).
-  if (offline_mode.is_null() || super_read_only.is_null()) {
+  if (!offline_mode.has_value() || !super_read_only.has_value() ||
+      member.state != mysqlshdk::gr::Member_state::ONLINE) {
     // offline_mode or super_read_only is null if it could not be obtained from
     // the instance.
     (*dict)["mode"] = shcore::Value("n/a");
@@ -861,7 +865,7 @@ void check_parallel_appliers(
       parallel_applier_options.get_required_values(instance_version);
 
   for (const auto &setting : required_values) {
-    std::string current_value = current_values[std::get<0>(setting)].get_safe();
+    auto current_value = current_values[std::get<0>(setting)].value_or("");
 
     if (!current_value.empty() && current_value != std::get<1>(setting)) {
       issues->push_back(shcore::Value(
@@ -941,7 +945,7 @@ void check_transaction_size_limit(shcore::Array_t issues, Instance *instance,
   // Check if the instance's value for group_replication_transaction_size_limit
   // matches the Cluster's one
   int64_t instance_transaction_size_limit =
-      instance->get_sysvar_int(kGrTransactionSizeLimit).get_safe();
+      instance->get_sysvar_int(kGrTransactionSizeLimit).value_or(0);
 
   if (cluster_transaction_size_limit != -1 &&
       instance_transaction_size_limit != cluster_transaction_size_limit) {
@@ -957,8 +961,8 @@ shcore::Array_t instance_diagnostics(
     const Instance_metadata_info &instance_md,
     const mysqlshdk::mysql::Replication_channel &recovery_channel,
     const mysqlshdk::mysql::Replication_channel &applier_channel,
-    const mysqlshdk::utils::nullable<bool> &super_read_only,
-    const mysqlshdk::gr::Member &minfo, mysqlshdk::gr::Member_state self_state,
+    std::optional<bool> super_read_only, const mysqlshdk::gr::Member &minfo,
+    mysqlshdk::gr::Member_state self_state,
     const Parallel_applier_options &parallel_applier_options,
     int64_t cluster_transaction_size_limit) {
   shcore::Array_t issues = shcore::make_array();
@@ -978,14 +982,14 @@ shcore::Array_t instance_diagnostics(
       !(minfo.role == mysqlshdk::gr::Member_role::PRIMARY &&
         cluster->is_primary_cluster()) &&
       self_state != mysqlshdk::gr::Member_state::RECOVERING &&
-      !super_read_only.is_null() && !*super_read_only) {
+      super_read_only.has_value() && !*super_read_only) {
     issues->push_back(shcore::Value(
         "WARNING: Instance is NOT the global PRIMARY but super_read_only "
         "option is OFF. Errant transactions and inconsistencies may be "
         "accidentally introduced."));
   } else if (minfo.role == mysqlshdk::gr::Member_role::SECONDARY &&
              self_state != mysqlshdk::gr::Member_state::RECOVERING &&
-             !super_read_only.is_null() && !*super_read_only) {
+             super_read_only.has_value() && !*super_read_only) {
     issues->push_back(
         shcore::Value("WARNING: Instance is NOT a PRIMARY but super_read_only "
                       "option is OFF."));
@@ -1020,6 +1024,14 @@ shcore::Array_t instance_diagnostics(
         "cluster.rescan() to update the metadata."));
   }
 
+  try {
+    mysqlshdk::utils::split_host_and_port(instance_md.md.grendpoint);
+  } catch (const std::invalid_argument &e) {
+    issues->push_back(shcore::Value(
+        "ERROR: Invalid or missing information of Group Replication's network "
+        "address in metadata. Use Cluster.rescan() to update the metadata."));
+  }
+
   // check if value of report_host matches what's in the metadata
   if (instance) check_host_metadata(issues, instance, instance_md);
 
@@ -1142,55 +1154,51 @@ shcore::Array_t validate_instance_recovery_user(
       state != mysqlshdk::gr::Member_state::RECOVERING)
     return issues;
 
-  if (instance && !endpoints.empty()) {
-    auto it = endpoints.find(actual_server_uuid);
-    if (it != endpoints.end()) {
-      std::string recovery_user = mysqlshdk::mysql::get_replication_user(
-          *instance, mysqlshdk::gr::k_gr_recovery_channel);
+  if (!instance || endpoints.empty()) return issues;
 
-      // it->second is recovery user from MD
-      if (!recovery_user.empty()) {
-        bool recovery_is_valid =
-            shcore::str_beginswith(
-                recovery_user,
-                mysqlshdk::gr::k_group_recovery_old_user_prefix) ||
-            shcore::str_beginswith(recovery_user,
-                                   mysqlshdk::gr::k_group_recovery_user_prefix);
+  auto it = endpoints.find(actual_server_uuid);
+  if (it == endpoints.end()) return issues;
 
-        if (it->second.empty() && recovery_is_valid) {
-          issues->push_back(
-              shcore::Value("WARNING: The replication recovery account in use "
-                            "by the instance is not stored in the metadata. "
-                            "Use Cluster.rescan() to update the metadata."));
-        } else if (it->second != recovery_user) {
-          if (recovery_is_valid) {
-            issues->push_back(shcore::Value(
-                "WARNING: The replication recovery account in use "
-                "by the instance is not stored in the metadata. "
-                "Use Cluster.rescan() to update the metadata."));
-          } else {
-            issues->push_back(shcore::Value(
-                "WARNING: Unsupported recovery account '" + recovery_user +
-                "' has been found for instance '" + instance->descr() +
-                "'. Operations such as "
-                "Cluster.resetRecoveryAccountsPassword() and "
-                "Cluster.addInstance() may fail. Please remove and add "
-                "the instance back to the Cluster to ensure a supported "
-                "recovery "
-                "account is used."));
-          }
-        }
+  std::string recovery_user = mysqlshdk::mysql::get_replication_user(
+      *instance, mysqlshdk::gr::k_gr_recovery_channel);
+
+  // it->second is recovery user from MD
+  if (!recovery_user.empty()) {
+    bool recovery_is_valid =
+        shcore::str_beginswith(
+            recovery_user, mysqlshdk::gr::k_group_recovery_old_user_prefix) ||
+        shcore::str_beginswith(recovery_user,
+                               mysqlshdk::gr::k_group_recovery_user_prefix);
+
+    if (it->second.empty() && recovery_is_valid) {
+      issues->push_back(
+          shcore::Value("WARNING: The replication recovery account in use "
+                        "by the instance is not stored in the metadata. "
+                        "Use Cluster.rescan() to update the metadata."));
+    } else if (it->second != recovery_user) {
+      if (recovery_is_valid) {
+        issues->push_back(
+            shcore::Value("WARNING: The replication recovery account in use "
+                          "by the instance is not stored in the metadata. "
+                          "Use Cluster.rescan() to update the metadata."));
       } else {
         issues->push_back(shcore::Value(
-            "WARNING: Recovery user account not found for server address: " +
-            instance->descr() + " with UUID " + instance->get_uuid()));
+            "WARNING: Unsupported recovery account '" + recovery_user +
+            "' has been found for instance '" + instance->descr() +
+            "'. Operations such as Cluster.resetRecoveryAccountsPassword() and "
+            "Cluster.addInstance() may fail. Please remove and add "
+            "the instance back to the Cluster to ensure a supported recovery "
+            "account is used."));
       }
     }
+  } else {
+    issues->push_back(shcore::Value(
+        "WARNING: Recovery user account not found for server address: " +
+        instance->descr() + " with UUID " + instance->get_uuid()));
   }
 
   return issues;
 }
-
 }  // namespace
 
 shcore::Dictionary_t Status::get_topology(
@@ -1310,6 +1318,9 @@ shcore::Dictionary_t Status::get_topology(
             m_cluster.get_id());
   }
 
+  auto mismatched_recovery_accounts =
+      m_cluster.get_mismatched_recovery_accounts();
+
   for (const auto &inst : instances) {
     shcore::Dictionary_t member = shcore::make_dict();
     mysqlshdk::gr::Member minfo(get_member(inst.actual_server_uuid));
@@ -1318,8 +1329,8 @@ shcore::Dictionary_t Status::get_topology(
 
     auto &instance = m_member_sessions[inst.md.endpoint];
 
-    mysqlshdk::utils::nullable<bool> super_read_only;
-    mysqlshdk::utils::nullable<bool> offline_mode;
+    std::optional<bool> super_read_only;
+    std::optional<bool> offline_mode;
     std::vector<std::string> fence_sysvars;
     bool auto_rejoin = false;
 
@@ -1345,13 +1356,13 @@ shcore::Dictionary_t Status::get_topology(
 
       minfo.version = instance->get_version().get_base();
 
-      if (!m_extended.is_null()) {
+      if (m_extended.has_value()) {
         if (*m_extended >= 1) {
           fence_sysvars = instance->get_fence_sysvars();
 
           auto workers = parallel_applier_options.replica_parallel_workers;
 
-          if (parallel_applier_options.replica_parallel_workers.get_safe() >
+          if (parallel_applier_options.replica_parallel_workers.value_or(0) >
               0) {
             (*member)["applierWorkerThreads"] = shcore::Value(*workers);
           }
@@ -1437,26 +1448,52 @@ shcore::Dictionary_t Status::get_topology(
     feed_member_info(member, minfo, offline_mode, super_read_only,
                      fence_sysvars, self_state, auto_rejoin);
 
-    shcore::Array_t issues = instance_diagnostics(
-        instance.get(), &m_cluster, inst, recovery_channel, applier_channel,
-        super_read_only, minfo, self_state, parallel_applier_options,
-        *m_cluster_transaction_size_limit);
+    {
+      shcore::Array_t issues = instance_diagnostics(
+          instance.get(), &m_cluster, inst, recovery_channel, applier_channel,
+          super_read_only, minfo, self_state, parallel_applier_options,
+          *m_cluster_transaction_size_limit);
 
-    if (offline_mode.get_safe(false))
-      issues->push_back(
-          shcore::Value("WARNING: Instance has offline_mode enabled."));
+      if (offline_mode.value_or(false))
+        issues->push_back(
+            shcore::Value("WARNING: Instance has offline_mode enabled."));
 
-    auto ret_val = validate_instance_recovery_user(
-        instance, endpoints, inst.actual_server_uuid, self_state);
+      if (instance) {
+        auto ret_val = validate_instance_recovery_user(
+            instance, endpoints, inst.actual_server_uuid, self_state);
 
-    issues->insert(issues->end(), std::make_move_iterator(ret_val->begin()),
-                   std::make_move_iterator(ret_val->end()));
+        // if the last check returned an error, the next check will too, so
+        // there's no need to show the user two different msgs that kind of
+        // point to the same thing (although for different reasons)
+        if (ret_val->empty()) {
+          auto it = mismatched_recovery_accounts.find(instance->get_id());
+          if (it != mismatched_recovery_accounts.end()) {
+            auto msg = shcore::str_format(
+                "WARNING: Incorrect recovery account (%s) being used. Use "
+                "Cluster.rescan() to repair.",
+                it->second.c_str());
+            ret_val->push_back(shcore::Value(std::move(msg)));
+          }
+        }
 
-    if (issues && !issues->empty()) {
-      (*member)["instanceErrors"] = shcore::Value(issues);
+        issues->insert(issues->end(), std::make_move_iterator(ret_val->begin()),
+                       std::make_move_iterator(ret_val->end()));
+      }
+
+      // check if primary has unused recovery accounts
+      if (minfo.role == Member_role::PRIMARY) {
+        auto ret_val =
+            validate_recovery_accounts_unused(mismatched_recovery_accounts);
+        issues->insert(issues->end(), std::make_move_iterator(ret_val->begin()),
+                       std::make_move_iterator(ret_val->end()));
+      }
+
+      if (issues && !issues->empty()) {
+        (*member)["instanceErrors"] = shcore::Value(std::move(issues));
+      }
     }
 
-    if ((!m_extended.is_null() && *m_extended >= 2) &&
+    if ((m_extended.value_or(0) >= 2) &&
         member_stats.find(inst.md.uuid) != member_stats.end()) {
       shcore::Dictionary_t mdict = member;
 
@@ -1515,15 +1552,14 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
     }
   }
 
-  if ((!m_extended.is_null() && *m_extended >= 1)) {
+  if (m_extended.value_or(0) >= 1) {
     (*ret)["groupName"] = shcore::Value(m_cluster.get_group_name());
 
     if (group_instance &&
         group_instance->get_version() >= mysqlshdk::utils::Version(8, 0, 26)) {
-      (*ret)["groupViewChangeUuid"] = shcore::Value(
-          group_instance
-              ->get_sysvar_string("group_replication_view_change_uuid")
-              .get_safe());
+      (*ret)["groupViewChangeUuid"] =
+          shcore::Value(group_instance->get_sysvar_string(
+              "group_replication_view_change_uuid", ""));
     }
 
     (*ret)["GRProtocolVersion"] =
@@ -1545,13 +1581,9 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
     }
   }
 
-  auto ssl_mode =
-      group_instance
-          ? group_instance
-                ->get_sysvar_string("group_replication_ssl_mode",
-                                    mysqlshdk::mysql::Var_qualifier::GLOBAL)
-                .get_safe()
-          : "";
+  auto ssl_mode = group_instance ? group_instance->get_sysvar_string(
+                                       "group_replication_ssl_mode", "")
+                                 : "";
   if (!ssl_mode.empty()) {
     (*ret)["ssl"] = shcore::Value(ssl_mode);
   }
@@ -1568,7 +1600,7 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
     tmp = check_group_status(*group_instance, member_info, has_quorum);
     (*ret)["statusText"] = shcore::Value(tmp->get_string("statusText"));
     (*ret)["status"] = shcore::Value(tmp->get_string("status"));
-    if (!m_extended.is_null() && *m_extended >= 1)
+    if (m_extended.value_or(0) >= 1)
       (*ret)["groupViewId"] = shcore::Value(view_id);
 
     std::shared_ptr<Instance> primary_instance;
@@ -1616,7 +1648,7 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
       m_cluster_transaction_size_limit =
           m_cluster.get_cluster_server()
               ->get_sysvar_int(kGrTransactionSizeLimit)
-              .get_safe();
+              .value_or(0);
     }
 
     if (!is_replica_cluster) {
@@ -1642,6 +1674,29 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
   return ret;
 }
 
+shcore::Array_t Status::validate_recovery_accounts_unused(
+    const std::unordered_map<uint32_t, std::string>
+        &mismatched_recovery_accounts) const {
+  auto issues = shcore::make_array();
+
+  auto accounts =
+      m_cluster.get_unused_recovery_accounts(mismatched_recovery_accounts);
+  if (accounts.empty()) return issues;
+
+  std::string msg{accounts.size() == 1
+                      ? "WARNING: Detected an unused recovery account: "
+                      : "WARNING: Detected unused recovery accounts: "};
+
+  for (const auto &account : accounts)
+    msg.append(std::get<0>(account)).append(", ");
+  msg.erase(msg.size() - 2);  // remove last ", "
+
+  msg.append(". Use Cluster.rescan() to clean up.");
+
+  issues->push_back(shcore::Value(std::move(msg)));
+  return issues;
+}
+
 void Status::prepare() {
   // Sanity check: Verify if the topology type changed and issue an error if
   // needed.
@@ -1720,10 +1775,8 @@ shcore::Value Status::execute() {
         shcore::Value(m_cluster.is_primary_cluster() ? "PRIMARY" : "REPLICA");
 
     // Get the ClusterSet replication channel status
-    auto cluster_cpy = std::make_unique<Cluster_impl>(m_cluster);
-
     Cluster_channel_status ch_status =
-        cluster_cpy->get_cluster_set_object()->get_replication_channel_status(
+        m_cluster.get_cluster_set_object()->get_replication_channel_status(
             m_cluster);
 
     // If the Cluster is a Replica, add the status right away
@@ -1746,7 +1799,7 @@ shcore::Value Status::execute() {
 
   if (m_cluster.get_cluster_server()) {
     // Gets the metadata version
-    if (!m_extended.is_null() && *m_extended >= 1) {
+    if (m_extended.value_or(0) >= 1) {
       auto version = mysqlsh::dba::metadata::installed_version(
           m_cluster.get_cluster_server());
       (*dict)["metadataVersion"] = shcore::Value(version.get_base());
