@@ -35,7 +35,6 @@
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/sql.h"
-#include "modules/adminapi/common/star_global_topology_manager.h"
 #include "modules/adminapi/common/validations.h"
 #include "modules/adminapi/mod_dba.h"
 #include "mysqlshdk/include/shellcore/console.h"
@@ -54,6 +53,7 @@
 #include "mysqlshdk/libs/mysql/user_privileges.h"
 #include "mysqlshdk/libs/textui/progress.h"
 #include "mysqlshdk/libs/textui/textui.h"
+#include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_lexing.h"
@@ -94,45 +94,32 @@ void validate_gr_session(
 }  // namespace
 
 std::string to_string(Cluster_ssl_mode ssl_mode) {
-  std::string ret_val;
-
   switch (ssl_mode) {
     case Cluster_ssl_mode::AUTO:
-      ret_val = kClusterSSLModeAuto;
-      break;
+      return kClusterSSLModeAuto;
     case Cluster_ssl_mode::DISABLED:
-      ret_val = kClusterSSLModeDisabled;
-      break;
+      return kClusterSSLModeDisabled;
     case Cluster_ssl_mode::REQUIRED:
-      ret_val = kClusterSSLModeRequired;
-      break;
+      return kClusterSSLModeRequired;
     case Cluster_ssl_mode::VERIFY_CA:
-      ret_val = kClusterSSLModeVerifyCA;
-      break;
+      return kClusterSSLModeVerifyCA;
     case Cluster_ssl_mode::VERIFY_IDENTITY:
-      ret_val = kClusterSSLModeVerifyIdentity;
-      break;
+      return kClusterSSLModeVerifyIdentity;
     case Cluster_ssl_mode::NONE:
-      ret_val = "NONE";
-      break;
+      return "NONE";
   }
-  return ret_val;
+  return {};
 }
 
 Cluster_ssl_mode to_cluster_ssl_mode(const std::string &mode) {
-  if (shcore::str_caseeq("AUTO", mode)) {
-    return Cluster_ssl_mode::AUTO;
-  } else if (shcore::str_caseeq("DISABLED", mode)) {
-    return Cluster_ssl_mode::DISABLED;
-  } else if (shcore::str_caseeq("REQUIRED", mode)) {
-    return Cluster_ssl_mode::REQUIRED;
-  } else if (shcore::str_caseeq("VERIFY_CA", mode)) {
-    return Cluster_ssl_mode::VERIFY_CA;
-  } else if (shcore::str_caseeq("VERIFY_IDENTITY", mode)) {
+  if (shcore::str_caseeq("AUTO", mode)) return Cluster_ssl_mode::AUTO;
+  if (shcore::str_caseeq("DISABLED", mode)) return Cluster_ssl_mode::DISABLED;
+  if (shcore::str_caseeq("REQUIRED", mode)) return Cluster_ssl_mode::REQUIRED;
+  if (shcore::str_caseeq("VERIFY_CA", mode)) return Cluster_ssl_mode::VERIFY_CA;
+  if (shcore::str_caseeq("VERIFY_IDENTITY", mode))
     return Cluster_ssl_mode::VERIFY_IDENTITY;
-  } else {
-    throw std::runtime_error("Unsupported Cluster SSL-mode: " + mode);
-  }
+
+  throw std::runtime_error("Unsupported Cluster SSL-mode: " + mode);
 }
 
 std::string get_mysqlprovision_error_string(
@@ -161,27 +148,35 @@ bool is_option_supported(
     const mysqlshdk::utils::Version &version, const std::string &option,
     const std::map<std::string, Option_availability> &options_map) {
   assert(options_map.find(option) != options_map.end());
-  Option_availability opt_avail = options_map.at(option);
+  auto &opt_avail = options_map.at(option);
+
+  // if no version was supplied, options can be used regardless of version
+  if (opt_avail.support_in_80.get_major() == 0 &&
+      opt_avail.support_in_57.get_major() == 0)
+    return true;
+
   if (version.get_major() == 8) {
     // 8.0 server
     // if only the 5.7 version was provided to the Option_availability struct,
     // then assume variable will also be supported in 8.0. This check is enough
     // since the default Version constructor sets the major version to 0.
     return version >= opt_avail.support_in_80;
-  } else if (version.get_major() == 5 && version.get_minor() == 7) {
+  }
+
+  if (version.get_major() == 5 && version.get_minor() == 7) {
     // 5.7 server
     if (opt_avail.support_in_57.get_major() == 0) {
       // if the default constructor for version was used, no 5.7 version was
       // used on the Option_availability struct, meaning 5.7 is not supported
       return false;
-    } else {
-      return version >= opt_avail.support_in_57;
     }
-  } else {
-    throw std::runtime_error(
-        "Unexpected version found for option support check: '" +
-        version.get_full() + "'.");
+
+    return version >= opt_avail.support_in_57;
   }
+
+  throw std::runtime_error(
+      "Unexpected version found for option support check: '" +
+      version.get_full() + "'.");
 }
 
 void validate_replication_filters(const mysqlshdk::mysql::IInstance &instance,
@@ -246,56 +241,53 @@ void validate_replication_filters(const mysqlshdk::mysql::IInstance &instance,
   }
 }
 
-/**
- * Resolves the SSL mode based on:
- * - The instance having SSL available
- * - The instance having require_secure_transport ON
- * - The memberSslMode option given by the user
- *
- * Assigned to:
- *   REQUIRED if SSL is supported and member_ssl_mode is either AUTO or REQUIRED
- *   VERIFY_CA if SSL is supported and member_ssl_mode is VERIFY_CA
- *   VERIFY_IDENTITY if SSL is supported and member_ssl_mode is VERIFY_IDENTITY
- *   DISABLED if SSL is not supported and member_ssl_mode is either unspecified
- *            DISABLED or AUTO.
- *
- * Error:
- *   - If SSL is supported, require_secure_transport is ON and member_ssl_mode
- *     is DISABLED
- *   - If SSL mode is not supported and member_ssl_mode is REQUIRED, VERIFY_CA
- *     or VERIFY_IDENTITY
- */
-mysqlshdk::db::nullable<Cluster_ssl_mode> resolve_ssl_mode(
-    const mysqlshdk::mysql::IInstance &instance,
-    const Cluster_ssl_mode &ssl_mode, bool *have_ssl) {
-  mysqlshdk::db::nullable<Cluster_ssl_mode> resolved_ssl_mode;
-  std::string have_ssl_str = *instance.get_sysvar_string("have_ssl");
+void resolve_ssl_mode_option(const std::string &option,
+                             const std::string &context,
+                             const mysqlshdk::mysql::IInstance &instance,
+                             Cluster_ssl_mode *ssl_mode) {
+  bool require_secure_transport =
+      instance.get_sysvar_bool("require_secure_transport", false);
+  bool have_ssl = instance.is_ssl_enabled();
 
-  // The instance supports SSL
-  if (shcore::str_caseeq(have_ssl_str, "YES")) {
-    if (have_ssl) *have_ssl = true;
-
-    if (ssl_mode == Cluster_ssl_mode::AUTO ||
-        ssl_mode == Cluster_ssl_mode::NONE) {
-      // sslMode when set to AUTO and SSL is supported, then REQUIRED is
-      // used
-      resolved_ssl_mode = Cluster_ssl_mode::REQUIRED;
-    } else {
-      resolved_ssl_mode = ssl_mode;
-    }
-  } else {  // The instance does not support SSL
-    if (have_ssl) *have_ssl = false;
-    // sslMode is either not defined, DISABLED or AUTO
-    if (ssl_mode != Cluster_ssl_mode::REQUIRED &&
-        ssl_mode != Cluster_ssl_mode::VERIFY_CA &&
-        ssl_mode != Cluster_ssl_mode::VERIFY_IDENTITY) {
-      resolved_ssl_mode = Cluster_ssl_mode::DISABLED;
-    } else {
-      resolved_ssl_mode = ssl_mode;
-    }
+  // sslMode is DISABLED but instance requires SSL
+  if (*ssl_mode == Cluster_ssl_mode::DISABLED && require_secure_transport) {
+    throw shcore::Exception::argument_error(
+        "The instance '" + instance.descr() +
+        "' requires secure connections, to create the " + context +
+        " either turn off require_secure_transport or use the " + option +
+        " option with 'REQUIRED', 'VERIFY_CA' or "
+        "'VERIFY_IDENTITY' value.");
   }
 
-  return resolved_ssl_mode;
+  // sslMode is REQUIRED, VERIFY_CA or VERIFY_IDENTITY
+  if (!have_ssl && (*ssl_mode == Cluster_ssl_mode::REQUIRED ||
+                    *ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
+                    *ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY)) {
+    throw shcore::Exception::argument_error(
+        "The instance '" + instance.descr() +
+        "' does not have TLS enabled, to create the " + context +
+        " either use an instance with TLS enabled, remove the " + option +
+        " option or use it with any of 'AUTO' or 'DISABLED'.");
+  }
+
+  // sslMode is VERIFY_CA or VERIFY_IDENTITY, verify the certificates
+  if (*ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
+      *ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
+    ensure_certificates_set(instance, *ssl_mode);
+  }
+
+  if (*ssl_mode == Cluster_ssl_mode::NONE ||
+      *ssl_mode == Cluster_ssl_mode::AUTO) {
+    if (have_ssl) {
+      *ssl_mode = Cluster_ssl_mode::REQUIRED;
+    } else {
+      current_console()->print_note("TLS not available at '" +
+                                    instance.descr() + "', assuming " + option +
+                                    " to be DISABLED");
+
+      *ssl_mode = Cluster_ssl_mode::DISABLED;
+    }
+  }
 }
 
 /**
@@ -323,82 +315,114 @@ mysqlshdk::db::nullable<Cluster_ssl_mode> resolve_ssl_mode(
  *     VERIFY_IDENTITY
  *   - Cluster has SSL disabled and the instance has require_secure_transport ON
  */
-void resolve_instance_ssl_mode(const mysqlshdk::mysql::IInstance &instance,
-                               const mysqlshdk::mysql::IInstance &pinstance,
-                               Cluster_ssl_mode *member_ssl_mode) {
+void resolve_instance_ssl_mode_option(
+    const mysqlshdk::mysql::IInstance &instance,
+    const mysqlshdk::mysql::IInstance &pinstance,
+    Cluster_ssl_mode *member_ssl_mode) {
   assert(member_ssl_mode);
 
-  // Get how memberSslMode was configured on the cluster
   Cluster_ssl_mode gr_ssl_mode = to_cluster_ssl_mode(
-      pinstance.get_sysvar_string("group_replication_ssl_mode").get_safe());
+      pinstance.get_sysvar_string("group_replication_ssl_mode", ""));
+
+  // check for conflicts between the (deprecated) per-instance memberSslMode
+  // and the group setting
+  switch (gr_ssl_mode) {
+    case Cluster_ssl_mode::REQUIRED:
+    case Cluster_ssl_mode::VERIFY_CA:
+    case Cluster_ssl_mode::VERIFY_IDENTITY:
+      // memberSslMode is DISABLED
+      if (*member_ssl_mode == Cluster_ssl_mode::DISABLED) {
+        throw shcore::Exception::runtime_error(
+            "The cluster has TLS (encryption) enabled. "
+            "To add the instance '" +
+            instance.descr() +
+            "' to the cluster either disable TLS on the cluster, remove the "
+            "memberSslMode option or use it with any of 'AUTO', 'REQUIRED', "
+            "'VERIFY_CA' or 'VERIFY_IDENTITY'.");
+      }
+      // addInstance() can have a different memberSslMode from the cluster,
+      // although that's deprecated
+      if (*member_ssl_mode == Cluster_ssl_mode::AUTO ||
+          *member_ssl_mode == Cluster_ssl_mode::NONE)
+        *member_ssl_mode = gr_ssl_mode;
+      break;
+
+    case Cluster_ssl_mode::NONE:
+    case Cluster_ssl_mode::DISABLED:
+      if (*member_ssl_mode == Cluster_ssl_mode::REQUIRED ||
+          *member_ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
+          *member_ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
+        throw shcore::Exception::runtime_error(
+            "The cluster has TLS (encryption) disabled. "
+            "To add the instance '" +
+            instance.descr() +
+            "' to the cluster either "
+            "enable TLS on the cluster, remove the memberSslMode option or "
+            "use it with any of 'AUTO' or 'DISABLED'.");
+      }
+      *member_ssl_mode = gr_ssl_mode;
+      break;
+
+    case Cluster_ssl_mode::AUTO:
+      // not possible
+      assert(0);
+      *member_ssl_mode = gr_ssl_mode;
+      break;
+  }
+
+  validate_instance_ssl_mode(Cluster_type::GROUP_REPLICATION, instance,
+                             *member_ssl_mode);
+}
+
+void validate_instance_ssl_mode(Cluster_type type,
+                                const mysqlshdk::mysql::IInstance &instance,
+                                Cluster_ssl_mode ssl_mode) {
+  assert(ssl_mode != Cluster_ssl_mode::AUTO);
+
+  bool have_ssl = instance.is_ssl_enabled();
 
   // The cluster REQUIRES SSL
-  if (gr_ssl_mode == Cluster_ssl_mode::REQUIRED ||
-      gr_ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
-      gr_ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
-    // memberSslMode is DISABLED
-    if (*member_ssl_mode == Cluster_ssl_mode::DISABLED) {
-      throw shcore::Exception::runtime_error(
-          "The cluster has SSL (encryption) enabled. "
-          "To add the instance '" +
-          instance.descr() +
-          "' to the cluster either disable SSL on the cluster, remove the "
-          "memberSslMode option or use it with any of 'AUTO', 'REQUIRED', "
-          "'VERIFY_CA' or 'VERIFY_IDENTITY'.");
-    }
-
+  if (ssl_mode == Cluster_ssl_mode::REQUIRED ||
+      ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
+      ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
     // Now checks if SSL is actually supported on the instance
-    std::string have_ssl = *instance.get_sysvar_string("have_ssl");
 
     // SSL is not supported on the instance
-    if (!shcore::str_caseeq(have_ssl, "YES")) {
+    if (!have_ssl) {
       throw shcore::Exception::runtime_error(
           "Instance '" + instance.descr() +
-          "' does not support SSL and cannot join a cluster with SSL "
-          "(encryption) enabled. Enable SSL support on the instance and try "
-          "again, otherwise it can only be added to a cluster with SSL "
-          "disabled.");
+          "' does not support TLS and cannot join " +
+          to_display_string(type, Display_form::A_THING) +
+          " with TLS (encryption) enabled. Enable TLS support on the instance "
+          "and try again, otherwise it can only be added to " +
+          to_display_string(type, Display_form::A_THING) +
+          " with TLS disabled.");
     } else {
-      // memberSslMode AUTO
-      if (*member_ssl_mode == Cluster_ssl_mode::AUTO ||
-          *member_ssl_mode == Cluster_ssl_mode::NONE) {
-        *member_ssl_mode = gr_ssl_mode;
-      } else if (*member_ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
-                 *member_ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
+      if (ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
+          ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
         // memberSslMode is VERIFY_CA or VERIFY_IDENTITY
         // verify the certificates
-        ensure_certificates_set(instance, *member_ssl_mode);
+        ensure_certificates_set(instance, ssl_mode);
       }
     }
     // The cluster has SSL DISABLED
-  } else if (gr_ssl_mode == Cluster_ssl_mode::DISABLED) {
-    // memberSslMode is REQUIRED, VERIFY_CA or VERIFY_IDENTITY
-    if (*member_ssl_mode == Cluster_ssl_mode::REQUIRED ||
-        *member_ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
-        *member_ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
-      throw shcore::Exception::runtime_error(
-          "The cluster has SSL (encryption) disabled. "
-          "To add the instance '" +
-          instance.descr() +
-          "' to the cluster either "
-          "enable SSL on the cluster, remove the memberSslMode option or use "
-          "it with any of 'AUTO' or 'DISABLED'.");
-    }
+  } else if (ssl_mode == Cluster_ssl_mode::DISABLED) {
+    bool require_secure_transport =
+        instance.get_sysvar_bool("require_secure_transport", false);
 
     // If the instance session requires SSL connections, then it can's
     // Join a cluster with SSL disabled
-    bool secure_transport_required =
-        *instance.get_sysvar_bool("require_secure_transport");
-    if (secure_transport_required) {
+    if (require_secure_transport) {
       throw shcore::Exception::runtime_error(
           "The instance '" + instance.descr() +
-          "' is configured to require a secure transport but the cluster has "
-          "SSL disabled. To add the instance to the cluster, either turn OFF "
-          "the require_secure_transport option on the instance or enable SSL "
-          "on the cluster.");
+          "' is configured to require a secure transport but the " +
+          to_display_string(type, Display_form::THING) +
+          " has TLS disabled. To add the instance to the " +
+          to_display_string(type, Display_form::THING) +
+          ", either turn OFF the require_secure_transport option on the "
+          "instance or enable TLS on the " +
+          to_display_string(type, Display_form::THING) + ".");
     }
-
-    *member_ssl_mode = Cluster_ssl_mode::DISABLED;
   }
 }
 
@@ -731,7 +755,7 @@ bool validate_cluster_group_name(const mysqlshdk::mysql::IInstance &instance,
 bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance,
                               mysqlshdk::null_bool clear_read_only,
                               bool interactive) {
-  if (auto super_read_only = *instance.get_sysvar_bool("super_read_only");
+  if (auto super_read_only = instance.get_sysvar_bool("super_read_only", false);
       !super_read_only)
     return false;
 
@@ -1040,64 +1064,56 @@ int prompt_menu(const std::vector<std::string> &options, int defopt) {
  */
 bool prompt_super_read_only(const mysqlshdk::mysql::IInstance &instance,
                             bool throw_on_error) {
+  // Get the status of super_read_only in order to verify if we need to
+  // prompt the user to disable it
+  if (auto super_read_only = instance.get_sysvar_bool("super_read_only", false);
+      !super_read_only) {
+    return true;
+  }
+
   auto options_session = instance.get_connection_options();
   auto active_session_address =
       options_session.as_uri(mysqlshdk::db::uri::formats::only_transport());
 
-  // Get the status of super_read_only in order to verify if we need to
-  // prompt the user to disable it
-  mysqlshdk::null_bool super_read_only =
-      instance.get_sysvar_bool("super_read_only");
+  auto console = mysqlsh::current_console();
+  console->print_para(
+      "The MySQL instance at '" + active_session_address +
+      "' currently has the super_read_only system variable set to "
+      "protect it from inadvertent updates from applications.\n"
+      "You must first unset it to be able to perform any changes "
+      "to this instance.\n"
+      "For more information see: https://dev.mysql.com/doc/refman/"
+      "en/server-system-variables.html#sysvar_super_read_only.");
 
-  // If super_read_only is not null and enabled
-  if (*super_read_only) {
-    auto console = mysqlsh::current_console();
-    console->print_para(
-        "The MySQL instance at '" + active_session_address +
-        "' currently has the super_read_only system variable set to "
-        "protect it from inadvertent updates from applications.\n"
-        "You must first unset it to be able to perform any changes "
-        "to this instance.\n"
-        "For more information see: https://dev.mysql.com/doc/refman/"
-        "en/server-system-variables.html#sysvar_super_read_only.");
+  // Get the list of open session to the instance
+  std::vector<std::pair<std::string, int>> open_sessions;
+  open_sessions = mysqlsh::dba::get_open_sessions(instance);
 
-    // Get the list of open session to the instance
-    std::vector<std::pair<std::string, int>> open_sessions;
-    open_sessions = mysqlsh::dba::get_open_sessions(instance);
+  if (!open_sessions.empty()) {
+    console->print_note("There are open sessions to '" +
+                        active_session_address + "'.");
+    console->print_info(
+        "You may want to kill these sessions to prevent them from "
+        "performing unexpected updates: \n");
 
-    if (!open_sessions.empty()) {
-      console->print_note("There are open sessions to '" +
-                          active_session_address + "'.");
-      console->print_info(
-          "You may want to kill these sessions to prevent them from "
-          "performing unexpected updates: \n");
-
-      for (auto &value : open_sessions) {
-        std::string account = value.first;
-        int num_open_sessions = value.second;
-
-        console->print_info("" + std::to_string(num_open_sessions) +
-                            " open session(s) of "
-                            "'" +
-                            account + "'. \n");
-      }
-    }
-
-    if (console->confirm("Do you want to disable super_read_only and continue?",
-                         Prompt_answer::NO) == Prompt_answer::NO) {
-      console->print_info();
-
-      if (throw_on_error)
-        throw shcore::cancelled("Cancelled");
-      else
-        console->print_info("Cancelled");
-
-      return false;
-    } else {
-      return true;
+    for (const auto &[account, num_open_sessions] : open_sessions) {
+      console->print_info(shcore::str_format("%d open session(s) of '%s'. \n",
+                                             num_open_sessions,
+                                             account.c_str()));
     }
   }
-  return true;
+
+  if (console->confirm("Do you want to disable super_read_only and continue?",
+                       Prompt_answer::NO) != Prompt_answer::NO) {
+    return true;
+  }
+
+  console->print_info();
+
+  if (throw_on_error) throw shcore::cancelled("Cancelled");
+  console->print_info("Cancelled");
+
+  return false;
 }
 
 /*
@@ -1337,19 +1353,19 @@ std::unique_ptr<mysqlshdk::config::Config> create_server_config(
   auto cfg = std::make_unique<mysqlshdk::config::Config>();
 
   // Get the capabilities to use set persist by the server.
-  mysqlshdk::null_bool can_set_persist = instance->is_set_persist_supported();
+  std::optional<bool> can_set_persist = instance->is_set_persist_supported();
 
   // Add server configuration handler depending on SET PERSIST support.
   cfg->add_handler(
       srv_cfg_handler_name,
       std::unique_ptr<mysqlshdk::config::IConfig_handler>(
           std::make_unique<mysqlshdk::config::Config_server_handler>(
-              instance, (!can_set_persist.is_null() && *can_set_persist)
+              instance, can_set_persist.value_or(false)
                             ? mysqlshdk::mysql::Var_qualifier::PERSIST
                             : mysqlshdk::mysql::Var_qualifier::GLOBAL)));
 
   if (!silent) {
-    if (can_set_persist.is_null()) {
+    if (!can_set_persist.has_value()) {
       auto console = mysqlsh::current_console();
 
       std::string warn_msg =
@@ -1410,13 +1426,13 @@ void add_config_file_handler(mysqlshdk::config::Config *cfg,
 }
 
 std::string resolve_gr_local_address(
-    const mysqlshdk::null_string &local_address,
-    const mysqlshdk::null_string &communication_stack,
+    const std::optional<std::string> &local_address,
+    const std::optional<std::string> &communication_stack,
     const std::string &raw_report_host, int port, bool check_if_busy,
     bool quiet) {
   assert(!raw_report_host.empty());  // First we need to get the report host.
   bool generated = false;
-  bool comm_stack_mysql = shcore::str_caseeq(communication_stack.get_safe(),
+  bool comm_stack_mysql = shcore::str_caseeq(communication_stack.value_or(""),
                                              kCommunicationStackMySQL);
 
   // if report host is an IPv6 address, surround it with []
@@ -1431,7 +1447,7 @@ std::string resolve_gr_local_address(
   std::string local_host;
   int local_port;
 
-  if (local_address.is_null() || local_address->empty()) {
+  if (!local_address.has_value() || local_address->empty()) {
     // If communicationStack is set to 'mysql' local_address must default to the
     // network address on which MySQL is listening to: report_host:port
     if (comm_stack_mysql) {
@@ -1844,6 +1860,52 @@ bool wait_for_gtid_set_safe(const mysqlshdk::mysql::IInstance &target_instance,
   return sync_res;
 }
 
+void wait_for_apply_retrieved_trx(
+    const mysqlshdk::mysql::IInstance &target_instance,
+    const std::string &channel_name, std::chrono::seconds timeout,
+    bool silent) {
+  log_info("Waiting %d seconds for received transactions to be applied at '%s'",
+           static_cast<int>(timeout.count()), target_instance.descr().c_str());
+
+  DBUG_EXECUTE_IF("dba_wait_for_apply_retrieved_trx_timeout", {
+    throw shcore::Exception(
+        shcore::str_format(
+            "Timeout waiting for received transactions to be applied on "
+            "instance '%s' (debug)",
+            target_instance.descr().c_str()),
+        SHERR_DBA_GTID_SYNC_TIMEOUT);
+  });
+
+  std::string gtid_set =
+      mysqlshdk::mysql::get_received_gtid_set(target_instance, channel_name);
+
+  // optimize (common?) case where the GTIDs have already been applied
+  if (mysqlshdk::mysql::test_for_gtid_set(
+          target_instance, mysqlshdk::mysql::Gtid_set::from_string(gtid_set)))
+    return;
+
+  if (!silent) {
+    auto console = mysqlsh::current_console();
+    console->print_info(shcore::str_format(
+        "** Waiting for received transactions to be applied at '%s'...",
+        target_instance.descr().c_str()));
+  }
+
+  try {
+    if (!mysqlshdk::mysql::wait_for_gtid_set(target_instance, gtid_set,
+                                             timeout.count())) {
+      throw shcore::Exception(
+          shcore::str_format(
+              "Timeout waiting for received transactions to be applied on "
+              "instance '%s'",
+              target_instance.descr().c_str()),
+          SHERR_DBA_GTID_SYNC_TIMEOUT);
+    }
+  } catch (const shcore::Error &e) {
+    throw shcore::Exception::mysql_error_with_code(e.what(), e.code());
+  }
+}
+
 void execute_script(const std::shared_ptr<Instance> &group_server,
                     const std::string &script, const std::string &context) {
   auto console = mysqlsh::current_console();
@@ -1851,12 +1913,12 @@ void execute_script(const std::shared_ptr<Instance> &group_server,
 
   mysqlshdk::mysql::execute_sql_script(
       *group_server, script,
-      [&console, &first_error, &context](const std::string &err) {
+      [&console, &first_error, &context](std::string_view err) {
         if (first_error) {
           console->print_error(context);
           first_error = false;
         }
-        console->print_error(err);
+        console->print_error(std::string{err});
       });
 }
 
@@ -1972,6 +2034,17 @@ TargetType::Type get_instance_type(
 
   try {
     auto channels = mysqlshdk::mysql::get_incoming_channels(target_instance);
+
+    // filter out GR channels, since they don't indicate AR is configured
+    channels.erase(
+        std::remove_if(
+            channels.begin(), channels.end(),
+            [](const mysqlshdk::mysql::Replication_channel &ch) {
+              return ch.channel_name == mysqlshdk::gr::k_gr_applier_channel ||
+                     ch.channel_name == mysqlshdk::gr::k_gr_recovery_channel;
+            }),
+        channels.end());
+
     if (!channels.empty()) return TargetType::AsyncReplication;
 
     auto slaves = mysqlshdk::mysql::get_slaves(target_instance);
@@ -2066,5 +2139,208 @@ Cluster_check_info get_cluster_check_info(const MetadataStorage &metadata,
   return state;
 }
 
+namespace cluster_topology_executor_ops {
+void validate_add_rejoin_options(Group_replication_options options,
+                                 const std::string &communication_stack) {
+  // ipAllowList cannot be used by addInstance/rejoinInstance when the
+  // communication stack in use by the Cluster is 'MySQL'
+  if (communication_stack == kCommunicationStackMySQL &&
+      options.ip_allowlist.has_value()) {
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Cannot use '%s' when the Cluster's communication stack is "
+        "'%s'",
+        options.ip_allowlist_option_name.c_str(), kCommunicationStackMySQL));
+  }
+}
+
+bool is_member_auto_rejoining(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance) {
+  // Check if instance was doing auto-rejoin and let the user know that the
+  // rejoin operation will override the auto-rejoin
+  if (mysqlshdk::gr::is_running_gr_auto_rejoin(*target_instance) ||
+      mysqlshdk::gr::is_group_replication_delayed_starting(*target_instance)) {
+    auto console = current_console();
+    console->print_note(
+        "The instance '" +
+        target_instance->get_connection_options().uri_endpoint() +
+        "' is running auto-rejoin process, which will be cancelled.");
+    console->print_info();
+
+    return true;
+  }
+
+  return false;
+}
+
+void ensure_not_auto_rejoining(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance) {
+  current_console()->print_note("Cancelling active GR auto-initialization at " +
+                                target_instance->descr());
+  mysqlshdk::gr::stop_group_replication(*target_instance);
+}
+
+void check_comm_stack_support(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+    Group_replication_options *gr_options,
+    const std::string &communication_stack) {
+  if (communication_stack == kCommunicationStackMySQL &&
+      target_instance->get_version() <
+          k_mysql_communication_stack_initial_version) {
+    auto console = mysqlsh::current_console();
+    console->print_error("Cannot join instance '" + target_instance->descr() +
+                         "' to Cluster: The Group Replication protocol stack "
+                         "in used by the Cluster ('" +
+                         kCommunicationStackMySQL +
+                         "') is not supported in the instance");
+
+    throw shcore::Exception("Unsupported Group Replication protocol stack '" +
+                                std::string(kCommunicationStackMySQL) + "'",
+                            SHERR_DBA_UNSUPPORTED_COMMUNICATION_PROTOCOL);
+  }
+
+  // Set the communication stack protocol to be used only if the target
+  // instance supports it
+  if (target_instance->get_version() >=
+      k_mysql_communication_stack_initial_version) {
+    gr_options->communication_stack = communication_stack;
+  }
+}
+
+void ensure_instance_check_installed_schema_version(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+    mysqlshdk::utils::Version lowest_cluster_version) {
+  try {
+    // Check instance version compatibility according to Group Replication.
+    mysqlshdk::gr::check_instance_check_installed_schema_version(
+        *target_instance, lowest_cluster_version);
+  } catch (const std::runtime_error &err) {
+    auto console = mysqlsh::current_console();
+    console->print_error(
+        "Cannot join instance '" + target_instance->descr() +
+        "' to cluster: instance version is incompatible with the cluster.");
+    throw;
+  }
+
+  // Print a warning if the instance is only read compatible.
+  if (mysqlshdk::gr::is_instance_only_read_compatible(*target_instance,
+                                                      lowest_cluster_version)) {
+    auto console = mysqlsh::current_console();
+    console->print_warning("The instance '" + target_instance->descr() +
+                           "' is only read compatible with the cluster, thus "
+                           "it will join the cluster in R/O mode.");
+  }
+}
+
+void log_used_gr_options(const Group_replication_options &gr_options) {
+  if (gr_options.local_address.has_value() &&
+      !gr_options.local_address->empty()) {
+    log_info("Using Group Replication local address: %s",
+             gr_options.local_address->c_str());
+  }
+
+  if (gr_options.group_seeds.has_value() && !gr_options.group_seeds->empty()) {
+    log_info("Using Group Replication group seeds: %s",
+             gr_options.group_seeds->c_str());
+  }
+
+  if (gr_options.exit_state_action.has_value() &&
+      !gr_options.exit_state_action->empty()) {
+    log_info("Using Group Replication exit state action: %s",
+             gr_options.exit_state_action->c_str());
+  }
+
+  if (gr_options.member_weight.has_value()) {
+    log_info("Using Group Replication member weight: %s",
+             std::to_string(*gr_options.member_weight).c_str());
+  }
+
+  if (gr_options.consistency.has_value() && !gr_options.consistency->empty()) {
+    log_info("Using Group Replication failover consistency: %s",
+             gr_options.consistency->c_str());
+  }
+
+  if (gr_options.expel_timeout.has_value()) {
+    log_info("Using Group Replication expel timeout: %s",
+             std::to_string(*gr_options.expel_timeout).c_str());
+  }
+
+  if (gr_options.auto_rejoin_tries.has_value()) {
+    log_info("Using Group Replication auto-rejoin tries: %s",
+             std::to_string(*gr_options.auto_rejoin_tries).c_str());
+  }
+}
+
+void validate_local_address_ip_compatibility(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+    const std::string &local_address, const std::string &group_seeds,
+    mysqlshdk::utils::Version lowest_cluster_version) {
+  // local_address must have some value
+  assert(!local_address.empty());
+
+  // Validate that the group_replication_local_address is valid for the version
+  // of the target instance.
+  if (!mysqlshdk::gr::is_endpoint_supported_by_gr(
+          local_address, target_instance->get_version())) {
+    auto console = mysqlsh::current_console();
+    console->print_error("Cannot join instance '" + target_instance->descr() +
+                         "' to cluster: unsupported localAddress value.");
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Cannot use value '%s' for option localAddress because it has "
+        "an IPv6 address which is only supported by Group Replication "
+        "from MySQL version >= 8.0.14 and the target instance version is %s.",
+        local_address.c_str(),
+        target_instance->get_version().get_base().c_str()));
+  }
+
+  // Validate that the localAddress values of the cluster members are
+  // compatible with the target instance we are adding
+  auto local_address_list = shcore::str_split(group_seeds, ",");
+  std::vector<std::string> unsupported_addresses;
+  for (const auto &raw_local_addr : local_address_list) {
+    std::string local_addr = shcore::str_strip(raw_local_addr);
+    if (!mysqlshdk::gr::is_endpoint_supported_by_gr(
+            local_addr, target_instance->get_version())) {
+      unsupported_addresses.push_back(local_addr);
+    }
+  }
+  if (!unsupported_addresses.empty()) {
+    std::string value_str =
+        (unsupported_addresses.size() == 1) ? "value" : "values";
+
+    auto console = mysqlsh::current_console();
+    console->print_error(
+        "Cannot join instance '" + target_instance->descr() +
+        "' to cluster: unsupported localAddress value on the cluster.");
+    throw shcore::Exception::runtime_error(shcore::str_format(
+        "Instance does not support the following localAddress %s of the "
+        "cluster: '%s'. IPv6 "
+        "addresses/hostnames are only supported by Group "
+        "Replication from MySQL version >= 8.0.14 and the target instance "
+        "version is %s.",
+        value_str.c_str(),
+        shcore::str_join(unsupported_addresses.cbegin(),
+                         unsupported_addresses.cend(), ", ")
+            .c_str(),
+        target_instance->get_version().get_base().c_str()));
+  }
+
+  // validate that the value of the localAddress is supported by all
+  // existing cluster members
+  if (!mysqlshdk::gr::is_endpoint_supported_by_gr(local_address,
+                                                  lowest_cluster_version)) {
+    auto console = mysqlsh::current_console();
+    console->print_error(
+        "Cannot join instance '" + target_instance->descr() +
+        "' to cluster: localAddress value not supported by the cluster.");
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Cannot use value '%s' for option localAddress because it has "
+        "an IPv6 address which is only supported by Group Replication "
+        "from MySQL version >= 8.0.14 but the cluster "
+        "contains at least one member with version %s.",
+        local_address.c_str(), lowest_cluster_version.get_base().c_str()));
+  }
+}
+}  // namespace cluster_topology_executor_ops
+
 }  // namespace dba
 }  // namespace mysqlsh
