@@ -28,12 +28,15 @@
 #include <locale>
 #include <map>
 #include <memory>
+#include <optional>
 #include <set>
 #include <string>
 #include <utility>
 #include <vector>
 
+#include "modules/adminapi/common/clone_options.h"
 #include "modules/adminapi/common/cluster_types.h"
+
 #include "modules/adminapi/common/metadata_management_mysql.h"
 #include "modules/mod_utils.h"
 #include "mysqlshdk/libs/config/config.h"
@@ -56,6 +59,8 @@ namespace dba {
 
 class Instance;
 
+struct Group_replication_options;
+
 struct NewInstanceInfo {
   std::string member_id;
   std::string host;
@@ -160,9 +165,9 @@ class cancel_sync : public std::exception {};
 class MetadataStorage;
 
 // Maximum Cluster Name length
-constexpr const int k_cluster_name_max_length = 63;
+inline constexpr const int k_cluster_name_max_length = 63;
 
-constexpr const char k_cluster_name_allowed_chars[] =
+inline constexpr const char k_cluster_name_allowed_chars[] =
     "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_.-";
 
 void SHCORE_PUBLIC parse_fully_qualified_cluster_name(
@@ -174,95 +179,101 @@ void SHCORE_PUBLIC validate_cluster_name(const std::string &name,
 void SHCORE_PUBLIC validate_label(const std::string &lavel);
 
 // Default names
-constexpr const char k_default_domain_partition_name[] = "default";
-constexpr const char k_default_domain_name[] = "mydb";
-constexpr const char *k_replicaset_channel_name = "";
-constexpr const char *k_clusterset_async_channel_name =
+inline constexpr const char k_default_domain_partition_name[] = "default";
+inline constexpr const char k_default_domain_name[] = "mydb";
+inline constexpr const char *k_replicaset_channel_name = "";
+inline constexpr const char *k_clusterset_async_channel_name =
     "clusterset_replication";
 
 // TODO(alfredo) - all server configuration constants and general functions
 // should be moved to repl_config.h
 
 // common keys for group replication and clone configuration options
-constexpr const char kExitStateAction[] = "exitStateAction";
-constexpr const char kGrExitStateAction[] =
+inline constexpr const char kExitStateAction[] = "exitStateAction";
+inline constexpr const char kGrExitStateAction[] =
     "group_replication_exit_state_action";
-constexpr const char kGroupSeeds[] = "groupSeeds";
-constexpr const char kGrGroupSeeds[] = "group_replication_group_seeds";
-constexpr const char kIpWhitelist[] = "ipWhitelist";
-constexpr const char kIpAllowlist[] = "ipAllowlist";
-constexpr const char kGrIpWhitelist[] = "group_replication_ip_whitelist";
-constexpr const char kGrIpAllowlist[] = "group_replication_ip_allowlist";
-constexpr const char kLocalAddress[] = "localAddress";
-constexpr const char kGrLocalAddress[] = "group_replication_local_address";
-constexpr const char kMemberWeight[] = "memberWeight";
-constexpr const char kGrMemberWeight[] = "group_replication_member_weight";
-constexpr const char kExpelTimeout[] = "expelTimeout";
-constexpr const char kGrExpelTimeout[] =
+inline constexpr const char kGroupSeeds[] = "groupSeeds";
+inline constexpr const char kGrGroupSeeds[] = "group_replication_group_seeds";
+inline constexpr const char kIpWhitelist[] = "ipWhitelist";
+inline constexpr const char kIpAllowlist[] = "ipAllowlist";
+inline constexpr const char kGrIpWhitelist[] = "group_replication_ip_whitelist";
+inline constexpr const char kGrIpAllowlist[] = "group_replication_ip_allowlist";
+inline constexpr const char kLocalAddress[] = "localAddress";
+inline constexpr const char kGrLocalAddress[] =
+    "group_replication_local_address";
+inline constexpr const char kMemberWeight[] = "memberWeight";
+inline constexpr const char kGrMemberWeight[] =
+    "group_replication_member_weight";
+inline constexpr const char kExpelTimeout[] = "expelTimeout";
+inline constexpr const char kGrExpelTimeout[] =
     "group_replication_member_expel_timeout";
-constexpr const char kFailoverConsistency[] = "failoverConsistency";
-constexpr const char kGrFailoverConsistency[] = "group_replication_consistency";
-constexpr const char kConsistency[] = "consistency";
-constexpr const char kGrConsistency[] = "group_replication_consistency";
-constexpr const char kGroupName[] = "groupName";
-constexpr const char kGrGroupName[] = "group_replication_group_name";
-constexpr const char kMemberSslMode[] = "memberSslMode";
-constexpr const char kGrMemberSslMode[] = "group_replication_ssl_mode";
-constexpr const char kClusterName[] = "clusterName";
-constexpr const char kAutoRejoinTries[] = "autoRejoinTries";
-constexpr const char kGrAutoRejoinTries[] =
+inline constexpr const char kFailoverConsistency[] = "failoverConsistency";
+inline constexpr const char kGrFailoverConsistency[] =
+    "group_replication_consistency";
+inline constexpr const char kConsistency[] = "consistency";
+inline constexpr const char kGrConsistency[] = "group_replication_consistency";
+inline constexpr const char kGroupName[] = "groupName";
+inline constexpr const char kGrGroupName[] = "group_replication_group_name";
+inline constexpr const char kMemberSslMode[] = "memberSslMode";
+inline constexpr const char kGrMemberSslMode[] = "group_replication_ssl_mode";
+inline constexpr const char kClusterName[] = "clusterName";
+inline constexpr const char kAutoRejoinTries[] = "autoRejoinTries";
+inline constexpr const char kGrAutoRejoinTries[] =
     "group_replication_autorejoin_tries";
-constexpr const char kManualStartOnBoot[] = "manualStartOnBoot";
-constexpr const char kDisableClone[] = "disableClone";
-constexpr const char kTags[] = "tags";
-constexpr const char kGtidSetIsComplete[] = "gtidSetIsComplete";
-constexpr const char kAdoptFromAR[] = "adoptFromAR";
-constexpr const char kDryRun[] = "dryRun";
-constexpr const char kInstanceLabel[] = "instanceLabel";
-constexpr const char kSandboxDir[] = "sandboxDir";
-constexpr const char kPortX[] = "portx";
-constexpr const char kAllowRootFrom[] = "allowRootFrom";
-constexpr const char kIgnoreSslError[] = "ignoreSslError";
-constexpr const char kMysqldOptions[] = "mysqldOptions";
-constexpr const char kMyCnfPath[] = "mycnfPath";
-constexpr const char kVerifyMyCnf[] = "verifyMyCnf";
-constexpr const char kOutputMycnfPath[] = "outputMycnfPath";
-constexpr const char kInteractive[] = "interactive";
-constexpr const char kClusterAdmin[] = "clusterAdmin";
-constexpr const char kClusterAdminPassword[] = "clusterAdminPassword";
-constexpr const char kRestart[] = "restart";
-constexpr const char kClearReadOnly[] = "clearReadOnly";
-constexpr const char kApplierWorkerThreads[] = "applierWorkerThreads";
-constexpr const char kMultiPrimary[] = "multiPrimary";
-constexpr const char kMultiMaster[] = "multiMaster";
-constexpr const char kForce[] = "force";
-constexpr const char kAdoptFromGR[] = "adoptFromGR";
-constexpr const char kAddInstances[] = "addInstances";
-constexpr const char kRemoveInstances[] = "removeInstances";
-constexpr const char kRejoinInstances[] = "rejoinInstances";
-constexpr const char kWaitRecovery[] = "waitRecovery";
-constexpr const char kRecoveryVerbosity[] = "recoveryProgress";
-constexpr const char kLabel[] = "label";
-constexpr const char kExtended[] = "extended";
-constexpr const char kQueryMembers[] = "queryMembers";
-constexpr const char kOnlyUpgradeRequired[] = "onlyUpgradeRequired";
-constexpr const char kUpdate[] = "update";
-constexpr const char kUpdateTopologyMode[] = "updateTopologyMode";
-constexpr const char kUpgradeCommProtocol[] = "upgradeCommProtocol";
-constexpr const char kUpdateViewChangeUuid[] = "updateViewChangeUuid";
-constexpr const char kAll[] = "all";
-constexpr const char kTimeout[] = "timeout";
-constexpr const char kInvalidateErrorInstances[] = "invalidateErrorInstances";
-constexpr const char kClusterSetReplicationSslMode[] =
+inline constexpr const char kManualStartOnBoot[] = "manualStartOnBoot";
+inline constexpr const char kDisableClone[] = "disableClone";
+inline constexpr const char kTags[] = "tags";
+inline constexpr const char kGtidSetIsComplete[] = "gtidSetIsComplete";
+inline constexpr const char kAdoptFromAR[] = "adoptFromAR";
+inline constexpr const char kDryRun[] = "dryRun";
+inline constexpr const char kInstanceLabel[] = "instanceLabel";
+inline constexpr const char kSandboxDir[] = "sandboxDir";
+inline constexpr const char kPortX[] = "portx";
+inline constexpr const char kAllowRootFrom[] = "allowRootFrom";
+inline constexpr const char kIgnoreSslError[] = "ignoreSslError";
+inline constexpr const char kMysqldOptions[] = "mysqldOptions";
+inline constexpr const char kMyCnfPath[] = "mycnfPath";
+inline constexpr const char kVerifyMyCnf[] = "verifyMyCnf";
+inline constexpr const char kOutputMycnfPath[] = "outputMycnfPath";
+inline constexpr const char kInteractive[] = "interactive";
+inline constexpr const char kClusterAdmin[] = "clusterAdmin";
+inline constexpr const char kClusterAdminPassword[] = "clusterAdminPassword";
+inline constexpr const char kRestart[] = "restart";
+inline constexpr const char kClearReadOnly[] = "clearReadOnly";
+inline constexpr const char kApplierWorkerThreads[] = "applierWorkerThreads";
+inline constexpr const char kMultiPrimary[] = "multiPrimary";
+inline constexpr const char kMultiMaster[] = "multiMaster";
+inline constexpr const char kForce[] = "force";
+inline constexpr const char kAdoptFromGR[] = "adoptFromGR";
+inline constexpr const char kAddInstances[] = "addInstances";
+inline constexpr const char kRemoveInstances[] = "removeInstances";
+inline constexpr const char kRejoinInstances[] = "rejoinInstances";
+inline constexpr const char kWaitRecovery[] = "waitRecovery";
+inline constexpr const char kRecoveryVerbosity[] = "recoveryProgress";
+inline constexpr const char kLabel[] = "label";
+inline constexpr const char kExtended[] = "extended";
+inline constexpr const char kQueryMembers[] = "queryMembers";
+inline constexpr const char kOnlyUpgradeRequired[] = "onlyUpgradeRequired";
+inline constexpr const char kUpdate[] = "update";
+inline constexpr const char kUpdateTopologyMode[] = "updateTopologyMode";
+inline constexpr const char kUpgradeCommProtocol[] = "upgradeCommProtocol";
+inline constexpr const char kUpdateViewChangeUuid[] = "updateViewChangeUuid";
+inline constexpr const char kAll[] = "all";
+inline constexpr const char kTimeout[] = "timeout";
+inline constexpr const char kInvalidateErrorInstances[] =
+    "invalidateErrorInstances";
+inline constexpr const char kClusterSetReplicationSslMode[] =
     "clusterSetReplicationSslMode";
-constexpr const char kReplicationAllowedHost[] = "replicationAllowedHost";
-constexpr const char kCommunicationStack[] = "communicationStack";
-constexpr const char kSwitchCommunicationStack[] = "switchCommunicationStack";
-constexpr const char kTransactionSizeLimit[] = "transactionSizeLimit";
-constexpr const char kGrTransactionSizeLimit[] =
+inline constexpr const char kReplicationAllowedHost[] =
+    "replicationAllowedHost";
+inline constexpr const char kCommunicationStack[] = "communicationStack";
+inline constexpr const char kSwitchCommunicationStack[] =
+    "switchCommunicationStack";
+inline constexpr const char kTransactionSizeLimit[] = "transactionSizeLimit";
+inline constexpr const char kGrTransactionSizeLimit[] =
     "group_replication_transaction_size_limit";
 
-constexpr const int k_group_replication_members_limit = 9;
+inline constexpr const int k_group_replication_members_limit = 9;
 
 // Group Replication configuration option availability regarding MySQL Server
 // version
@@ -276,28 +287,17 @@ struct Option_availability {
  * Map of the global Cluster configuration options of the AdminAPI
  * <sysvar, name>
  */
-const std::map<std::string, std::string> k_global_cluster_options{
+inline const std::map<std::string, std::string> k_global_cluster_options{
     {kGroupName, kGrGroupName},
     {kMemberSslMode, kGrMemberSslMode},
     {kTransactionSizeLimit, kGrTransactionSizeLimit}};
 
-/**
- * Map of the instance configuration options of the AdminAPI
- * <sysvar, name>
- */
-const std::map<std::string, std::string> k_instance_options{
-    {kExitStateAction, kGrExitStateAction}, {kGroupSeeds, kGrGroupSeeds},
-    {kIpWhitelist, kGrIpWhitelist},         {kIpAllowlist, kGrIpAllowlist},
-    {kLocalAddress, kGrLocalAddress},       {kMemberWeight, kGrMemberWeight},
-    {kExpelTimeout, kGrExpelTimeout},       {kConsistency, kGrConsistency},
-    {kAutoRejoinTries, kGrAutoRejoinTries}};
-
 /**
  * Map of the supported global cluster configuration options in the
  * AdminAPI <sysvar, name>
  */
 // TODO(.) This and its dependencies must be moved out to a new user_options.h
-const std::map<std::string, Option_availability>
+inline const std::map<std::string, Option_availability>
     k_global_cluster_supported_options{
         {kExitStateAction,
          {kGrExitStateAction, mysqlshdk::utils::Version("8.0.12"),
@@ -313,32 +313,12 @@ const std::map<std::string, Option_availability>
          {kGrConsistency, mysqlshdk::utils::Version("8.0.14"), {}}},
         {kAutoRejoinTries,
          {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16"), {}}},
-        {kTransactionSizeLimit, {kGrTransactionSizeLimit, {}, {}}}};
+        {kTransactionSizeLimit, {kGrTransactionSizeLimit, {}, {}}},
+        {kIpAllowlist,
+         {kGrIpAllowlist, mysqlshdk::utils::Version("8.0.24"), {}}}};
 
-/**
- * List with the supported build-in tags for setOption and setInstanceOption
- */
-typedef std::map<std::string, shcore::Value_type> built_in_tags_map_t;
-const built_in_tags_map_t k_supported_set_option_tags{
-    {"_hidden", shcore::Value_type::Bool},
-    {"_disconnect_existing_sessions_when_hidden", shcore::Value_type::Bool}};
-
-/**
- * Map of the supported instance configuration options in the AdminAPI
- * <sysvar, name>
- */
-const std::map<std::string, Option_availability> k_instance_supported_options{
-    {kExitStateAction,
-     {kGrExitStateAction, mysqlshdk::utils::Version("8.0.12"),
-      mysqlshdk::utils::Version("5.7.24")}},
-    {kMemberWeight,
-     {kGrMemberWeight, mysqlshdk::utils::Version("8.0.11"),
-      mysqlshdk::utils::Version("5.7.20")}},
-    {kAutoRejoinTries,
-     {kGrAutoRejoinTries, mysqlshdk::utils::Version("8.0.16"), {}}}};
-
-const mysqlshdk::utils::Version k_mysql_communication_stack_initial_version(
-    "8.0.27");
+inline const mysqlshdk::utils::Version
+    k_mysql_communication_stack_initial_version("8.0.27");
 
 struct Instance_definition {
   int host_id;
@@ -444,13 +424,19 @@ bool is_option_supported(
 void validate_replication_filters(const mysqlshdk::mysql::IInstance &instance,
                                   Cluster_type cluster_type);
 
-mysqlshdk::db::nullable<Cluster_ssl_mode> resolve_ssl_mode(
-    const mysqlshdk::mysql::IInstance &instance,
-    const Cluster_ssl_mode &ssl_mode, bool *have_ssl);
+void resolve_ssl_mode_option(const std::string &option,
+                             const std::string &context,
+                             const mysqlshdk::mysql::IInstance &instance,
+                             Cluster_ssl_mode *ssl_mode);
 
-void resolve_instance_ssl_mode(const mysqlshdk::mysql::IInstance &instance,
-                               const mysqlshdk::mysql::IInstance &pinstance,
-                               Cluster_ssl_mode *member_ssl_mode);
+void resolve_instance_ssl_mode_option(
+    const mysqlshdk::mysql::IInstance &instance,
+    const mysqlshdk::mysql::IInstance &pinstance,
+    Cluster_ssl_mode *member_ssl_mode);
+
+void validate_instance_ssl_mode(Cluster_type type,
+                                const mysqlshdk::mysql::IInstance &instance,
+                                Cluster_ssl_mode ssl_mode);
 
 std::vector<NewInstanceInfo> get_newly_discovered_instances(
     const mysqlshdk::mysql::IInstance &group_server,
@@ -566,8 +552,8 @@ void add_config_file_handler(mysqlshdk::config::Config *cfg,
  * if it is already being used.
  */
 std::string resolve_gr_local_address(
-    const mysqlshdk::null_string &local_address,
-    const mysqlshdk::null_string &communication_stack,
+    const std::optional<std::string> &local_address,
+    const std::optional<std::string> &communication_stack,
     const std::string &report_host, int port, bool check_if_busy,
     bool quiet = false);
 
@@ -639,6 +625,28 @@ bool wait_for_gtid_set_safe(const mysqlshdk::mysql::IInstance &target_instance,
                             const std::string &channel_name, int timeout,
                             bool cancelable = false);
 
+/*
+ * Synchronize transactions on target instance.
+ *
+ * Wait for gtid_set to be applied on the specified target instance. Function
+ * will monitor for replication errors on the named channel and throw an
+ * exception if an error is detected.
+ *
+ * @param target_instance instance to wait for transaction to be applied.
+ * @param gtid_set the transaction set to wait for
+ * @param channel_name the name of the channel to monitor
+ * @param timeout number of seconds to wait
+ * @param cancelable boolean to indicate if the operation is cancelable with
+ * SIGINT or not
+ *
+ * @throw RuntimeError if the timeout is reached when waiting for
+ * transactions to be applied or replication errors are detected.
+ */
+void wait_for_apply_retrieved_trx(
+    const mysqlshdk::mysql::IInstance &target_instance,
+    const std::string &channel_name, std::chrono::seconds timeout,
+    bool silent = true);
+
 void execute_script(const std::shared_ptr<Instance> &group_server,
                     const std::string &script, const std::string &context);
 
@@ -695,6 +703,49 @@ Cluster_check_info get_cluster_check_info(const MetadataStorage &metadata,
                                           Instance *group_server = nullptr,
                                           bool skip_version_check = true);
 
+namespace cluster_topology_executor_ops {
+/**
+ * Validate the options used in addInstance() and rejoinInstance()
+ *
+ * The function validates if the options used in
+ * addInstance()/rejoinInstance() are accepted according to the communication
+ * stack in use by the Cluster
+ */
+void validate_add_rejoin_options(Group_replication_options options,
+                                 const std::string &communication_stack);
+
+bool is_member_auto_rejoining(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance);
+
+void ensure_not_auto_rejoining(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance);
+
+/**
+ * Check if the target instance supported the communication protocol in used
+ * by the Cluster
+ */
+void check_comm_stack_support(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+    Group_replication_options *gr_options,
+    const std::string &communication_stack);
+
+void ensure_instance_check_installed_schema_version(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+    mysqlshdk::utils::Version lowest_cluster_version);
+
+void log_used_gr_options(const Group_replication_options &gr_options);
+
+/**
+ * Validate the use of IPv6 addresses on the localAddress of the
+ * target instance and check if the target instance supports usage of
+ * IPv6 on the localAddress values being used on the cluster instances.
+ */
+void validate_local_address_ip_compatibility(
+    const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
+    const std::string &local_address, const std::string &group_seeds,
+    mysqlshdk::utils::Version lowest_cluster_version);
+}  // namespace cluster_topology_executor_ops
+
 }  // namespace dba
 }  // namespace mysqlsh
 
