@@ -28,7 +28,6 @@
 #include "modules/adminapi/cluster_set/cluster_set_impl.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/dba_errors.h"
-#include "modules/adminapi/common/global_topology_check.h"
 #include "modules/adminapi/common/instance_pool.h"
 #include "modules/adminapi/common/sql.h"
 #include "mysqlshdk/include/shellcore/scoped_contexts.h"
@@ -195,8 +194,12 @@ const std::map<std::string, Function_availability>
          {k_min_adminapi_server_version,
           TargetType::StandaloneWithMetadata |
               TargetType::StandaloneInMetadata | TargetType::InnoDBCluster |
-              TargetType::AsyncReplicaSet,
-          ReplicationQuorum::State(ReplicationQuorum::States::Normal)}},
+              TargetType::InnoDBClusterSet | TargetType::AsyncReplicaSet,
+          ReplicationQuorum::State(ReplicationQuorum::States::Normal),
+          {},
+          k_primary_required,
+          kClusterGlobalStateAny,
+          true}},
         {"Dba.rebootClusterFromCompleteOutage",
          {k_min_gr_version,
           TargetType::StandaloneInMetadata | TargetType::InnoDBCluster |
@@ -344,9 +347,12 @@ const std::map<std::string, Function_availability>
           true}},
         {"Cluster.dissolve",
          {k_min_gr_version,
-          TargetType::InnoDBCluster,
+          TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
           ReplicationQuorum::State(ReplicationQuorum::States::Normal),
-          {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}}}},
+          {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}},
+          k_primary_required,
+          kClusterGlobalStateAny,
+          true}},
         {"Cluster.checkInstanceState",
          {k_min_gr_version,
           TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
@@ -733,6 +739,13 @@ std::string describe(State state) {
 }
 }  // namespace ManagedInstance
 
+const Function_availability &Precondition_checker::get_function_preconditions(
+    const std::string &function_name) {
+  assert(s_preconditions.find(function_name) != s_preconditions.end());
+
+  return s_preconditions.at(function_name);
+}
+
 Precondition_checker::Precondition_checker(
     const std::shared_ptr<MetadataStorage> &metadata,
     const std::shared_ptr<Instance> &group_server, bool primary_available)
@@ -748,8 +761,7 @@ Cluster_check_info Precondition_checker::check_preconditions(
   // function name
   if (!custom_func_avail) {
     // Retrieves the availability configuration for the given function
-    assert(s_preconditions.find(function_name) != s_preconditions.end());
-    availability = s_preconditions.at(function_name);
+    availability = get_function_preconditions(function_name);
   } else {
     // If a function availability is provided use it
     availability = *custom_func_avail;
@@ -1155,7 +1167,7 @@ MDS Precondition_checker::check_metadata_state_actions(
             } else if (item.action == MDS_actions::RAISE_ERROR) {
               throw std::runtime_error(shcore::str_subvars(
                   pre_formatted,
-                  [](const std::string &var) {
+                  [](std::string_view var) {
                     return shcore::get_member_name(
                         var, shcore::current_naming_style());
                   },
