@@ -283,6 +283,8 @@ const shcore::Option_pack_def<Reboot_cluster_options>
           .optional(kSwitchCommunicationStack,
                     &Reboot_cluster_options::set_switch_communication_stack, "",
                     shcore::Option_extract_mode::CASE_INSENSITIVE)
+          .optional(kTimeout, &Reboot_cluster_options::set_timeout, "",
+                    shcore::Option_extract_mode::CASE_INSENSITIVE)
           .include(&Reboot_cluster_options::gr_options);
 
   return opts;
@@ -303,22 +305,22 @@ void Reboot_cluster_options::check_option_values(
   // Using switchCommunicationStack set to 'mysql' and ipAllowlist at the same
   // time is forbidden
   if (switch_communication_stack.value_or("") == kCommunicationStackMySQL &&
-      !gr_options.ip_allowlist.is_null()) {
+      gr_options.ip_allowlist.has_value()) {
     throw shcore::Exception::argument_error(shcore::str_format(
         "Cannot use '%s' when setting the '%s' option to '%s'", kIpAllowlist,
         kSwitchCommunicationStack, kCommunicationStackMySQL));
   }
 
   if (!switch_communication_stack && comm_stack == kCommunicationStackMySQL &&
-      !gr_options.ip_allowlist.is_null()) {
+      gr_options.ip_allowlist.has_value()) {
     throw shcore::Exception::argument_error(shcore::str_format(
         "Cannot use '%s' when the Cluster's communication stack is '%s'",
         gr_options.ip_allowlist_option_name.c_str(), kCommunicationStackMySQL));
   }
 
   // Validate the usage of the localAddress option
-  if (!gr_options.local_address.is_null()) {
-    validate_local_address_option(gr_options.local_address.get_safe(),
+  if (gr_options.local_address.has_value()) {
+    validate_local_address_option(gr_options.local_address.value_or(""),
                                   switch_communication_stack.value_or(""),
                                   canonical_port);
   }
@@ -373,6 +375,15 @@ void Reboot_cluster_options::set_switch_communication_stack(
   }
 }
 
+void Reboot_cluster_options::set_timeout(uint32_t timeout_seconds) {
+  timeout = std::chrono::seconds{timeout_seconds};
+}
+
+std::chrono::seconds Reboot_cluster_options::get_timeout() const {
+  return timeout.value_or(std::chrono::seconds{
+      current_shell_options()->get().dba_gtid_wait_timeout});
+}
+
 const shcore::Option_pack_def<Upgrade_metadata_options>
     &Upgrade_metadata_options::options() {
   static const auto opts =
