@@ -58,14 +58,18 @@ Create_cluster::Create_cluster(const std::shared_ptr<Instance> &target_instance,
                                const Create_cluster_options &options)
     : m_target_instance(target_instance),
       m_cluster_name(cluster_name),
-      m_options(options) {}
+      m_options(options) {
+  if (!options.adopt_from_gr) m_primary_master = target_instance;
+}
 
 Create_cluster::Create_cluster(const std::shared_ptr<MetadataStorage> &metadata,
                                const std::shared_ptr<Instance> &target_instance,
+                               const std::shared_ptr<Instance> &primary_master,
                                const std::string &cluster_name,
                                const Create_cluster_options &options)
     : m_metadata(metadata),
       m_target_instance(target_instance),
+      m_primary_master(primary_master),
       m_cluster_name(cluster_name),
       m_options(options) {}
 
@@ -74,12 +78,11 @@ Create_cluster::~Create_cluster() = default;
 void Create_cluster::validate_create_cluster_options() {
   auto console = mysqlsh::current_console();
 
-  if (!m_options.gr_options.auto_rejoin_tries.is_null() &&
+  if (m_options.gr_options.auto_rejoin_tries.has_value() &&
       *m_options.gr_options.auto_rejoin_tries != 0) {
-    std::string warn_msg =
+    console->print_warning(
         "The member will only proceed according to its exitStateAction if "
-        "auto-rejoin fails (i.e. all retry attempts are exhausted).";
-    console->print_warning(warn_msg);
+        "auto-rejoin fails (i.e. all retry attempts are exhausted).");
     console->print_info();
   }
 
@@ -87,7 +90,7 @@ void Create_cluster::validate_create_cluster_options() {
   TargetType::Type instance_type = get_gr_instance_type(*m_target_instance);
 
   if (instance_type == mysqlsh::dba::TargetType::GroupReplication) {
-    if (!m_options.adopt_from_gr && m_options.interactive()) {
+    if (!m_options.adopt_from_gr.has_value() && m_options.interactive()) {
       if (console->confirm(
               "You are connected to an instance that belongs to an unmanaged "
               "replication group.\nDo you want to setup an InnoDB Cluster "
@@ -126,17 +129,17 @@ void Create_cluster::validate_create_cluster_options() {
 
   // Using communicationStack and adoptFromGR and/or ipAllowlist/ipWhitelist at
   // the same time is forbidden
-  if (m_options.adopt_from_gr &&
-      !m_options.gr_options.communication_stack.is_null()) {
+  if (m_options.adopt_from_gr.value_or(false) &&
+      m_options.gr_options.communication_stack.has_value()) {
     throw shcore::Exception::argument_error(
         shcore::str_format("Cannot use the '%s' option if '%s' is set "
                            "to true.",
                            kCommunicationStack, kAdoptFromGR));
   }
 
-  if (m_options.gr_options.communication_stack.get_safe() ==
+  if (m_options.gr_options.communication_stack.value_or("") ==
           kCommunicationStackMySQL &&
-      !m_options.gr_options.ip_allowlist.is_null()) {
+      m_options.gr_options.ip_allowlist.has_value()) {
     throw shcore::Exception::argument_error(shcore::str_format(
         "Cannot use '%s' when setting the '%s' option to '%s'",
         m_options.gr_options.ip_allowlist_option_name.c_str(),
@@ -185,49 +188,8 @@ void Create_cluster::validate_create_cluster_options() {
  * instance).
  */
 void Create_cluster::resolve_ssl_mode() {
-  bool have_ssl;
-  bool require_secure_transport =
-      m_target_instance->get_sysvar_bool("require_secure_transport").get_safe();
-
-  auto resolved_ssl_mode = mysqlsh::dba::resolve_ssl_mode(
-      *m_target_instance, m_options.gr_options.ssl_mode, &have_ssl);
-
-  if (resolved_ssl_mode.is_null()) {
-    throw std::logic_error("Unable to resolve SSL mode");
-  }
-
-  if (have_ssl) {
-    // sslMode is DISABLED but instance requires SSL
-    if (m_options.gr_options.ssl_mode == Cluster_ssl_mode::DISABLED &&
-        require_secure_transport) {
-      throw shcore::Exception::argument_error(
-          "The instance '" + m_target_instance->descr() +
-          "' requires secure connections, to create the "
-          "cluster either turn off require_secure_transport or use the "
-          "memberSslMode option with 'REQUIRED', 'VERIFY_CA' or "
-          "'VERIFY_IDENTITY' value.");
-    }
-
-    // sslMode is VERIFY_CA or VERIFY_IDENTITY, verify the certificates
-    if (m_options.gr_options.ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
-        m_options.gr_options.ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
-      ensure_certificates_set(*m_target_instance,
-                              m_options.gr_options.ssl_mode);
-    }
-  } else {  // The instance does not support SSL
-    // sslMode is REQUIRED, VERIFY_CA or VERIFY_IDENTITY
-    if (m_options.gr_options.ssl_mode == Cluster_ssl_mode::REQUIRED ||
-        m_options.gr_options.ssl_mode == Cluster_ssl_mode::VERIFY_CA ||
-        m_options.gr_options.ssl_mode == Cluster_ssl_mode::VERIFY_IDENTITY) {
-      throw shcore::Exception::argument_error(
-          "The instance '" + m_target_instance->descr() +
-          "' does not have SSL enabled, to create the "
-          "cluster either use an instance with SSL enabled, remove the "
-          "memberSslMode option or use it with any of 'AUTO' or 'DISABLED'.");
-    }
-  }
-
-  m_options.gr_options.ssl_mode = resolved_ssl_mode.get_safe();
+  resolve_ssl_mode_option("memberSslMode", "Cluster", *m_target_instance,
+                          &m_options.gr_options.ssl_mode);
 
   log_info("SSL mode used to configure the cluster: '%s'",
            to_string(m_options.gr_options.ssl_mode).c_str());
@@ -275,15 +237,15 @@ void Create_cluster::prepare() {
   // instance is running 8.0.27+
   // NOTE: When adoptFromGR is used, we don't set the communication stack since
   // the one in use by the unmanaged GR group must be kept
-  if (m_options.gr_options.communication_stack.is_null() &&
-      !m_options.adopt_from_gr &&
+  if (!m_options.gr_options.communication_stack.has_value() &&
+      !m_options.adopt_from_gr.has_value() &&
       m_target_instance->get_version() >=
           k_mysql_communication_stack_initial_version) {
     m_options.gr_options.communication_stack = kCommunicationStackMySQL;
 
     // Verify if the allowlist is used when the communication stack is MySQL by
     // default
-    if (!m_options.gr_options.ip_allowlist.is_null()) {
+    if (m_options.gr_options.ip_allowlist.has_value()) {
       throw shcore::Exception::argument_error(shcore::str_format(
           "Cannot use '%s' when the '%s' is '%s'",
           m_options.gr_options.ip_allowlist_option_name.c_str(),
@@ -291,10 +253,10 @@ void Create_cluster::prepare() {
     }
 
     // Validate localAddress if the communication stack is MySQL by default
-    if (!m_options.gr_options.local_address.is_null()) {
+    if (m_options.gr_options.local_address.has_value()) {
       validate_local_address_option(
           *m_options.gr_options.local_address,
-          m_options.gr_options.communication_stack.get_safe(),
+          m_options.gr_options.communication_stack.value_or(""),
           m_target_instance->get_canonical_port());
     }
   }
@@ -320,11 +282,12 @@ void Create_cluster::prepare() {
   // secondary will end up having super_read_only disabled.
   if (m_options.get_adopt_from_gr()) {
     m_target_instance = get_primary_member_from_group(m_target_instance);
+    m_primary_master = m_target_instance;
   }
 
   // Disable super_read_only mode if it is enabled.
   bool super_read_only =
-      m_target_instance->get_sysvar_bool("super_read_only").get_safe();
+      m_target_instance->get_sysvar_bool("super_read_only", false);
   if (super_read_only) {
     console->print_info("Disabling super_read_only mode on instance '" +
                         m_target_instance->descr() + "'.");
@@ -347,7 +310,7 @@ void Create_cluster::prepare() {
       // NOTE: In 8.0.16 the default value became READ_ONLY so we must not
       // change it
       auto instance_version = m_target_instance->get_version();
-      if (m_options.gr_options.exit_state_action.is_null() &&
+      if (!m_options.gr_options.exit_state_action.has_value() &&
           is_option_supported(instance_version, kExpelTimeout,
                               k_global_cluster_supported_options) &&
           instance_version < mysqlshdk::utils::Version("8.0.16")) {
@@ -387,7 +350,7 @@ void Create_cluster::prepare() {
       validate_local_address_ip_compatibility();
 
       // Generate the GR group name (if needed).
-      if (m_options.gr_options.group_name.is_null()) {
+      if (!m_options.gr_options.group_name.has_value()) {
         m_options.gr_options.group_name =
             mysqlshdk::gr::generate_uuid(*m_target_instance);
       }
@@ -452,52 +415,52 @@ void Create_cluster::log_used_gr_options() {
              to_string(m_options.gr_options.ssl_mode).c_str());
   }
 
-  if (!m_options.gr_options.group_name.is_null()) {
+  if (m_options.gr_options.group_name.has_value()) {
     log_info("Using Group Replication group name: %s",
              m_options.gr_options.group_name->c_str());
   }
 
-  if (!m_options.gr_options.local_address.is_null()) {
+  if (m_options.gr_options.local_address.has_value()) {
     log_info("Using Group Replication local address: %s",
              m_options.gr_options.local_address->c_str());
   }
 
-  if (!m_options.gr_options.group_seeds.is_null()) {
+  if (m_options.gr_options.group_seeds.has_value()) {
     log_info("Using Group Replication group seeds: %s",
              m_options.gr_options.group_seeds->c_str());
   }
 
-  if (!m_options.gr_options.exit_state_action.is_null()) {
+  if (m_options.gr_options.exit_state_action.has_value()) {
     log_info("Using Group Replication exit state action: %s",
              m_options.gr_options.exit_state_action->c_str());
   }
 
-  if (!m_options.gr_options.member_weight.is_null()) {
+  if (m_options.gr_options.member_weight.has_value()) {
     log_info("Using Group Replication member weight: %s",
              std::to_string(*m_options.gr_options.member_weight).c_str());
   }
 
-  if (!m_options.gr_options.consistency.is_null()) {
+  if (m_options.gr_options.consistency.has_value()) {
     log_info("Using Group Replication failover consistency: %s",
              m_options.gr_options.consistency->c_str());
   }
 
-  if (!m_options.gr_options.expel_timeout.is_null()) {
+  if (m_options.gr_options.expel_timeout.has_value()) {
     log_info("Using Group Replication expel timeout: %s",
              std::to_string(*m_options.gr_options.expel_timeout).c_str());
   }
 
-  if (!m_options.gr_options.auto_rejoin_tries.is_null()) {
+  if (m_options.gr_options.auto_rejoin_tries.has_value()) {
     log_info("Using Group Replication auto-rejoin tries: %s",
              std::to_string(*m_options.gr_options.auto_rejoin_tries).c_str());
   }
 
-  if (!m_options.gr_options.communication_stack.is_null()) {
+  if (m_options.gr_options.communication_stack.has_value()) {
     log_info("Using Group Replication Communication Stack: %s",
              m_options.gr_options.communication_stack->c_str());
   }
 
-  if (!m_options.gr_options.transaction_size_limit.is_null()) {
+  if (m_options.gr_options.transaction_size_limit.has_value()) {
     log_info(
         "Using Group Replication transaction size limit: %s",
         std::to_string(*m_options.gr_options.transaction_size_limit).c_str());
@@ -518,8 +481,8 @@ void Create_cluster::prepare_metadata_schema() {
 }
 
 void Create_cluster::create_recovery_account(
-    mysqlshdk::mysql::IInstance *target, Cluster_impl *cluster,
-    std::string *out_username) {
+    mysqlshdk::mysql::IInstance *primary, mysqlshdk::mysql::IInstance *target,
+    Cluster_impl *cluster, std::string *out_username) {
   // Setup recovery account for this seed instance, which will be used
   // when/if it needs to rejoin.
   std::string repl_account_host;
@@ -546,7 +509,7 @@ void Create_cluster::create_recovery_account(
           "deleted and created again with a new password.",
           repl_account.user.c_str(), repl_account_host.c_str(),
           m_target_instance->descr().c_str()));
-      m_target_instance->drop_user(repl_account.user, repl_account_host);
+      primary->drop_user(repl_account.user, repl_account_host);
     }
 
     auto target_version = m_target_instance->get_version();
@@ -559,7 +522,7 @@ void Create_cluster::create_recovery_account(
         target_version >= k_mysql_communication_stack_initial_version;
 
     repl_account = mysqlshdk::gr::create_recovery_user(
-        repl_account.user, *m_target_instance, {repl_account_host}, {},
+        repl_account.user, *primary, {repl_account_host}, {},
         clone_available_on_target, false,
         mysql_communication_stack_available_on_target);
   }
@@ -626,7 +589,8 @@ void Create_cluster::reset_recovery_all(Cluster_impl *cluster) {
 
         std::string new_user;
 
-        create_recovery_account(target.get(), cluster, &new_user);
+        create_recovery_account(m_target_instance.get(), target.get(), cluster,
+                                &new_user);
         store_recovery_account_metadata(target.get(), *cluster);
 
         new_users.insert(new_user);
@@ -662,17 +626,17 @@ void Create_cluster::persist_sro_all(Cluster_impl *cluster) {
 
   auto config = cluster->create_config_object({}, false, true);
 
-  config->set("super_read_only", mysqlshdk::utils::nullable<bool>(true));
+  config->set("super_read_only", std::optional<bool>(true));
 
   config->apply();
 }
 
 void Create_cluster::validate_local_address_ip_compatibility() const {
   // local_address must have some value
-  assert(!m_options.gr_options.local_address.is_null() &&
-         !m_options.gr_options.local_address.get_safe().empty());
+  assert(m_options.gr_options.local_address.has_value() &&
+         !m_options.gr_options.local_address->empty());
 
-  std::string local_address = m_options.gr_options.local_address.get_safe();
+  std::string local_address = m_options.gr_options.local_address.value_or("");
 
   // Validate that the group_replication_local_address is valid for the version
   // of the target instance.
@@ -751,8 +715,7 @@ shcore::Value Create_cluster::execute() {
 
   // Get the current value of group_replication_transaction_size_limit
   int64_t original_transaction_size_limit =
-      m_target_instance->get_sysvar_int(kGrTransactionSizeLimit).get_safe();
-  ;
+      m_target_instance->get_sysvar_int(kGrTransactionSizeLimit).value_or(0);
 
   shcore::Scoped_callback_list undo_list;
 
@@ -783,7 +746,7 @@ shcore::Value Create_cluster::execute() {
       // When using the communicationStack 'MySQL' the recovery channel must be
       // set-up before starting GR because GR requires that the recovery channel
       // is configured in order to obtain the credentials information
-      if (m_options.gr_options.communication_stack.get_safe() ==
+      if (m_options.gr_options.communication_stack.value_or("") ==
           kCommunicationStackMySQL) {
         // Create the Recovery account and configure GR's recovery channel.
         // If creating a Replica Cluster, suppress the binary log otherwise
@@ -795,7 +758,7 @@ shcore::Value Create_cluster::execute() {
         // Check if super_read_only is enabled. If so it must be disabled to
         // create the account. This might happen if super_read_only is persisted
         // and we're creating a Replica Cluster
-        if (m_target_instance->get_sysvar_bool("super_read_only").get_safe()) {
+        if (m_target_instance->get_sysvar_bool("super_read_only", false)) {
           m_target_instance->set_sysvar("super_read_only", false);
         }
 
@@ -805,10 +768,12 @@ shcore::Value Create_cluster::execute() {
           mysqlshdk::mysql::Suppress_binary_log nobinlog(
               m_target_instance.get());
 
-          create_recovery_account(m_target_instance.get(), nullptr,
+          create_recovery_account(m_target_instance.get(),
+                                  m_target_instance.get(), nullptr,
                                   &repl_account);
         } else {
-          create_recovery_account(m_target_instance.get(), nullptr,
+          create_recovery_account(m_primary_master.get(),
+                                  m_target_instance.get(), nullptr,
                                   &repl_account);
         }
 
@@ -818,7 +783,7 @@ shcore::Value Create_cluster::execute() {
               m_options.replication_allowed_host.empty()
                   ? "%"
                   : m_options.replication_allowed_host;
-          m_target_instance->drop_user(repl_account, repl_account_host);
+          m_primary_master->drop_user(repl_account, repl_account_host);
         });
       }
 
@@ -858,7 +823,16 @@ shcore::Value Create_cluster::execute() {
     if (!m_metadata) {
       // Create the Metadata Schema.
       prepare_metadata_schema();
-      metadata = std::make_shared<MetadataStorage>(m_target_instance);
+
+      // Open a separate metadata connection to not mix MD transactions and
+      // other auto-committing operations on the same session
+
+      auto ipool = current_ipool();
+
+      auto inst =
+          ipool->connect_unchecked(m_target_instance->get_connection_options());
+
+      metadata = std::make_shared<MetadataStorage>(inst);
     } else {
       metadata = m_metadata;
     }
@@ -877,7 +851,8 @@ shcore::Value Create_cluster::execute() {
             : mysqlshdk::gr::Topology_mode::SINGLE_PRIMARY;
 
     auto cluster_impl = std::make_shared<Cluster_impl>(
-        cluster_name, group_name, m_target_instance, metadata, topology_mode);
+        cluster_name, group_name, m_target_instance, m_primary_master, metadata,
+        topology_mode);
 
     // Update the properties
     // For V1.0, let's see the Cluster's description to "default"
@@ -900,7 +875,7 @@ shcore::Value Create_cluster::execute() {
     // TODO(miguel): build and add the list of allowed operations
     metadata->update_cluster_capability(
         cluster_impl->get_id(), kCommunicationStack,
-        m_options.gr_options.communication_stack.get_safe(), {});
+        m_options.gr_options.communication_stack.value_or(""), {});
 
     metadata->update_cluster_attribute(
         cluster_impl->get_id(), k_cluster_attribute_assume_gtid_set_complete,
@@ -909,7 +884,7 @@ shcore::Value Create_cluster::execute() {
 
     metadata->update_cluster_attribute(
         cluster_impl->get_id(), k_cluster_attribute_manual_start_on_boot,
-        m_options.gr_options.manual_start_on_boot.get_safe(false)
+        m_options.gr_options.manual_start_on_boot.value_or(false)
             ? shcore::Value::True()
             : shcore::Value::False());
 
@@ -917,10 +892,10 @@ shcore::Value Create_cluster::execute() {
                                        k_cluster_attribute_default,
                                        shcore::Value::True());
 
-    if (!m_options.gr_options.view_change_uuid.is_null()) {
+    if (m_options.gr_options.view_change_uuid) {
       metadata->update_cluster_attribute(
           cluster_impl->get_id(), "group_replication_view_change_uuid",
-          shcore::Value(m_options.gr_options.view_change_uuid.get_safe()));
+          shcore::Value(m_options.gr_options.view_change_uuid.value_or("")));
     }
 
     // Store in the Metadata the value of
@@ -936,7 +911,7 @@ shcore::Value Create_cluster::execute() {
           cluster_impl->get_id(), k_cluster_attribute_transaction_size_limit,
           shcore::Value(
               m_target_instance->get_sysvar_int(kGrTransactionSizeLimit)
-                  .get_safe()));
+                  .value_or(0)));
     }
 
     // Insert instance into the metadata.
@@ -969,14 +944,14 @@ shcore::Value Create_cluster::execute() {
 
       // Create the recovery account and update the Metadata
       // NOTE: If the Cluster is a REPLICA the account must be created at the
-      // PRIMARY Cluster too (create_recovery_account will create it at the MD
-      // server)
+      // PRIMARY Cluster too
       if (m_create_replica_cluster ||
-          m_options.gr_options.communication_stack.is_null() ||
-          m_options.gr_options.communication_stack.get_safe() ==
-              kCommunicationStackXCom) {
+          !m_options.gr_options.communication_stack.has_value() ||
+          (m_options.gr_options.communication_stack.value() ==
+           kCommunicationStackXCom)) {
         std::string repl_account;
-        create_recovery_account(m_target_instance.get(), cluster_impl.get(),
+        create_recovery_account(m_target_instance.get(),
+                                m_target_instance.get(), cluster_impl.get(),
                                 &repl_account);
 
         // Drop the recovery account if GR fails to start
@@ -985,7 +960,7 @@ shcore::Value Create_cluster::execute() {
               m_options.replication_allowed_host.empty()
                   ? "%"
                   : m_options.replication_allowed_host;
-          m_target_instance->drop_user(repl_account, repl_account_host);
+          m_primary_master->drop_user(repl_account, repl_account_host);
         });
 
         store_recovery_account_metadata(m_target_instance.get(), *cluster_impl);
@@ -999,8 +974,7 @@ shcore::Value Create_cluster::execute() {
     // Handle the clone options
     {
       // If disableClone: true, uninstall the plugin and update the Metadata
-      if (!m_options.clone_options.disable_clone.is_null() &&
-          *m_options.clone_options.disable_clone) {
+      if (m_options.clone_options.disable_clone.value_or(false)) {
         mysqlshdk::mysql::uninstall_clone_plugin(*m_target_instance, nullptr);
         cluster_impl->set_disable_clone_option(
             *m_options.clone_options.disable_clone);
