@@ -102,8 +102,7 @@ void Upgrade_metadata::prepare() {
     case MDState::PATCH_HIGHER:
       throw std::runtime_error(
           "Installed metadata at '" + instance_data +
-          "' is newer than the version version supported by "
-          "this Shell (installed: " +
+          "' is newer than the version supported by this Shell (installed: " +
           installed.get_base() + ", shell: " + current.get_base() + ").");
 
       break;
@@ -131,7 +130,7 @@ void Upgrade_metadata::prepare() {
     case MDState::UPGRADING:
       throw std::runtime_error(shcore::str_subvars(
           mysqlsh::dba::metadata::kFailedUpgradeError,
-          [](const std::string &var) {
+          [](std::string_view var) {
             return shcore::get_member_name(var, shcore::current_naming_style());
           },
           "<<<", ">>>"));
@@ -336,7 +335,7 @@ void Upgrade_metadata::prepare_rolling_upgrade() {
                 "version\n"
                 "4 - Continue with the metadata upgrade once all Router "
                 "instances are upgraded or accounted for\n",
-                [](const std::string &var) {
+                [](std::string_view var) {
                   return shcore::get_member_name(
                       var, shcore::current_naming_style());
                 },
