@@ -285,22 +285,6 @@ This is the default value. A prompt will be shown if not possible to safely
 determine a safe way forward. If interaction is disabled, the operation will be
 canceled instead.
 
-@attention The memberSslMode option will be removed in a future release.
-
-The memberSslMode option supports the following values:
-
-@li REQUIRED: if used, SSL (encryption) will be enabled for the instance to
-communicate with other members of the cluster
-@li VERIFY_CA: Like REQUIRED, but additionally verify the server TLS
-certificate against the configured Certificate Authority (CA) certificates.
-@li VERIFY_IDENTITY: Like VERIFY_CA, but additionally verify that the server
-certificate matches the host to which the connection is attempted.
-@li DISABLED: if used, SSL (encryption) will be disabled
-@li AUTO: if used, SSL (encryption) will be automatically enabled or disabled
-based on the cluster configuration
-
-If memberSslMode is not specified AUTO will be used by default.
-
 The waitRecovery option supports the following values:
 
 @li 0: do not wait and let the recovery process to finish in the background.
@@ -332,6 +316,8 @@ ${CLUSTER_OPT_MEMBER_WEIGHT_DETAIL_EXTRA}
 
 ${CLUSTER_OPT_AUTO_REJOIN_TRIES_EXTRA}
 
+@attention The memberSslMode option will be removed in a future release.
+
 @attention The ipWhitelist option will be removed in a future release.
 Please use the ipAllowlist option instead.
 
@@ -354,7 +340,6 @@ void Cluster::add_instance(
   auto instance_def = instance_def_;
 
   if (!options->password.is_null()) {
-    instance_def.clear_password();
     instance_def.set_password(*(options->password));
   }
 
@@ -370,23 +355,10 @@ void Cluster::add_instance(
     }
   }
 
-  // Init progress_style
-  Recovery_progress_style progress_style;
-
-  if (options->wait_recovery == 0) {
-    progress_style = Recovery_progress_style::NOWAIT;
-  } else if (options->wait_recovery == 1) {
-    progress_style = Recovery_progress_style::NOINFO;
-  } else if (options->wait_recovery == 2) {
-    progress_style = Recovery_progress_style::TEXTUAL;
-  } else {
-    progress_style = Recovery_progress_style::PROGRESSBAR;
-  }
-
   return execute_with_pool(
       [&]() {
         // Add the Instance to the Cluster
-        impl()->add_instance(instance_def, *options, progress_style);
+        impl()->add_instance(instance_def, *options);
       },
       false);
 }
@@ -418,22 +390,6 @@ ${CLUSTER_OPT_LOCAL_ADDRESS}
 The password may be contained on the instance definition, however, it can be
 overwritten if it is specified on the options.
 
-@attention The memberSslMode option will be removed in a future release.
-
-The memberSslMode option supports these values:
-
-@li REQUIRED: if used, SSL (encryption) will be enabled for the instance to
-communicate with other members of the cluster
-@li VERIFY_CA: Like REQUIRED, but additionally verify the server TLS
-certificate against the configured Certificate Authority (CA) certificates.
-@li VERIFY_IDENTITY: Like VERIFY_CA, but additionally verify that the server
-certificate matches the host to which the connection is attempted.
-@li DISABLED: if used, SSL (encryption) will be disabled
-@li AUTO: if used, SSL (encryption) will be automatically enabled or disabled
-based on the cluster configuration
-
-If memberSslMode is not specified AUTO will be used by default.
-
 ${CLUSTER_OPT_IP_ALLOWLIST_EXTRA}
 
 The localAddress is an advanced option and its usage is discouraged
@@ -441,6 +397,8 @@ since incorrect values can lead to Group Replication errors.
 
 ${CLUSTER_OPT_LOCAL_ADDRESS_EXTRA}
 
+@attention The memberSslMode option will be removed in a future release.
+
 @attention The ipWhitelist option will be removed in a future release.
 Please use the ipAllowlist option instead.
 )*");
@@ -465,15 +423,13 @@ void Cluster::rejoin_instance(
   auto instance_def = instance_def_;
 
   if (!options->password.is_null()) {
-    instance_def.clear_password();
     instance_def.set_password(*(options->password));
   }
 
   return execute_with_pool(
       [&]() {
         // Rejoin the Instance to the Cluster
-        impl()->rejoin_instance(instance_def, options->gr_options,
-                                options->interactive(), false, {});
+        impl()->rejoin_instance(instance_def, *options);
       },
       false);
 }
@@ -528,7 +484,6 @@ void Cluster::remove_instance(
   auto instance_def = instance_def_;
 
   if (!options->password.is_null()) {
-    instance_def.clear_password();
     instance_def.set_password(*(options->password));
   }
 
@@ -1136,6 +1091,7 @@ ${CLUSTER_OPT_FAILOVER_CONSISTENCY}
 ${CLUSTER_OPT_CONSISTENCY}
 ${CLUSTER_OPT_EXPEL_TIMEOUT}
 ${CLUSTER_OPT_AUTO_REJOIN_TRIES}
+${CLUSTER_OPT_IP_ALLOWLIST}
 @li disableClone: boolean value used to disable the clone usage on the cluster.
 @li replicationAllowedHost string value to use as the host name part of
 internal replication accounts. Existing accounts will be re-created with the new
@@ -1166,6 +1122,8 @@ ${CLUSTER_OPT_AUTO_REJOIN_TRIES_EXTRA}
 
 ${CLUSTER_OPT_TRANSACTION_SIZE_LIMIT_EXTRA}
 
+${CLUSTER_OPT_IP_ALLOWLIST_EXTRA}
+
 ${NAMESPACE_TAG_DETAIL_CLUSTER}
 )*");
 
@@ -1208,6 +1166,7 @@ ${NAMESPACE_TAG}
 ${CLUSTER_OPT_EXIT_STATE_ACTION}
 ${CLUSTER_OPT_MEMBER_WEIGHT}
 ${CLUSTER_OPT_AUTO_REJOIN_TRIES}
+${CLUSTER_OPT_IP_ALLOWLIST}
 @li label a string identifier of the instance.
 
 ${CLUSTER_OPT_EXIT_STATE_ACTION_DETAIL}
@@ -1218,6 +1177,8 @@ ${CLUSTER_OPT_MEMBER_WEIGHT_DETAIL_EXTRA}
 
 ${CLUSTER_OPT_AUTO_REJOIN_TRIES_EXTRA}
 
+${CLUSTER_OPT_IP_ALLOWLIST_EXTRA}
+
 ${NAMESPACE_TAG_DETAIL_CLUSTER}
 
 ${NAMESPACE_TAG_INSTANCE_DETAILS_EXTRA}
