@@ -263,22 +263,14 @@ clone from. IPv6 addresses are not supported for this option.
 @li manualStartOnBoot: boolean (default false). If false, Group Replication in
 cluster instances will automatically start and rejoin when MySQL starts,
 otherwise it must be started manually.
-@li memberSslMode: SSL mode used to configure the security state of the
-communication between the InnoDB Cluster members.
-@li ipAllowlist: The list of hosts allowed to connect to the instance for
-Group Replication.
+${CLUSTER_OPT_MEMBER_SSL_MODE}
+${CLUSTER_OPT_IP_ALLOWLIST}
 ${CLUSTER_OPT_LOCAL_ADDRESS}
-@li exitStateAction: string value indicating the Group Replication exit
-state action.
-@li memberWeight: integer value with a percentage weight for automatic
-primary election on failover.
-@li consistency: string value indicating the consistency guarantees
-that the cluster provides.
-@li expelTimeout: integer value to define the time period in seconds that
-Cluster members should wait for a non-responding member before evicting
-it from the Cluster.
-@li autoRejoinTries: integer value to define the number of times an
-instance will attempt to rejoin the Cluster after being expelled.
+${CLUSTER_OPT_EXIT_STATE_ACTION}
+${CLUSTER_OPT_MEMBER_WEIGHT}
+${CLUSTER_OPT_CONSISTENCY}
+${CLUSTER_OPT_EXPEL_TIMEOUT}
+${CLUSTER_OPT_AUTO_REJOIN_TRIES}
 @li timeout: maximum number of seconds to wait for the instance to sync up
 with the PRIMARY Cluster. Default is 0 and it means no timeout.
 @li replicationAllowedHost: string value to use as the host name part of
@@ -319,19 +311,7 @@ member will be chosen as donor. If no SECONDARY members are available the
 PRIMARY will be selected. The option accepts values in the format: 'host:port'.
 IPv6 addresses are not supported.
 
-The memberSslMode option supports the following values:
-
-@li REQUIRED: if used, SSL (encryption) will be enabled for the instances to
-communicate with other members of the Cluster
-@li VERIFY_CA: Like REQUIRED, but additionally verify the server TLS
-certificate against the configured Certificate Authority (CA) certificates.
-@li VERIFY_IDENTITY: Like VERIFY_CA, but additionally verify that the server
-certificate matches the host to which the connection is attempted.
-@li DISABLED: if used, SSL (encryption) will be disabled
-@li AUTO: if used, SSL (encryption) will be enabled if supported by the
-instance, otherwise disabled
-
-If memberSslMode is not specified AUTO will be used by default.
+${CLUSTER_OPT_MEMBER_SSL_MODE_DETAIL}
 
 ${CLUSTER_OPT_IP_ALLOWLIST_EXTRA}
 
@@ -587,7 +567,7 @@ PRIMARY.
 
 During the switchover, the promoted Cluster will be synchronized with
 the old PRIMARY, ensuring that all transactions present in the PRIMARY
-are applied before the topology change is commited. The current PRIMARY
+are applied before the topology change is committed. The current PRIMARY
 instance is also locked with 'FLUSH TABLES WITH READ LOCK' in order to prevent
 changes during the switch. If either of these operations take too long or fails,
 the switch will be aborted.
@@ -618,7 +598,9 @@ The following options may be given:
 performed, but will not execute them. The operations that would be
 performed can be viewed by enabling verbose output in the shell.
 @li timeout: integer value to set the maximum number of seconds to wait
-for the synchronization of the Cluster.
+for the synchronization of the Cluster and also for the instance
+being promoted to catch up with the current PRIMARY (in the case of the latter,
+the default value is retrieved from the 'dba.gtidWaitTimeout' shell option).
 @li invalidateReplicaClusters: list of names of REPLICA Clusters that are
 unreachable or unavailable that are to be invalidated during the switchover.
 )*");
@@ -716,6 +698,9 @@ performed, but will not execute them. The operations that would be
 performed can be viewed by enabling verbose output in the shell.
 @li invalidateReplicaClusters: list of names of REPLICA Clusters that are
 unreachable or unavailable that are to be invalidated during the failover.
+@li timeout: integer value with the maximum number of seconds to wait for
+pending transactions to be applied in each instance of the cluster (default
+value is retrieved from the 'dba.gtidWaitTimeout' shell option).
 )*");
 /**
  * $(CLUSTERSET_FORCEPRIMARYCLUSTER_BRIEF)
@@ -891,9 +876,11 @@ shcore::Value ClusterSet::list_routers(const std::string &router) {
 
 REGISTER_HELP_FUNCTION(setRoutingOption, ClusterSet);
 REGISTER_HELP_FUNCTION_TEXT(CLUSTERSET_SETROUTINGOPTION, R"*(
-Changes the value of either a global Routing option or of a single Router instance.
+Changes the value of either a global Routing option or of a single Router
+instance.
 
-@param router optional identifier of the target router instance (e.g. 192.168.45.70@::system).
+@param router optional identifier of the target router instance (e.g.
+192.168.45.70@::system).
 @param option The Router option to be changed.
 @param value The value that the option shall get (or null to unset).
 
@@ -901,14 +888,19 @@ Changes the value of either a global Routing option or of a single Router instan
 
 The accepted options are:
 
-@li target_cluster: Target Cluster for Router routing operations.
+@li target_cluster: Target Cluster for Router routing operations. Default value
+is 'primary'.
 @li invalidated_cluster_policy: Routing policy to be taken when the target
-cluster is detected as being invalidated.
-@li stats_updates_frequency: Frequency of Router check-in updates.
+cluster is detected as being invalidated. Default value is 'drop_all'.
+@li stats_updates_frequency: Frequency of Router check-in updates. Default
+value is 0.
+@li use_replica_primary_as_rw: Enable/Disable the RW Port in Replica Clusters.
+Disabled by default.
 
 The target_cluster option supports the following values:
 
-@li primary: follow the Primary Cluster whenever it changes in runtime
+@li primary: Follow the Primary Cluster whenever it changes in runtime (
+default).
 @li @<clusterName@>: Use the Cluster named @<clusterName@> as target.
 
 The invalidated_cluster_policy option supports the following values:
@@ -916,11 +908,11 @@ The invalidated_cluster_policy option supports the following values:
 @li accept_ro: all the RW connections are be dropped and no new RW connections
 are be accepted. RO connections keep being accepted and handled.
 @li drop_all: all connections to the target Cluster are closed and no new
-connections will be accepted.
+connections will be accepted (default).
 
 The stats_updates_frequency option accepts positive integers and sets the
-frequency of Router check-in updates in seconds in the Metadata. If set to 0 (
-default), no periodic updates are done. Router will round up the value to be a
+frequency of Router check-in updates in seconds in the Metadata. If set to 0
+(default), no periodic updates are done. Router will round up the value to be a
 multiple of Router's TTL, i.e.:
 
 @li If lower than TTL its gets rounded up to TTL, e.g. TTL=30, and
@@ -930,9 +922,17 @@ stats_updates_frequency=1, effective frequency is 30 seconds.
 the TTL, e.g. TTL=5, stats_updates_frequency=11, effective frequency is 15
 seconds; TTL=5, stats_updates_frequency=13, effective frequency is 15 seconds.
 
-If the value is null, the option value is cleared and the default value takes
-effect.
-)*");
+If the value is null, the option value is cleared and the default value (0)
+takes effect.
+
+The use_replica_primary_as_rw option accepts a boolean value to configure
+whether the Router should enable or disable the RW Port for the target Cluster.
+
+When enabled, forces the RW port of Routers targeting a specific Cluster
+(target_cluster != 'primary') to always route to the PRIMARY of that Cluster,
+even when it is in a REPLICA cluster and thus, read-only. By default, the
+option is false and Router blocks connections to the RW port in this
+scenario.)*");
 
 #if DOXYGEN_JS
 Undefined ClusterSet::setRoutingOption(String option, String value) {}
