@@ -90,7 +90,7 @@ class Replica_set_impl : public Base_cluster_impl {
                        bool interactive, bool dry_run);
 
   void remove_instance(const std::string &instance_def,
-                       const mysqlshdk::null_bool &force, int timeout);
+                       std::optional<bool> force, int timeout);
 
   void set_primary_instance(const std::string &instance_def, uint32_t timeout,
                             bool dry_run);
@@ -126,6 +126,7 @@ class Replica_set_impl : public Base_cluster_impl {
       std::list<Instance_metadata> *out_unreachable);
 
   mysqlsh::dba::Instance *acquire_primary(
+      bool primary_required = true,
       mysqlshdk::mysql::Lock_mode mode = mysqlshdk::mysql::Lock_mode::NONE,
       const std::string &skip_lock_uuid = "") override;
 
@@ -159,7 +160,7 @@ class Replica_set_impl : public Base_cluster_impl {
   void validate_add_instance(Global_topology_manager *topology,
                              mysqlshdk::mysql::IInstance *master,
                              Instance *target_instance,
-                             const Async_replication_options &ar_options,
+                             Async_replication_options *ar_options,
                              Clone_options *clone_options, bool interactive);
 
   void validate_rejoin_instance(Global_topology_manager *topology_mng,
@@ -236,6 +237,8 @@ class Replica_set_impl : public Base_cluster_impl {
       const std::string &function_name,
       bool throw_if_primary_unavailable = true);
 
+  void read_replication_options(Async_replication_options *ar_options);
+
   Global_topology_type m_topology_type;
 };
 
