@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -254,13 +254,9 @@ namespace {
 #define X(name, query, _) {name, {name, nullptr, query}},
 #define S(section)
 
-bool comparator(const std::string &l, const std::string &r) {
-  return shcore::str_casecmp(l, r) < 0;
-}
-
 const std::map<std::string, Column_definition,
-               std::function<decltype(comparator)>>
-    allowed_columns{{COLUMN_DESCRIPTIONS}, comparator};
+               shcore::Case_insensitive_comparator>
+    allowed_columns{{COLUMN_DESCRIPTIONS}};
 
 #undef S
 #undef X
