@@ -27,6 +27,7 @@
 #include <string>
 
 #include "mysqlshdk/libs/aws/s3_bucket_options.h"
+#include "mysqlshdk/libs/azure/blob_storage_options.h"
 
 #include "modules/util/dump/dump_manifest_options.h"
 #include "modules/util/dump/dump_options.h"
@@ -64,6 +65,10 @@ class Ddl_dumper_options : public Dump_options {
 
   bool consistent_dump() const override { return m_consistent_dump; }
 
+  bool skip_consistency_checks() const override {
+    return m_skip_consistency_checks;
+  }
+
   bool dump_triggers() const override { return m_dump_triggers; }
 
   bool use_timezone_utc() const override { return m_timezone_utc; }
@@ -95,6 +100,7 @@ class Ddl_dumper_options : public Dump_options {
   // this should be in the Dump_options class, but storing it at the same level
   // as OCI options helps in handling both option groups at the same time
   mysqlshdk::aws::S3_bucket_options m_s3_bucket_options;
+  mysqlshdk::azure::Blob_storage_options m_blob_storage_options;
 
   bool m_split = true;
   uint64_t m_bytes_per_chunk;
@@ -106,6 +112,7 @@ class Ddl_dumper_options : public Dump_options {
   bool m_data_only = false;
   bool m_dry_run = false;
   bool m_consistent_dump = true;
+  bool m_skip_consistency_checks = false;
 };
 
 }  // namespace dump
