@@ -40,7 +40,6 @@
 #include "mysqlshdk/libs/storage/idirectory.h"
 #include "mysqlshdk/libs/storage/ifile.h"
 #include "mysqlshdk/libs/textui/text_progress.h"
-#include "mysqlshdk/libs/utils/nullable.h"
 #include "mysqlshdk/libs/utils/synchronized_queue.h"
 #include "mysqlshdk/libs/utils/version.h"
 
@@ -108,6 +107,11 @@ class Dumper {
   bool dump_users() const;
 
  private:
+  class Dump_writer_controller;
+  class Single_file_writer_controller;
+  class Default_writer_controller;
+  class Multi_file_writer_controller;
+
   struct Object_info {
     std::string name;
     std::string quoted_name;
@@ -134,13 +138,11 @@ class Dumper {
   struct Table_task : Table_info {
     std::string task_name;
     std::string schema;
-    const Instance_cache::Partition *partition = nullptr;
+    std::string where;
   };
 
   struct Table_data_task : Table_task {
-    std::string where;
-    Dump_writer *writer = nullptr;
-    std::unique_ptr<mysqlshdk::storage::IFile> index_file;
+    std::unique_ptr<Dump_writer_controller> controller;
     std::string id;
   };
 
@@ -272,15 +274,16 @@ class Dumper {
 
   void push_table_chunking_task(Table_task &&task);
 
-  bool is_chunked(const Table_task &task) const;
-
   bool should_dump_data(const Table_task &table);
 
-  Dump_writer *get_table_data_writer(const std::string &filename);
+  std::unique_ptr<Dump_writer_controller> table_dump_controller(
+      const std::string &filename) const;
 
-  std::size_t finish_writing(Dump_writer *writer, uint64_t total_bytes);
+  std::unique_ptr<Dump_writer_controller> table_dump_multi_file_controller(
+      const std::string &basename) const;
 
-  std::string close_file(const Dump_writer &writer) const;
+  void finish_writing(const std::string &schema, const std::string &table,
+                      const Dump_writer_controller *controller);
 
   void write_metadata() const;
 
@@ -308,13 +311,9 @@ class Dumper {
                                       const std::size_t idx,
                                       const bool last_chunk) const;
 
-  std::string get_table_data_ext() const;
-
   void initialize_progress();
 
-  void update_bytes_written(uint64_t new_bytes);
-
-  void update_progress(uint64_t new_rows, const Dump_write_result &new_bytes);
+  void update_progress(const Dump_write_result &progress);
 
   void shutdown_progress();
 
@@ -353,8 +352,6 @@ class Dumper {
 
   void fetch_server_information();
 
-  std::string filename_for_data_dump(const std::string &filename) const;
-
   // returns true in case of errors
   bool check_for_upgrade_errors() const;
 
@@ -381,6 +378,7 @@ class Dumper {
   Instance_cache m_cache;
   std::vector<Schema_info> m_schema_infos;
   std::unordered_map<std::string, std::size_t> m_truncated_basenames;
+  std::string m_table_data_extension;
 
   // status variables
   bool m_instance_locked = false;
@@ -396,10 +394,6 @@ class Dumper {
   uint64_t m_total_objects = 0;
 
   // progress information
-  mutable Progress_thread m_progress_thread;
-  mutable Progress_thread::Stage *m_current_stage = nullptr;
-  Progress_thread::Stage *m_data_dump_stage = nullptr;
-
   std::atomic<uint64_t> m_data_bytes;
   std::atomic<uint64_t> m_bytes_written;
   std::atomic<uint64_t> m_rows_written;
@@ -432,9 +426,15 @@ class Dumper {
   std::atomic<uint64_t> m_chunking_tasks;
   std::atomic<bool> m_main_thread_finished_producing_chunking_tasks;
   std::unique_ptr<Synchronize_workers> m_worker_synchronization;
-  std::vector<std::unique_ptr<Dump_writer>> m_worker_writers;
-  std::mutex m_worker_writers_mutex;
+  std::function<std::unique_ptr<Dump_writer>()> m_writer_creator;
   volatile bool m_worker_interrupt = false;
+
+  // progress thread needs to be placed after any of the fields it uses, in
+  // order to ensure that it is destroyed (and stopped) before any of those
+  // fields
+  mutable Progress_thread m_progress_thread;
+  mutable Progress_thread::Stage *m_current_stage = nullptr;
+  Progress_thread::Stage *m_data_dump_stage = nullptr;
 };
 
 }  // namespace dump
