@@ -472,6 +472,8 @@ class Dump_loader {
       const std::string &schema, const std::string &table,
       const std::vector<Dump_reader::Histogram> &histograms) const;
 
+  void load_users() const;
+
  private:
 #ifdef FRIEND_TEST
   FRIEND_TEST(Load_dump, sql_transforms_strip_sql_mode);
@@ -482,11 +484,10 @@ class Dump_loader {
 
   class Sql_transform {
    public:
-    bool operator()(const char *sql, size_t length,
-                    std::string *out_new_sql) const {
+    bool operator()(std::string_view sql, std::string *out_new_sql) const {
       if (m_ops.empty()) return false;
 
-      std::string orig_sql(sql, length);
+      std::string orig_sql(sql);
       std::string new_sql;
 
       for (const auto &f : m_ops) {
@@ -509,20 +510,20 @@ class Dump_loader {
      * Callback should return true if this statement should be executed.
      */
     void add_execute_conditionally(
-        std::function<bool(const std::string &, const std::string &)> &&f);
+        std::function<bool(std::string_view, std::string_view)> f);
 
     /**
      * Whenever a USE `schema` or CREATE DATABASE ... `schema` statement is
      * executed, `schema` is going to be replaced with the new name.
      */
-    void add_rename_schema(const std::string &new_name);
+    void add_rename_schema(std::string_view new_name);
 
    private:
-    void add(std::function<void(const std::string &, std::string *)> &&f) {
+    void add(std::function<void(std::string_view, std::string *)> f) {
       m_ops.emplace_back(std::move(f));
     }
 
-    std::list<std::function<void(const std::string &, std::string *)>> m_ops;
+    std::list<std::function<void(std::string_view, std::string *)>> m_ops;
   };
 
   const Load_dump_options &m_options;
@@ -560,11 +561,6 @@ class Dump_loader {
   bool m_init_done = false;
   bool m_workers_killed = false;
 
-  dump::Progress_thread m_progress_thread;
-  dump::Progress_thread::Stage *m_load_data_stage = nullptr;
-  dump::Progress_thread::Stage *m_create_indexes_stage = nullptr;
-  dump::Progress_thread::Stage *m_analyze_tables_stage = nullptr;
-
   // tables and partitions loaded
   std::unordered_set<std::string> m_unique_tables_loaded;
   size_t m_total_tables_with_data = 0;
@@ -589,6 +585,14 @@ class Dump_loader {
 
   std::unordered_map<std::string, bool> m_schema_ddl_ready;
   std::unordered_map<std::string, uint64_t> m_ddl_in_progress_per_schema;
+
+  // progress thread needs to be placed after any of the fields it uses, in
+  // order to ensure that it is destroyed (and stopped) before any of those
+  // fields
+  dump::Progress_thread m_progress_thread;
+  dump::Progress_thread::Stage *m_load_data_stage = nullptr;
+  dump::Progress_thread::Stage *m_create_indexes_stage = nullptr;
+  dump::Progress_thread::Stage *m_analyze_tables_stage = nullptr;
 };
 
 }  // namespace mysqlsh
