@@ -152,7 +152,10 @@ std::shared_ptr<mysqlshdk::oci::IPAR_config> par_config(
 }  // namespace
 
 Load_dump_options::Load_dump_options() : Load_dump_options("") {}
-Load_dump_options::Load_dump_options(const std::string &url) : m_url(url) {
+Load_dump_options::Load_dump_options(const std::string &url)
+    : m_url(url),
+      m_blob_storage_options{
+          mysqlshdk::azure::Blob_storage_options::Operation::READ} {
   // some users are always excluded
   add_excluded_users(shcore::to_accounts(k_excluded_users));
 }
@@ -217,6 +220,7 @@ const shcore::Option_pack_def<Load_dump_options> &Load_dump_options::options() {
           .optional("sessionInitSql", &Load_dump_options::m_session_init_sql)
           .include(&Load_dump_options::m_oci_bucket_options)
           .include(&Load_dump_options::m_s3_bucket_options)
+          .include(&Load_dump_options::m_blob_storage_options)
           .on_done(&Load_dump_options::on_unpacked_options)
           .on_log(&Load_dump_options::on_log_options);
 
@@ -314,7 +318,7 @@ void Load_dump_options::set_max_bytes_per_transaction(
 
   m_max_bytes_per_transaction = mysqlshdk::utils::expand_to_bytes(value);
 
-  if (m_max_bytes_per_transaction &&
+  if (m_max_bytes_per_transaction.has_value() &&
       *m_max_bytes_per_transaction < k_minimum_max_bytes_per_transaction) {
     throw std::invalid_argument(
         "The value of 'maxBytesPerTransaction' option must be greater than or "
@@ -406,7 +410,7 @@ void Load_dump_options::set_session(
       // MYSQLSH_ALLOW_ALWAYS_GIPK environment variable
       if (!sql_generate_invisible_primary_key() ||
           getenv("MYSQLSH_ALLOW_ALWAYS_GIPK")) {
-        m_sql_generate_invisible_primary_key.reset();
+        m_sql_generate_invisible_primary_key = std::nullopt;
       }
     }
   }
@@ -448,7 +452,7 @@ void Load_dump_options::validate() {
     if (config && config->valid()) {
       if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type() ||
           mysqlshdk::oci::PAR_type::PREFIX == config->par().type()) {
-        if (m_progress_file.is_null()) {
+        if (!m_progress_file.has_value()) {
           throw shcore::Exception::argument_error(
               "When using a PAR to load a dump, the progressFile option must "
               "be defined");
@@ -476,7 +480,7 @@ void Load_dump_options::validate() {
     }
   }
 
-  if (m_progress_file.is_null()) {
+  if (!m_progress_file.has_value()) {
     m_default_progress_file = "load-progress." + m_server_uuid + ".json";
   }
 }
@@ -539,6 +543,8 @@ std::string Load_dump_options::target_import_info() const {
 
 void Load_dump_options::on_unpacked_options() {
   m_s3_bucket_options.throw_on_conflict(m_oci_bucket_options);
+  m_s3_bucket_options.throw_on_conflict(m_blob_storage_options);
+  m_blob_storage_options.throw_on_conflict(m_oci_bucket_options);
 
   if (m_oci_bucket_options) {
     m_storage_config = m_oci_bucket_options.config();
@@ -548,6 +554,10 @@ void Load_dump_options::on_unpacked_options() {
     m_storage_config = m_s3_bucket_options.config();
   }
 
+  if (m_blob_storage_options) {
+    m_storage_config = m_blob_storage_options.config();
+  }
+
   if (!m_load_data && !m_load_ddl && !m_load_users &&
       m_analyze_tables == Analyze_table_mode::OFF &&
       m_update_gtid_set == Update_gtid_set::OFF) {
@@ -599,7 +609,7 @@ Load_dump_options::create_dump_handle() const {
 
 std::unique_ptr<mysqlshdk::storage::IFile>
 Load_dump_options::create_progress_file_handle() const {
-  if (m_progress_file.get_safe().empty())
+  if (m_progress_file.value_or(std::string{}).empty())
     return create_dump_handle()->file(m_default_progress_file);
   else
     return mysqlshdk::storage::make_file(*m_progress_file,
@@ -608,7 +618,7 @@ Load_dump_options::create_progress_file_handle() const {
 
 // Filtering works as:
 // (includeSchemas + includeTables || *) - excludeSchemas - excludeTables
-bool Load_dump_options::include_schema(const std::string &schema) const {
+bool Load_dump_options::include_schema(std::string_view schema) const {
   const auto qschema = shcore::quote_identifier(schema);
 
   if (m_exclude_schemas.count(qschema) > 0) return false;
@@ -624,69 +634,92 @@ bool Load_dump_options::include_schema(const std::string &schema) const {
   return false;
 }
 
-bool Load_dump_options::include_table(const std::string &schema,
-                                      const std::string &table) const {
+bool Load_dump_options::include_table(std::string_view schema,
+                                      std::string_view table) const {
   return include_object(schema, table, m_include_tables, m_exclude_tables);
 }
 
-bool Load_dump_options::include_event(const std::string &schema,
-                                      const std::string &event) const {
+bool Load_dump_options::include_event(std::string_view schema,
+                                      std::string_view event) const {
   return include_object(schema, event, m_include_events, m_exclude_events);
 }
 
-bool Load_dump_options::include_routine(const std::string &schema,
-                                        const std::string &routine) const {
+bool Load_dump_options::include_routine(std::string_view schema,
+                                        std::string_view routine) const {
   return include_object(schema, routine, m_include_routines,
                         m_exclude_routines);
 }
 
+bool Load_dump_options::include_routine_ci(std::string_view schema,
+                                           std::string_view routine) const {
+  return include_object_ci(schema, routine, m_include_routines,
+                           m_exclude_routines);
+}
+
 bool Load_dump_options::include_object(
-    const std::string &schema, const std::string &object,
+    std::string_view schema, std::string_view object,
     const std::unordered_set<std::string> &included,
     const std::unordered_set<std::string> &excluded) const {
   assert(!schema.empty());
   assert(!object.empty());
 
-  if (include_schema(schema)) {
-    const auto key = schema_object_key(schema, object);
+  if (!include_schema(schema)) return false;
 
-    if (excluded.count(key) > 0) {
-      return false;
-    }
+  const auto key = schema_object_key(schema, object);
 
-    if (included.empty() || included.count(key) > 0) {
-      return true;
-    }
-  }
+  if (excluded.count(key) > 0) return false;
 
-  return false;
+  return (included.empty() || included.count(key) > 0);
 }
 
-bool Load_dump_options::include_trigger(const std::string &schema,
-                                        const std::string &table,
-                                        const std::string &trigger) const {
+bool Load_dump_options::include_object_ci(
+    std::string_view schema, std::string_view object,
+    const std::unordered_set<std::string> &included,
+    const std::unordered_set<std::string> &excluded) const {
+  assert(!schema.empty());
+  assert(!object.empty());
+
+  if (!include_schema(schema)) return false;
+
+  const auto key = shcore::utf8_to_wide(schema_object_key(schema, object));
+  const auto contains_ci = [&key](const auto &c) {
+    for (const auto &e : c) {
+      if (shcore::str_caseeq(key, shcore::utf8_to_wide(e))) {
+        return true;
+      }
+    }
+    return false;
+  };
+
+  if (contains_ci(excluded)) {
+    return false;
+  }
+
+  return (included.empty() || contains_ci(included));
+}
+
+bool Load_dump_options::include_trigger(std::string_view schema,
+                                        std::string_view table,
+                                        std::string_view trigger) const {
   assert(!schema.empty());
   assert(!table.empty());
   assert(!trigger.empty());
 
-  if (include_table(schema, table)) {
-    // filters for triggers contain either `schema`.`table` or
-    // `schema`.`table`.`trigger` entries
-    const auto table_key = schema_object_key(schema, table);
-    const auto trigger_key = schema_table_object_key(schema, table, trigger);
+  if (!include_table(schema, table)) return false;
 
-    if (m_exclude_triggers.count(table_key) > 0 ||
-        m_exclude_triggers.count(trigger_key) > 0) {
-      return false;
-    }
+  // filters for triggers contain either `schema`.`table` or
+  // `schema`.`table`.`trigger` entries
+  const auto table_key = schema_object_key(schema, table);
+  const auto trigger_key = schema_table_object_key(schema, table, trigger);
 
-    if (m_include_triggers.empty() || m_include_triggers.count(table_key) > 0 ||
-        m_include_triggers.count(trigger_key) > 0) {
-      return true;
-    }
+  if (m_exclude_triggers.count(table_key) > 0 ||
+      m_exclude_triggers.count(trigger_key) > 0) {
+    return false;
   }
 
-  return false;
+  return (m_include_triggers.empty() ||
+          m_include_triggers.count(table_key) > 0 ||
+          m_include_triggers.count(trigger_key) > 0);
 }
 
 bool Load_dump_options::include_user(const shcore::Account &account) const {
