@@ -25,20 +25,22 @@
 #define MODULES_UTIL_LOAD_LOAD_DUMP_OPTIONS_H_
 
 #include <memory>
+#include <optional>
 #include <string>
 #include <string_view>
 #include <unordered_set>
 #include <vector>
+
 #include "modules/mod_utils.h"
 #include "modules/util/import_table/helpers.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/libs/aws/s3_bucket_options.h"
+#include "mysqlshdk/libs/azure/blob_storage_options.h"
 #include "mysqlshdk/libs/db/connection_options.h"
 #include "mysqlshdk/libs/oci/oci_bucket_options.h"
 #include "mysqlshdk/libs/storage/config.h"
 #include "mysqlshdk/libs/storage/idirectory.h"
 #include "mysqlshdk/libs/storage/ifile.h"
-#include "mysqlshdk/libs/utils/nullable.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_sqlstring.h"
@@ -46,17 +48,28 @@
 
 namespace mysqlsh {
 
-inline std::string schema_object_key(const std::string &schema,
-                                     const std::string &table) {
-  return shcore::quote_identifier(schema) +
-         (table.empty() ? "" : "." + shcore::quote_identifier(table));
+inline std::string schema_object_key(std::string_view schema,
+                                     std::string_view table) {
+  std::string res;
+  res.reserve(schema.size() + table.size() + 1);
+
+  res.append(shcore::quote_identifier(schema));
+  if (table.empty()) return res;
+
+  res.append(".");
+  res.append(shcore::quote_identifier(table));
+  return res;
 }
 
-inline std::string schema_table_object_key(const std::string &schema,
-                                           const std::string &table,
-                                           const std::string &partition) {
-  return schema_object_key(schema, table) +
-         (partition.empty() ? "" : "." + shcore::quote_identifier(partition));
+inline std::string schema_table_object_key(std::string_view schema,
+                                           std::string_view table,
+                                           std::string_view partition) {
+  auto res = schema_object_key(schema, table);
+  if (partition.empty()) return res;
+
+  res.append(".");
+  res.append(shcore::quote_identifier(partition));
+  return res;
 }
 
 class Load_dump_options {
@@ -105,7 +118,7 @@ class Load_dump_options {
   std::unique_ptr<mysqlshdk::storage::IFile> create_progress_file_handle()
       const;
 
-  const mysqlshdk::null_string &progress_file() const {
+  const std::optional<std::string> &progress_file() const {
     return m_progress_file;
   }
 
@@ -122,7 +135,7 @@ class Load_dump_options {
   uint64_t threads_count() const { return m_threads_count; }
 
   uint64_t background_threads_count(uint64_t def) const {
-    return m_background_threads_count.get_safe(def);
+    return m_background_threads_count.value_or(def);
   }
 
   uint64_t threads_per_add_index() const { return m_threads_per_add_index; }
@@ -143,13 +156,14 @@ class Load_dump_options {
 
   bool force() const { return m_force; }
 
-  bool include_schema(const std::string &schema) const;
-  bool include_table(const std::string &schema, const std::string &table) const;
-  bool include_event(const std::string &schema, const std::string &event) const;
-  bool include_routine(const std::string &schema,
-                       const std::string &routine) const;
-  bool include_trigger(const std::string &schema, const std::string &table,
-                       const std::string &trigger) const;
+  bool include_schema(std::string_view schema) const;
+  bool include_table(std::string_view schema, std::string_view table) const;
+  bool include_event(std::string_view schema, std::string_view event) const;
+  bool include_routine(std::string_view schema, std::string_view routine) const;
+  bool include_routine_ci(std::string_view schema,
+                          std::string_view routine) const;
+  bool include_trigger(std::string_view schema, std::string_view table,
+                       std::string_view trigger) const;
 
   bool ignore_existing_objects() const { return m_ignore_existing_objects; }
 
@@ -182,17 +196,16 @@ class Load_dump_options {
   bool show_metadata() const { return m_show_metadata; }
 
   bool should_create_pks(bool default_value) const {
-    return m_create_invisible_pks.get_safe(default_value);
+    return m_create_invisible_pks.value_or(default_value);
   }
 
   bool auto_create_pks_supported() const {
-    return !m_sql_generate_invisible_primary_key.is_null();
+    return m_sql_generate_invisible_primary_key.has_value();
   }
 
   bool sql_generate_invisible_primary_key() const;
 
-  const mysqlshdk::utils::nullable<uint64_t> &max_bytes_per_transaction()
-      const {
+  std::optional<uint64_t> max_bytes_per_transaction() const {
     return m_max_bytes_per_transaction;
   }
 
@@ -220,10 +233,14 @@ class Load_dump_options {
 
   void add_excluded_users(std::vector<shcore::Account> &&users);
 
-  bool include_object(const std::string &schema, const std::string &object,
+  bool include_object(std::string_view schema, std::string_view object,
                       const std::unordered_set<std::string> &included,
                       const std::unordered_set<std::string> &excluded) const;
 
+  bool include_object_ci(std::string_view schema, std::string_view object,
+                         const std::unordered_set<std::string> &included,
+                         const std::unordered_set<std::string> &excluded) const;
+
   bool error_on_object_filters_conflicts(
       const std::unordered_set<std::string> &included,
       const std::unordered_set<std::string> &excluded,
@@ -233,11 +250,12 @@ class Load_dump_options {
 
   std::string m_url;
   uint64_t m_threads_count = 4;
-  mysqlshdk::utils::nullable<uint64_t> m_background_threads_count;
+  std::optional<uint64_t> m_background_threads_count;
   bool m_show_progress = isatty(fileno(stdout)) ? true : false;
 
   mysqlshdk::oci::Oci_bucket_options m_oci_bucket_options;
   mysqlshdk::aws::S3_bucket_options m_s3_bucket_options;
+  mysqlshdk::azure::Blob_storage_options m_blob_storage_options;
   mysqlshdk::storage::Config_ptr m_storage_config;
   mysqlshdk::storage::Config_ptr m_progress_file_config;
   Connection_options m_target;
@@ -265,7 +283,7 @@ class Load_dump_options {
 
   uint64_t m_wait_dump_timeout_ms = 0;
   bool m_reset_progress = false;
-  mysqlshdk::null_string m_progress_file;
+  std::optional<std::string> m_progress_file;
   std::string m_default_progress_file;
   std::string m_character_set;
   bool m_load_data = true;
@@ -286,10 +304,10 @@ class Load_dump_options {
   mysqlshdk::utils::Version m_target_server_version;
   bool m_is_mds = false;
   bool m_show_metadata = false;
-  mysqlshdk::null_bool m_create_invisible_pks;
-  mysqlshdk::null_bool m_sql_generate_invisible_primary_key;
+  std::optional<bool> m_create_invisible_pks;
+  std::optional<bool> m_sql_generate_invisible_primary_key;
 
-  mysqlshdk::utils::nullable<uint64_t> m_max_bytes_per_transaction;
+  std::optional<uint64_t> m_max_bytes_per_transaction;
 
   std::string m_server_uuid;
 
