@@ -154,7 +154,7 @@ void Util::check_for_server_upgrade(
     const shcore::Option_pack_ref<Upgrade_check_options> &options) {
   auto connection = connection_options;
   if (connection.has_data()) {
-    if (!options->password.is_null()) {
+    if (options->password.has_value()) {
       if (connection.has_password()) connection.clear_password();
       connection.set_password(*options->password);
     }
@@ -474,15 +474,72 @@ void Util::import_json(
   importer.print_stats();
 }
 
+REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_AZURE_COMMON_OPTIONS, R"*(
+@li <b>azureContainerName</b>: string (default: not set) - Name of the Azure
+container to use. The container must already exist.
+@li <b>azureConfigFile</b>: string (default: not set) - Use the specified Azure
+configuration file instead of the one at the default location.
+@li <b>azureStorageAccount</b>: string (default: not set) - The account to be used
+for the operation.
+@li <b>azureStorageSasToken</b>: string (default: not set) - Azure Shared Access
+Signature (SAS) token, to be used for the authentication of the operation, instead of a key.)*");
+
+REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_AZURE_COMMON_OPTION_DETAILS, R"*(
+If the <b>azureContainerName</b> option is used, the dump is stored in the specified
+Azure container. Connection is established using the configuration at the
+local Azure configuration file.The directory structure is simulated
+within the blob name.
+
+The <b>azureConfigFile</b> option cannot be used if the <b>azureContainerName</b>
+option is not set or set to an empty string.
+
+<b>Handling of the Azure settings</b>
+
+-# The following settings are read from the <b>storage</b> section in the <b>config</b>
+file:
+@li <b>connection_string</b>
+@li <b>account</b>
+@li <b>key</b>
+@li <b>sas_token</b>
+
+Additionally, the connection options may be defined using the standard Azure environment
+variables:
+@li <b>AZURE_STORAGE_CONNECTION_STRING</b>
+@li <b>AZURE_STORAGE_ACCOUNT</b>
+@li <b>AZURE_STORAGE_KEY</b>
+@li <b>AZURE_STORAGE_SAS_TOKEN</b>
+
+The Azure configuration values are evaluated in the following precedence:
+
+- Options parameter
+- Environment Variables
+- Configuration File
+
+If a connection string is defined either case in the environment variable or the configuration
+option, the individual configuration values for account and key will be ignored.
+
+If a SAS Token is defined, it will be used for the authorization (ignoring any defined account key).
+
+The default Azure Blob Endpoint to be used in the operations is defined by:
+
+%https://@<account@>.blob.core.windows.net
+
+Unless a different EndPoint is defined in the connection string.)*");
+
+REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_DUMP_AZURE_COMMON_OPTION_DETAILS, R"*(
+<b>Dumping to a Container in the Azure Blob Storage</b>
+
+${TOPIC_UTIL_AZURE_COMMON_OPTION_DETAILS})*");
+
 REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_AWS_COMMON_OPTIONS, R"*(
 @li <b>s3BucketName</b>: string (default: not set) - Name of the AWS S3 bucket
 to use. The bucket must already exist.
 @li <b>s3CredentialsFile</b>: string (default: not set) - Use the specified AWS
-<b>credentials</b> file instead of the one at the default location.
+<b>credentials</b> file.
 @li <b>s3ConfigFile</b>: string (default: not set) - Use the specified AWS
-<b>config</b> file instead of the one at the default location.
-@li <b>s3Profile</b>: string (default: not set) - Use the specified AWS profile
-instead of the <b>default</b> one.
+<b>config</b> file.
+@li <b>s3Profile</b>: string (default: not set) - Use the specified AWS profile.
+@li <b>s3Region</b>: string (default: not set) - Use the specified AWS region.
 @li <b>s3EndpointOverride</b>: string (default: not set) - Use the specified AWS
 S3 API endpoint instead of the default one.)*");
 
@@ -492,32 +549,71 @@ AWS S3 bucket. Connection is established using default local AWS configuration
 paths and profiles, unless overridden. The directory structure is simulated
 within the object name.
 
-The <b>s3CredentialsFile</b>, <b>s3ConfigFile</b>, <b>s3Profile</b> and
-<b>s3EndpointOverride</b> options cannot be used if the <b>s3BucketName</b>
-option is not set or set to an empty string.
+The <b>s3CredentialsFile</b>, <b>s3ConfigFile</b>, <b>s3Profile</b>,
+<b>s3Region</b> and <b>s3EndpointOverride</b> options cannot be used if the
+<b>s3BucketName</b> option is not set or set to an empty string.
 
 <b>Handling of the AWS settings</b>
 
--# The following settings are read from the <b>config</b> file for the
-specified profile:
+The AWS options are evaluated in the order of precedence, the first available
+value is used.
+
+-# Name of the AWS profile:
+@li the <b>s3Profile</b> option
+@li the <b>AWS_PROFILE</b> environment variable
+@li the <b>AWS_DEFAULT_PROFILE</b> environment variable
+@li the default value of <b>default</b>
+-# Location of the <b>credentials</b> file:
+@li the <b>s3CredentialsFile</b> option
+@li the <b>AWS_SHARED_CREDENTIALS_FILE</b> environment variable
+@li the default value of <b>~/.aws/credentials</b>
+-# Location of the <b>config</b> file:
+@li the <b>s3ConfigFile</b> option
+@li the <b>AWS_CONFIG_FILE</b> environment variable
+@li the default value of <b>~/.aws/config</b>
+-# Name of the AWS region:
+@li the <b>s3Region</b> option
+@li the <b>AWS_REGION</b> environment variable
+@li the <b>AWS_DEFAULT_REGION</b> environment variable
+@li the <b>region</b> setting from the <b>config</b> file for the specified profile
+@li the default value of <b>us-east-1</b>
+-# URI of AWS S3 API endpoint
+@li the <b>s3EndpointOverride</b> option
+@li the default value of <b>%https://@<s3BucketName@>.s3.@<region@>.amazonaws.com</b>
+
+.
+The AWS credentials are fetched from the following providers, in the order of
+precedence:
+
+-# Environment variables:
+@li <b>AWS_ACCESS_KEY_ID</b>
+@li <b>AWS_SECRET_ACCESS_KEY</b>
+@li <b>AWS_SESSION_TOKEN</b>
+-# Settings from the <b>credentials</b> file for the specified profile:
 @li <b>aws_access_key_id</b>
 @li <b>aws_secret_access_key</b>
 @li <b>aws_session_token</b>
-@li <b>region</b>
--# The following settings are read from the <b>credentials</b> file for the
-specified profile:
+-# Settings from the <b>config</b> file for the specified profile:
 @li <b>aws_access_key_id</b>
 @li <b>aws_secret_access_key</b>
 @li <b>aws_session_token</b>
--# If there are credentials in both <b>credentials</b> and <b>config</b> files
-for the specified profile, the keys in the <b>credentials</b> file take
-precedence.
--# If either <b>aws_access_key_id</b> or <b>aws_secret_access_key</b> is
-missing, an exception is thrown.
--# If <b>aws_session_token</b> is missing, or is empty, it is not used to
-authenticate the user.
--# If <b>region</b> is missing, or is empty, a default value of <b>us-east-1</b>
-is used instead.)*");
+
+.
+The items specified above correspond to the following credentials:
+@li the AWS access key
+@li the secret key associated with the AWS access key
+@li the AWS session token for the temporary security credentials
+
+The following credential handling rules apply:
+@li If the <b>s3Profile</b> option is set to a non-empty string, the environment
+variables are not used as a potential credential provider.
+@li If either an access key or a secret key is available in a potential
+credential provider, it is selected as the credential provider.
+@li If either the access key or the secret key is missing in the selected
+credential provider, an exception is thrown.
+@li If the session token is missing in the selected credential provider, or if
+it is set to an empty string, it is not used to authenticate the user.
+)*");
 
 REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_DUMP_AWS_COMMON_OPTION_DETAILS, R"*(
 <b>Dumping to a Bucket in the AWS S3 Object Storage</b>
@@ -527,7 +623,7 @@ ${TOPIC_UTIL_AWS_COMMON_OPTION_DETAILS})*");
 REGISTER_HELP_DETAIL_TEXT(IMPORT_EXPORT_URL_DETAIL, R"*(
 @li <b>/path/to/file</b> - Path to a locally or remotely (e.g. in OCI Object
 Storage) accessible file or directory
-@li <b>file:///path/to/file</b> - Path to a locally accessible file or directory
+@li <b>%file:///path/to/file</b> - Path to a locally accessible file or directory
 @li <b>http[s]://host.domain[:port]/path/to/file</b> - Location of a remote file
 accessible through HTTP(s) (<<<importTable>>>() only)
 
@@ -539,7 +635,10 @@ oci.configFile global shell options and can be overridden with ociProfile and
 ociConfigFile, respectively.
 
 If the <b>s3BucketName</b> option is given, the path argument must specify a
-plain path in that AWS S3 bucket.)*");
+plain path in that AWS S3 bucket.
+
+If the <b>azureContainerName</b> option is given, the path argument must specify a
+plain path in that Azure container.)*");
 
 REGISTER_HELP_DETAIL_TEXT(IMPORT_EXPORT_OCI_OPTIONS_DETAIL, R"*(
 <b>OCI Object Storage Options</b>
@@ -566,8 +665,8 @@ All selected files must be chunks of the same target table.
 @param options Optional dictionary with import options
 
 The scheme part of a filename contains infomation about the transport backend.
-Supported transport backends are: file://, http://, https://.
-If the scheme part of a filename is omitted, then file:// transport backend
+Supported transport backends are: %file://, %http://, %https://.
+If the scheme part of a filename is omitted, then %file:// transport backend
 will be chosen.
 
 Supported filename formats:
@@ -656,6 +755,12 @@ ${TOPIC_UTIL_AWS_COMMON_OPTIONS}
 
 ${TOPIC_UTIL_AWS_COMMON_OPTION_DETAILS}
 
+<b>Azure Blob Storage Options</b>
+
+${TOPIC_UTIL_AZURE_COMMON_OPTIONS}
+
+${TOPIC_UTIL_AZURE_COMMON_OPTION_DETAILS}
+
 <b>dialect</b> predefines following set of options fieldsTerminatedBy (FT),
 fieldsEnclosedBy (FE), fieldsOptionallyEnclosed (FOE), fieldsEscapedBy (FESC)
 and linesTerminatedBy (LT) in following manner:
@@ -688,6 +793,10 @@ Each parallel connection sets the following session variables:
 @li SET unique_checks = 0
 @li SET foreign_key_checks = 0
 @li SET SESSION TRANSACTION ISOLATION LEVEL READ UNCOMMITTED
+
+Note: because of storage engine limitations, table locks held by MyISAM will
+cause imports of such tables to be sequential, regardless of the number of
+threads used.
 )*");
 /**
  * \ingroup util
@@ -879,9 +988,9 @@ using a single PAR
 
 <<<loadDump>>>() will load a dump from the specified path. It transparently
 handles compressed files and directly streams data when loading from remote
-storage (currently HTTP, OCI Object Storage and AWS S3 Object Storage). If the
-'waitDumpTimeout' option is set, it will load a dump on-the-fly, loading table
-data chunks as the dumper produces them.
+storage (currently HTTP, OCI Object Storage, AWS S3 Object Storage and Azure
+Containers). If the 'waitDumpTimeout' option is set, it will load a dump
+on-the-fly, loading table data chunks as the dumper produces them.
 
 Table data will be loaded in parallel using the configured number of threads
 (4 by default). Multiple threads per table can be used if the dump was created
@@ -1037,6 +1146,7 @@ seconds) passes.
 list of SQL statements in each session about to load data.
 ${TOPIC_UTIL_DUMP_OCI_COMMON_OPTIONS}
 ${TOPIC_UTIL_AWS_COMMON_OPTIONS}
+${TOPIC_UTIL_AZURE_COMMON_OPTIONS}
 
 Connection options set in the global session, such as compression, ssl-mode, etc.
 are inherited by load sessions.
@@ -1267,6 +1377,26 @@ operating systems which support them): <b>rw-r-----</b>.
 )*");
 
 REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_DUMP_EXPORT_COMMON_OPTIONS, R"*(
+@li <b>fieldsTerminatedBy</b>: string (default: "\t") - This option has the same
+meaning as the corresponding clause for SELECT ... INTO OUTFILE.
+@li <b>fieldsEnclosedBy</b>: char (default: '') - This option has the same
+meaning as the corresponding clause for SELECT ... INTO OUTFILE.
+@li <b>fieldsEscapedBy</b>: char (default: '\\') - This option has the same
+meaning as the corresponding clause for SELECT ... INTO OUTFILE.
+@li <b>fieldsOptionallyEnclosed</b>: bool (default: false) - Set to true if the
+input values are not necessarily enclosed within quotation marks specified by
+<b>fieldsEnclosedBy</b> option. Set to false if all fields are quoted by
+character specified by <b>fieldsEnclosedBy</b> option.
+@li <b>linesTerminatedBy</b>: string (default: "\n") - This option has the same
+meaning as the corresponding clause for SELECT ... INTO OUTFILE. See Section
+13.2.10.1, "SELECT ... INTO Statement".
+@li <b>dialect</b>: enum (default: "default") - Setup fields and lines options
+that matches specific data file format. Can be used as base dialect and
+customized with <b>fieldsTerminatedBy</b>, <b>fieldsEnclosedBy</b>,
+<b>fieldsEscapedBy</b>, <b>fieldsOptionallyEnclosed</b> and
+<b>linesTerminatedBy</b> options. Must be one of the following values: default,
+csv, tsv or csv-unix.
+
 @li <b>maxRate</b>: string (default: "0") - Limit data read throughput to
 maximum rate, measured in bytes per second per thread. Use maxRate="0" to set no
 limit.
@@ -1305,10 +1435,20 @@ to be included in the dump in the format of <b>schema</b>.<b>table</b>
 (all triggers from the specified table) or
 <b>schema</b>.<b>table</b>.<b>trigger</b> (the individual trigger).
 
+@li <b>where</b>: dictionary (default: not set) - A key-value pair of a table
+name in the format of <b>schema.table</b> and a valid SQL condition expression
+used to filter the data being exported.
+@li <b>partitions</b>: dictionary (default: not set) - A key-value pair of a
+table name in the format of <b>schema.table</b> and a list of valid partition
+names used to limit the data export to just the specified partitions.
+
 @li <b>tzUtc</b>: bool (default: true) - Convert TIMESTAMP data to UTC.
 
 @li <b>consistent</b>: bool (default: true) - Enable or disable consistent data
 dumps.
+@li <b>skipConsistencyChecks</b>: bool (default: false) - Skips additional
+consistency checks which are executed when running consistent dumps and i.e.
+backup lock cannot not be acquired.
 @li <b>ddlOnly</b>: bool (default: false) - Only dump Data Definition Language
 (DDL) from the database.
 @li <b>dataOnly</b>: bool (default: false) - Only dump data from the database.
@@ -1387,8 +1527,8 @@ ${TOPIC_UTIL_DUMP_DDL_COMMON_REQUIREMENTS}
 This operation writes SQL files per each schema, table and view dumped, along
 with some global SQL files.
 
-Table data dumps are written to TSV files, optionally splitting them into
-multiple chunk files.
+Table data dumps are written to text files using the specified file format,
+optionally splitting them into multiple chunk files.
 
 ${TOPIC_UTIL_DUMP_SESSION_DETAILS}
 
@@ -1399,14 +1539,28 @@ Data dumps cannot be created for the following tables:
 @li mysql.slow_log
 )*");
 
-REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_DUMP_DDL_COMMON_OPTION_DETAILS, R"*(
-The names given in the <b>exclude{object}</b> or <b>include{object}</b> options
-should be valid MySQL identifiers, quoted using backtick characters when
-required.
+REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_DUMP_EXPORT_DIALECT_OPTION_DETAILS, R"*(
+The <b>dialect</b> option predefines the set of options fieldsTerminatedBy (FT),
+fieldsEnclosedBy (FE), fieldsOptionallyEnclosed (FOE), fieldsEscapedBy (FESC)
+and linesTerminatedBy (LT) in the following manner:
+@li default: no quoting, tab-separated, LF line endings.
+(LT=@<LF@>, FESC='\', FT=@<TAB@>, FE=@<empty@>, FOE=false)
+@li csv: optionally quoted, comma-separated, CRLF line endings.
+(LT=@<CR@>@<LF@>, FESC='\', FT=",", FE='&quot;', FOE=true)
+@li tsv: optionally quoted, tab-separated, CRLF line endings.
+(LT=@<CR@>@<LF@>, FESC='\', FT=@<TAB@>, FE='&quot;', FOE=true)
+@li csv-unix: fully quoted, comma-separated, LF line endings.
+(LT=@<LF@>, FESC='\', FT=",", FE='&quot;', FOE=false)
+)*");
 
-If the <b>exclude{object}</b> or <b>include{object}</b> options contain an
-object which does not exist, or an object which belongs to a schema which does
-not exist, it is ignored.
+REGISTER_HELP_DETAIL_TEXT(TOPIC_UTIL_DUMP_DDL_COMMON_OPTION_DETAILS, R"*(
+The names given in the <b>exclude{object}</b>, <b>include{object}</b>,
+<b>where</b> or <b>partitions</b> options should be valid MySQL identifiers,
+quoted using backtick characters when required.
+
+If the <b>exclude{object}</b>, <b>include{object}</b>, <b>where</b> or
+<b>partitions</b> options contain an object which does not exist, or an object
+which belongs to a schema which does not exist, it is ignored.
 
 The <b>tzUtc</b> option allows dumping TIMESTAMP data when a server has data in
 different time zones or data is being moved between servers with different time
@@ -1435,10 +1589,12 @@ written to a single file.
 
 If the <b>chunking</b> option is set to <b>true</b>, but a table to be dumped
 cannot be chunked (for example if it does not contain a primary key or a unique
-index), a warning is displayed and chunking is disabled for this table.
+index), data is dumped to multiple files using a single thread.
 
 The value of the <b>threads</b> option must be a positive number.
 
+${TOPIC_UTIL_DUMP_EXPORT_DIALECT_OPTION_DETAILS}
+
 Both the <b>bytesPerChunk</b> and <b>maxRate</b> options support unit suffixes:
 @li k - for kilobytes,
 @li M - for Megabytes,
@@ -1522,21 +1678,10 @@ to be overwritten. The output file is created with the following access rights
 (on operating systems which support them): <b>rw-r-----</b>.
 
 <b>The following options are supported:</b>
-@li <b>fieldsTerminatedBy</b>: string (default: "\t"), <b>fieldsEnclosedBy</b>:
-char (default: ''), <b>fieldsEscapedBy</b>: char (default: '\'),
-<b>linesTerminatedBy</b>: string (default: "\n") - These options have the same
-meaning as the corresponding clauses for SELECT ... INTO OUTFILE. For more
-information use <b>\? SQL Syntax/SELECT</b>, (a session is required).
-@li <b>fieldsOptionallyEnclosed</b>: bool (default: false) - Set to true if the
-input values are not necessarily enclosed within quotation marks specified by
-<b>fieldsEnclosedBy</b> option. Set to false if all fields are quoted by
-character specified by <b>fieldsEnclosedBy</b> option.
-@li <b>dialect</b>: enum (default: "default") - Setup fields and lines options
-that matches specific data file format. Can be used as base dialect and
-customized with <b>fieldsTerminatedBy</b>, <b>fieldsEnclosedBy</b>,
-<b>fieldsOptionallyEnclosed</b>, <b>fieldsEscapedBy</b> and
-<b>linesTerminatedBy</b> options. Must be one of the following values: default,
-csv, tsv or csv-unix.
+@li <b>where</b>: string (default: not set) - A valid SQL condition expression
+used to filter the data being exported.
+@li <b>partitions</b>: list of strings (default: not set) - A list of valid
+partition names used to limit the data export to just the specified partitions.
 
 ${TOPIC_UTIL_DUMP_EXPORT_COMMON_OPTIONS}
 @li <b>compression</b>: string (default: "none") - Compression used when writing
@@ -1546,6 +1691,8 @@ ${TOPIC_UTIL_DUMP_OCI_COMMON_OPTIONS}
 
 ${TOPIC_UTIL_AWS_COMMON_OPTIONS}
 
+${TOPIC_UTIL_AZURE_COMMON_OPTIONS}
+
 ${TOPIC_UTIL_DUMP_EXPORT_COMMON_REQUIREMENTS}
 
 <b>Details</b>
@@ -1556,17 +1703,7 @@ ${TOPIC_UTIL_DUMP_SESSION_DETAILS}
 
 <b>Options</b>
 
-The <b>dialect</b> option predefines the set of options fieldsTerminatedBy (FT),
-fieldsEnclosedBy (FE), fieldsOptionallyEnclosed (FOE), fieldsEscapedBy (FESC)
-and linesTerminatedBy (LT) in the following manner:
-@li default: no quoting, tab-separated, LF line endings.
-(LT=@<LF@>, FESC='\', FT=@<TAB@>, FE=@<empty@>, FOE=false)
-@li csv: optionally quoted, comma-separated, CRLF line endings.
-(LT=@<CR@>@<LF@>, FESC='\', FT=",", FE='&quot;', FOE=true)
-@li tsv: optionally quoted, tab-separated, CRLF line endings.
-(LT=@<CR@>@<LF@>, FESC='\', FT=@<TAB@>, FE='&quot;', FOE=true)
-@li csv-unix: fully quoted, comma-separated, LF line endings.
-(LT=@<LF@>, FESC='\', FT=",", FE='&quot;', FOE=false)
+${TOPIC_UTIL_DUMP_EXPORT_DIALECT_OPTION_DETAILS}
 
 The <b>maxRate</b> option supports unit suffixes:
 @li k - for kilobytes,
@@ -1579,6 +1716,8 @@ ${TOPIC_UTIL_DUMP_OCI_COMMON_OPTION_DETAILS}
 
 ${TOPIC_UTIL_DUMP_AWS_COMMON_OPTION_DETAILS}
 
+${TOPIC_UTIL_DUMP_AZURE_COMMON_OPTION_DETAILS}
+
 @throws ArgumentError in the following scenarios:
 @li If any of the input arguments contains an invalid value.
 
@@ -1650,6 +1789,8 @@ ${TOPIC_UTIL_DUMP_OCI_PAR_COMMON_OPTIONS}
 
 ${TOPIC_UTIL_AWS_COMMON_OPTIONS}
 
+${TOPIC_UTIL_AZURE_COMMON_OPTIONS}
+
 ${TOPIC_UTIL_DUMP_DDL_COMMON_REQUIREMENTS}
 @li Views and triggers to be dumped must not use qualified names to reference
 other views or tables.
@@ -1665,8 +1806,8 @@ that when using the util.<<<loadDump>>>() function to load the dump, it is
 automatically recreated. Alternatively, dump can be loaded into another existing
 schema using the <b>schema</b> option.
 
-Table data dumps are written to TSV files, optionally splitting them into
-multiple chunk files.
+Table data dumps are written to text files using the specified file format,
+optionally splitting them into multiple chunk files.
 
 ${TOPIC_UTIL_DUMP_SESSION_DETAILS}
 
@@ -1684,6 +1825,8 @@ ${TOPIC_UTIL_DUMP_OCI_PAR_OPTION_DETAILS}
 
 ${TOPIC_UTIL_DUMP_AWS_COMMON_OPTION_DETAILS}
 
+${TOPIC_UTIL_DUMP_AZURE_COMMON_OPTION_DETAILS}
+
 @throws ArgumentError in the following scenarios:
 @li If any of the input arguments contains an invalid value.
 
@@ -1753,6 +1896,8 @@ ${TOPIC_UTIL_DUMP_OCI_PAR_COMMON_OPTIONS}
 
 ${TOPIC_UTIL_AWS_COMMON_OPTIONS}
 
+${TOPIC_UTIL_AZURE_COMMON_OPTIONS}
+
 ${TOPIC_UTIL_DUMP_SCHEMAS_COMMON_DETAILS}
 
 <b>Options</b>
@@ -1764,6 +1909,8 @@ ${TOPIC_UTIL_DUMP_OCI_PAR_OPTION_DETAILS}
 
 ${TOPIC_UTIL_DUMP_AWS_COMMON_OPTION_DETAILS}
 
+${TOPIC_UTIL_DUMP_AZURE_COMMON_OPTION_DETAILS}
+
 @throws ArgumentError in the following scenarios:
 @li If any of the input arguments contains an invalid value.
 
@@ -1841,6 +1988,8 @@ ${TOPIC_UTIL_DUMP_OCI_PAR_COMMON_OPTIONS}
 
 ${TOPIC_UTIL_AWS_COMMON_OPTIONS}
 
+${TOPIC_UTIL_AZURE_COMMON_OPTIONS}
+
 ${TOPIC_UTIL_DUMP_SCHEMAS_COMMON_DETAILS}
 
 Dumps cannot be created for the following schemas:
@@ -1862,6 +2011,8 @@ ${TOPIC_UTIL_DUMP_OCI_PAR_OPTION_DETAILS}
 
 ${TOPIC_UTIL_DUMP_AWS_COMMON_OPTION_DETAILS}
 
+${TOPIC_UTIL_DUMP_AZURE_COMMON_OPTION_DETAILS}
+
 @throws ArgumentError in the following scenarios:
 @li If any of the input arguments contains an invalid value.
 
