@@ -28,6 +28,7 @@
 #include <functional>
 #include <map>
 #include <memory>
+#include <optional>
 #include <string>
 #include <utility>
 #include <vector>
@@ -69,7 +70,7 @@ struct Upgrade_check_options {
       mysqlshdk::utils::Version(MYSH_VERSION);
   std::string config_path;
   std::string output_format;
-  mysqlshdk::utils::nullable<std::string> password;
+  std::optional<std::string> password;
 
  private:
   void set_target_version(const std::string &value);
@@ -209,6 +210,8 @@ class Sql_upgrade_check : public Upgrade_check {
   static std::unique_ptr<Sql_upgrade_check>
   get_columns_which_cannot_have_defaults_check();
   static std::unique_ptr<Sql_upgrade_check> get_invalid_57_names_check();
+  static std::unique_ptr<Sql_upgrade_check> get_orphaned_routines_check();
+  static std::unique_ptr<Sql_upgrade_check> get_dollar_sign_name_check();
 
   Sql_upgrade_check(const char *name, const char *title,
                     std::vector<std::string> &&queries,
