@@ -36,6 +36,7 @@
 #include <set>
 #include <stdexcept>
 #include <string>
+#include <string_view>
 #include <unordered_set>
 #include <utility>
 #include <vector>
@@ -198,8 +199,8 @@ struct SHCORE_PUBLIC Value {
     size_t count(const std::string &k) const { return _map.count(k); }
 
     template <class T>
-    std::pair<iterator, bool> emplace(const std::string &key, const T &v) {
-      return _map.emplace(key, Value(v));
+    std::pair<iterator, bool> emplace(const std::string &key, T &&v) {
+      return _map.emplace(key, Value(std::forward<T>(v)));
     }
 
    private:
@@ -229,6 +230,7 @@ struct SHCORE_PUBLIC Value {
   explicit Value(std::string &&s, bool binary = false);
   explicit Value(const char *);
   explicit Value(const char *, size_t n, bool binary = false);
+  explicit Value(std::string_view s, bool binary = false);
   explicit Value(std::wstring_view s);
   explicit Value(std::nullptr_t);
   explicit Value(int i);
@@ -368,11 +370,12 @@ struct SHCORE_PUBLIC Value {
   template <class C>
   C to_string_container() const {
     C vec;
-    check_type(Array);
     auto arr = as_array();
 
-    std::transform(arr->begin(), arr->end(), std::inserter<C>(vec, vec.end()),
-                   [](const shcore::Value &v) { return v.get_string(); });
+    if (arr) {
+      std::transform(arr->begin(), arr->end(), std::inserter<C>(vec, vec.end()),
+                     [](const shcore::Value &v) { return v.get_string(); });
+    }
 
     return vec;
   }
@@ -386,6 +389,16 @@ struct SHCORE_PUBLIC Value {
     return map;
   }
 
+  template <class C>
+  std::map<std::string, C> to_container_map() const {
+    std::map<std::string, C> map;
+    check_type(Map);
+    for (const auto &v : *as_map()) {
+      map.emplace(v.first, v.second.to_string_container<C>());
+    }
+    return map;
+  }
+
   std::shared_ptr<Function_base> as_function() const {
     check_type(Function);
     return std::dynamic_pointer_cast<Function_base>(
@@ -723,6 +736,15 @@ struct value_type_for_native<std::map<std::string, std::string>> {
   }
 };
 
+template <class C>
+struct value_type_for_native<std::map<std::string, C>> {
+  static const Value_type type = Map;
+
+  static std::map<std::string, C> extract(const Value &value) {
+    return value.to_container_map<C>();
+  }
+};
+
 template <>
 struct value_type_for_native<Object_bridge *> {
   static const Value_type type = Object;
