@@ -31,6 +31,7 @@
 #include <unordered_set>
 #include <utility>
 
+#include "mysqlshdk/libs/rest/rest_utils.h"
 #include "mysqlshdk/libs/utils/ssl_keygen.h"
 #include "mysqlshdk/libs/utils/utils_encoding.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
@@ -41,6 +42,7 @@ namespace aws {
 
 using rest::Base_response_buffer;
 using rest::Headers;
+using rest::parse_xml;
 using rest::Response;
 using rest::Response_error;
 using rest::Signed_request;
@@ -54,34 +56,36 @@ constexpr std::size_t k_min_part_size = 5242880;  // 5 MiB
 constexpr std::size_t k_max_part_size = std::min<uint64_t>(
     UINT64_C(5368709120), std::numeric_limits<std::size_t>::max());
 
-inline std::string encode_path(const std::string &data) {
-  // signer expects that path segments are URL-encoded, slashes should not be
-  // encoded
-  return shcore::pctencode_path(data);
+std::string encode_path(const std::string &data) {
+  // signer expects that path is URL-encoded, all bytes except the unreserved
+  // characters and the slash character must be encoded
+  std::size_t pos = 0;
+  std::string path;
+
+  do {
+    auto next_pos = data.find('/', pos);
+    path += shcore::pctencode(data.substr(pos, next_pos - pos));
+    pos = next_pos;
+
+    if (std::string::npos != pos) {
+      ++pos;
+      path += '/';
+    }
+  } while (std::string::npos != pos);
+
+  return path;
 }
 
 inline std::string encode_query(const std::string &data) {
-  // signer expects that query parameters are URL-encoded
+  // signer expects that query parameters are URL-encoded, all bytes except the
+  // unreserved characters must be encoded
   return shcore::pctencode(data);
 }
 
-std::unique_ptr<tinyxml2::XMLDocument> parse_xml(
-    const rest::Base_response_buffer &buffer) {
-  auto xml = std::make_unique<tinyxml2::XMLDocument>();
-
-  if (tinyxml2::XMLError::XML_SUCCESS !=
-      xml->Parse(buffer.data(), buffer.size())) {
-    throw shcore::Exception::runtime_error("Failed to parse AWS response: " +
-                                           std::string{xml->ErrorStr()});
-  }
-
-  return xml;
-}
-
 }  // namespace
 
 S3_bucket::S3_bucket(const S3_bucket_config_ptr &config)
-    : storage::backend::object_storage::Bucket(config),
+    : storage::backend::object_storage::Container(config),
       m_config(config),
       // bucket-related requests, path-style: /bucket, virtual-style: /
       m_bucket_path("/" + (config->path_style_access()
@@ -95,7 +99,7 @@ rest::Signed_request S3_bucket::list_objects_request(
     const std::string &prefix, size_t limit, bool recursive,
     const Object_details::Fields_mask &, const std::string &start_from) {
   // ListObjectsV2
-  Query query = {{"list-type", "2"}};
+  rest::Query query = {{"list-type", "2"}};
 
   if (!prefix.empty()) {
     query.emplace("prefix", encode_query(prefix));
@@ -215,7 +219,7 @@ void S3_bucket::execute_rename_object(Signed_rest_service *,
 
 rest::Signed_request S3_bucket::list_multipart_uploads_request(size_t limit) {
   // ListMultipartUploads
-  Query query = {{"uploads", {}}};
+  rest::Query query = {{"uploads", {}}};
 
   if (limit) {
     query.emplace("max-uploads", std::to_string(limit));
@@ -265,7 +269,7 @@ std::vector<Multipart_object> S3_bucket::parse_list_multipart_uploads(
 rest::Signed_request S3_bucket::list_multipart_uploaded_parts_request(
     const Multipart_object &object, size_t limit) {
   // ListParts
-  Query query = {{"uploadId", object.upload_id}};
+  rest::Query query = {{"uploadId", object.upload_id}};
 
   if (limit) {
     query.emplace("max-parts", std::to_string(limit));
@@ -323,13 +327,13 @@ rest::Signed_request S3_bucket::create_multipart_upload_request(
   // CreateMultipartUpload
   // no body
   *request_body = "";
-  Query query = {{"uploads", {}}};
+  rest::Query query = {{"uploads", {}}};
   return create_object_request(object_name, query);
 }
 
 std::string S3_bucket::parse_create_multipart_upload(
-    const rest::Base_response_buffer &buffer) {
-  const auto xml = parse_xml(buffer);
+    const rest::String_response &response) {
+  const auto xml = parse_xml(response.buffer);
   const auto root = xml->FirstChildElement("InitiateMultipartUploadResult");
 
   if (!root) {
@@ -346,10 +350,10 @@ std::string S3_bucket::parse_create_multipart_upload(
 }
 
 rest::Signed_request S3_bucket::upload_part_request(
-    const Multipart_object &object, size_t part_num) {
+    const Multipart_object &object, size_t part_num, size_t /*size*/) {
   // UploadPart
-  Query query = {{"partNumber", std::to_string(part_num)},
-                 {"uploadId", object.upload_id}};
+  rest::Query query = {{"partNumber", std::to_string(part_num)},
+                       {"uploadId", object.upload_id}};
   return create_object_request(object.name, query);
 }
 
@@ -358,7 +362,7 @@ rest::Signed_request S3_bucket::commit_multipart_upload_request(
     const std::vector<Multipart_object_part> &parts,
     std::string *request_body) {
   // CompleteMultipartUpload
-  Query query = {{"uploadId", object.upload_id}};
+  rest::Query query = {{"uploadId", object.upload_id}};
 
   // create the request, using compact mode to save some bytes
   tinyxml2::XMLPrinter printer;
@@ -391,7 +395,7 @@ rest::Signed_request S3_bucket::commit_multipart_upload_request(
 rest::Signed_request S3_bucket::abort_multipart_upload_request(
     const Multipart_object &object) {
   // AbortMultipartUpload
-  Query query = {{"uploadId", object.upload_id}};
+  rest::Query query = {{"uploadId", object.upload_id}};
   return create_object_request(object.name, query);
 }
 
@@ -461,7 +465,7 @@ void S3_bucket::copy_object_multipart(const std::string &src_name,
   Headers headers = {{"x-amz-copy-source", copy_source_header(src_name)}};
   auto &range = headers["x-amz-copy-source-range"];
 
-  Query query = {{"uploadId", upload.upload_id}};
+  rest::Query query = {{"uploadId", upload.upload_id}};
   auto &part_number = query["partNumber"];
 
   while (start < total_size) {
@@ -513,7 +517,7 @@ void S3_bucket::delete_objects(const std::vector<std::string> &list) {
 }
 
 rest::Signed_request S3_bucket::create_bucket_request(
-    const Query &query) const {
+    const rest::Query &query) const {
   return Signed_request(add_query_parameters(m_bucket_path, query));
 }
 
@@ -523,12 +527,12 @@ rest::Signed_request S3_bucket::create_object_request(
 }
 
 rest::Signed_request S3_bucket::create_object_request(
-    const std::string &name, const Query &query) const {
+    const std::string &name, const rest::Query &query) const {
   return Signed_request(add_query_parameters(object_path(name), query));
 }
 
 std::string S3_bucket::add_query_parameters(const std::string &path,
-                                            const Query &query) const {
+                                            const rest::Query &query) const {
   std::string p = path;
 
   if (!query.empty()) {
@@ -539,7 +543,7 @@ std::string S3_bucket::add_query_parameters(const std::string &path,
       p += param.first;
 
       p += '=';
-      p += param.second.value_or("");
+      p += param.second.value_or(std::string{});
 
       p += '&';
     }
@@ -571,7 +575,7 @@ void S3_bucket::delete_objects(
   // DeleteObjects
   Headers headers;
   auto &md5 = headers["Content-MD5"];
-  Query query = {{"delete", {}}};
+  rest::Query query = {{"delete", {}}};
 
   for (std::size_t i = 0; i < size; i += max_items) {
     tinyxml2::XMLPrinter printer;
