@@ -115,7 +115,7 @@ void Session_impl::connect(
     for (const auto &att : _connection_options.get_connection_attributes()) {
       std::string attribute = att.first;
       std::string value;
-      if (!att.second.is_null()) {
+      if (att.second.has_value()) {
         value = *att.second;
       }
 
@@ -135,8 +135,7 @@ void Session_impl::connect(
 
   if (connection_options.has(mysqlshdk::db::kServerPublicKeyPath)) {
     std::string server_public_key =
-        connection_options.get_extra_options().get_value(
-            mysqlshdk::db::kServerPublicKeyPath);
+        connection_options.get(mysqlshdk::db::kServerPublicKeyPath);
     mysql_options(_mysql, MYSQL_SERVER_PUBLIC_KEY, server_public_key.c_str());
   }
 
@@ -257,12 +256,13 @@ void Session_impl::connect(
     mysql_options(_mysql, MYSQL_OPT_NET_BUFFER_LENGTH, &opt_net_buffer_length);
   }
 
+  auto mysql_plugin_dir = mysqlshdk::db::default_mysql_plugins_dir();
   if (connection_options.has(mysqlshdk::db::kMysqlPluginDir)) {
-    auto mysql_plugin_dir =
-        connection_options.get(mysqlshdk::db::kMysqlPluginDir);
-    if (!mysql_plugin_dir.empty()) {
-      mysql_options(_mysql, MYSQL_PLUGIN_DIR, mysql_plugin_dir.c_str());
-    }
+    mysql_plugin_dir = connection_options.get(mysqlshdk::db::kMysqlPluginDir);
+  }
+
+  if (!mysql_plugin_dir.empty()) {
+    mysql_options(_mysql, MYSQL_PLUGIN_DIR, mysql_plugin_dir.c_str());
   }
 
   DBUG_LOG("sqlall", "CONNECT: " << _connection_options.uri_endpoint());
@@ -461,20 +461,21 @@ std::shared_ptr<IResult> Session_impl::run_sql(const char *sql, size_t len,
       }
     }
 
-    if (filter_set == 0 || (filter_set > 0 && std::regex_match(sql, filter))) {
+    if (filter_set == 0 ||
+        (filter_set > 0 && std::regex_match(sql, sql + len, filter))) {
       static int count = std::stoi(getenv("TEST_SQL_UNTIL_CRASH"));
       if (--count == 0) {
         fprintf(stderr, "%s SQL statements executed, will throw now\n",
                 getenv("TEST_SQL_UNTIL_CRASH"));
-        throw mysqlshdk::db::Error(
-            "Injected error when about to execute '" + std::string(sql) + "'",
-            CR_UNKNOWN_ERROR);
+        throw mysqlshdk::db::Error("Injected error when about to execute '" +
+                                       std::string(sql, len) + "'",
+                                   CR_UNKNOWN_ERROR);
       }
     }
   });
 
   auto log_sql_handler = shcore::current_log_sql();
-  log_sql_handler->log(get_thread_id(), sql, len);
+  log_sql_handler->log(get_thread_id(), std::string_view{sql, len});
 
   DBUG_LOG("sqlall", get_thread_id() << ": QUERY: " << std::string(sql, len));
 
@@ -486,8 +487,7 @@ std::shared_ptr<IResult> Session_impl::run_sql(const char *sql, size_t len,
     auto err =
         Error(mysql_error(_mysql), mysql_errno(_mysql), mysql_sqlstate(_mysql));
 
-    shcore::current_log_sql()->log(get_thread_id(), sql_script.data(),
-                                   sql_script.size(), err);
+    shcore::current_log_sql()->log(get_thread_id(), sql_script, err);
 
     if (DBUG_EVALUATE_IF("sqlall", 1, 0)) {
       DBUG_LOG("sql", get_thread_id() << ": ERROR: " << err.format());
@@ -589,24 +589,15 @@ std::vector<std::string> Session_impl::get_last_gtids() const {
   return gtids;
 }
 
-std::string Session::escape_string(const std::string &s) const {
+std::string Session::escape_string(std::string_view s) const {
   std::string res;
-  res.resize(s.length() * 2 + 1);
+  res.resize(s.size() * 2 + 1);
   size_t l = mysql_real_escape_string_quote(_impl->_mysql, &res[0], s.data(),
                                             s.size(), '\'');
   res.resize(l);
   return res;
 }
 
-std::string Session::escape_string(const char *buffer, size_t len) const {
-  std::string res;
-  res.resize(len * 2 + 1);
-  size_t l =
-      mysql_real_escape_string_quote(_impl->_mysql, &res[0], buffer, len, '\'');
-  res.resize(l);
-  return res;
-}
-
 void Session_impl::setup_default_character_set() {
   // libmysqlclient 8.0 by default is using 'utf8mb4' character set for the new
   // connections, however when negotiating the connection details it sends the
