@@ -199,145 +199,6 @@ mysqlshdk::ssh::Ssh_connection_options get_ssh_connection_options(
   return config;
 }
 
-/**
- * Overrides connection data parameters with specific values, also adds
- * parameters with default values if missing
- */
-void update_connection_data(
-    mysqlshdk::db::Connection_options *connection_options,
-    const std::string &user, const char *password, const std::string &host,
-    int port, const mysqlshdk::utils::nullable<std::string> &sock,
-    const std::string &database, const mysqlshdk::db::Ssl_options &ssl_options,
-    const std::string &auth_method, bool get_server_public_key,
-    const std::string &server_public_key_path,
-    const std::string &connect_timeout, const std::string &compression,
-    const std::string &compress_algorithm,
-    mysqlshdk::utils::nullable<int64_t> compress_level) {
-  if (!user.empty()) {
-    connection_options->clear_user();
-    connection_options->set_user(user);
-  }
-
-  if (!host.empty()) {
-    connection_options->clear_host();
-    connection_options->set_host(host);
-  }
-
-  if (port != 0) {
-    connection_options->clear_port();
-    connection_options->set_port(port);
-  }
-
-  if (password) {
-    connection_options->clear_password();
-    connection_options->set_password(password);
-  }
-
-  if (!database.empty()) {
-    connection_options->clear_schema();
-    connection_options->set_schema(database);
-  }
-
-  if (!sock.is_null()) {
-    connection_options->clear_socket();
-#ifdef _WIN32
-    connection_options->set_pipe(*sock);
-#else   // !_WIN32
-    connection_options->set_socket(*sock);
-#endif  // !_WIN32
-  }
-
-  if (ssl_options.has_ca()) {
-    connection_options->get_ssl_options().clear_ca();
-    connection_options->get_ssl_options().set_ca(ssl_options.get_ca());
-  }
-
-  if (ssl_options.has_cert()) {
-    connection_options->get_ssl_options().clear_cert();
-    connection_options->get_ssl_options().set_cert(ssl_options.get_cert());
-  }
-
-  if (ssl_options.has_key()) {
-    connection_options->get_ssl_options().clear_key();
-    connection_options->get_ssl_options().set_key(ssl_options.get_key());
-  }
-
-  if (ssl_options.has_capath()) {
-    connection_options->get_ssl_options().clear_capath();
-    connection_options->get_ssl_options().set_capath(ssl_options.get_capath());
-  }
-
-  if (ssl_options.has_crl()) {
-    connection_options->get_ssl_options().clear_crl();
-    connection_options->get_ssl_options().set_crl(ssl_options.get_crl());
-  }
-
-  if (ssl_options.has_crlpath()) {
-    connection_options->get_ssl_options().clear_crlpath();
-    connection_options->get_ssl_options().set_crlpath(
-        ssl_options.get_crlpath());
-  }
-
-  if (ssl_options.has_cipher()) {
-    connection_options->get_ssl_options().clear_cipher();
-    connection_options->get_ssl_options().set_cipher(ssl_options.get_cipher());
-  }
-
-  if (ssl_options.has_tls_version()) {
-    connection_options->get_ssl_options().clear_tls_version();
-    connection_options->get_ssl_options().set_tls_version(
-        ssl_options.get_tls_version());
-  }
-
-  if (ssl_options.has_tls_ciphersuites()) {
-    connection_options->get_ssl_options().clear_tls_ciphersuites();
-    connection_options->get_ssl_options().set_tls_ciphersuites(
-        ssl_options.get_tls_ciphersuites());
-  }
-
-  if (ssl_options.has_mode()) {
-    connection_options->get_ssl_options().clear_mode();
-    connection_options->get_ssl_options().set_mode(ssl_options.get_mode());
-  }
-
-  if (!auth_method.empty()) {
-    if (connection_options->has(mysqlshdk::db::kAuthMethod))
-      connection_options->remove(mysqlshdk::db::kAuthMethod);
-
-    connection_options->set(mysqlshdk::db::kAuthMethod, auth_method);
-  }
-
-  if (get_server_public_key) {
-    if (connection_options->has(mysqlshdk::db::kGetServerPublicKey)) {
-      connection_options->remove(mysqlshdk::db::kGetServerPublicKey);
-    }
-    connection_options->set(mysqlshdk::db::kGetServerPublicKey, "true");
-  }
-
-  if (!server_public_key_path.empty()) {
-    if (connection_options->has(mysqlshdk::db::kServerPublicKeyPath)) {
-      connection_options->remove(mysqlshdk::db::kServerPublicKeyPath);
-    }
-    connection_options->set(mysqlshdk::db::kServerPublicKeyPath,
-                            server_public_key_path);
-  }
-
-  if (!connect_timeout.empty()) {
-    if (connection_options->has(mysqlshdk::db::kConnectTimeout)) {
-      connection_options->remove(mysqlshdk::db::kConnectTimeout);
-    }
-    connection_options->set(mysqlshdk::db::kConnectTimeout, connect_timeout);
-  }
-
-  if (!compression.empty()) connection_options->set_compression(compression);
-
-  if (!compress_algorithm.empty())
-    connection_options->set_compression_algorithms(compress_algorithm);
-
-  if (!compress_level.is_null())
-    connection_options->set_compression_level(*compress_level);
-}
-
 std::string get_system_user() {
   std::string ret_val{"UNKNOWN_USER"};
 
@@ -406,25 +267,25 @@ std::string errno_to_string(int err) {
 #endif
 }
 
-std::vector<std::string> split_string(const std::string &input,
-                                      const std::string &separator,
+std::vector<std::string> split_string(std::string_view input,
+                                      std::string_view separator,
                                       bool compress) {
   std::vector<std::string> ret_val;
 
   size_t index = 0, new_find = 0;
 
-  while (new_find != std::string::npos) {
+  while (new_find != std::string_view::npos) {
     new_find = input.find(separator, index);
 
-    if (new_find != std::string::npos) {
+    if (new_find != std::string_view::npos) {
       // When compress is enabled, consecutive separators
       // do not generate new elements
       if (new_find > index || !compress || new_find == 0)
-        ret_val.push_back(input.substr(index, new_find - index));
+        ret_val.emplace_back(input.substr(index, new_find - index));
 
       index = new_find + separator.length();
     } else {
-      ret_val.push_back(input.substr(index));
+      ret_val.emplace_back(input.substr(index));
     }
   }
 
@@ -443,25 +304,25 @@ std::vector<std::string> split_string(const std::string &input,
  *
  * @returns vector of splitted strings
  */
-std::vector<std::string> split_string_chars(const std::string &input,
-                                            const std::string &separator_chars,
+std::vector<std::string> split_string_chars(std::string_view input,
+                                            std::string_view separator_chars,
                                             bool compress) {
   std::vector<std::string> ret_val;
 
   size_t index = 0, new_find = 0;
 
-  while (new_find != std::string::npos) {
+  while (new_find != std::string_view::npos) {
     new_find = input.find_first_of(separator_chars, index);
 
-    if (new_find != std::string::npos) {
+    if (new_find != std::string_view::npos) {
       // When compress is enabled, consecutive separators
       // do not generate new elements
       if (new_find > index || !compress || new_find == 0)
-        ret_val.push_back(input.substr(index, new_find - index));
+        ret_val.emplace_back(input.substr(index, new_find - index));
 
       index = new_find + 1;
     } else {
-      ret_val.push_back(input.substr(index));
+      ret_val.emplace_back(input.substr(index));
     }
   }
 
@@ -472,18 +333,19 @@ std::vector<std::string> split_string_chars(const std::string &input,
 // NOTE: Assumption is given that everything is created using a lowerUpperCase
 // naming style
 //       Which is the default to be used on C++ and JS
-std::string get_member_name(const std::string &name,
-                            shcore::NamingStyle style) {
-  std::string new_name;
+std::string get_member_name(std::string_view name, shcore::NamingStyle style) {
   switch (style) {
     // This is the default style, input is returned without modifications
     case shcore::LowerCamelCase:
-      return new_name = name;
+      return std::string{name};
     case shcore::LowerCaseUnderscores: {
       // Uppercase letters will be converted to underscore+lowercase letter
       // except in two situations:
       // - When it is the first letter
       // - When an underscore is already before the uppercase letter
+      std::string new_name;
+      new_name.reserve(name.size());
+
       bool skip_underscore = true;
       for (auto character : name) {
         if (character >= 65 && character <= 90) {
@@ -500,20 +362,20 @@ std::string get_member_name(const std::string &name,
           new_name.append(1, character);
         }
       }
-      break;
+      return new_name;
     }
     case Constants: {
-      for (auto character : name) {
-        if (character >= 97 && character <= 122)
-          new_name.append(1, character - 32);
-        else
-          new_name.append(1, character);
+      std::string new_name{name};
+
+      for (auto &character : new_name) {
+        if (character >= 97 && character <= 122) character -= 32;
       }
-      break;
+
+      return new_name;
     }
   }
 
-  return new_name;
+  return {};
 }
 
 /** Convert string from under_score/dash naming convention to camelCase
@@ -1159,6 +1021,9 @@ std::string SHCORE_PUBLIC unquote_sql_string(const std::string &s) {
 }
 
 void sleep_ms(uint32_t ms) { shcore::current_interrupt()->wait(ms); }
+void sleep(std::chrono::milliseconds duration) {
+  shcore::current_interrupt()->wait(duration.count());
+}
 
 /*
  * Determines the current Operating System
