@@ -126,6 +126,31 @@ struct Case_insensitive_comparator {
   }
 };
 
+struct Case_comparator {
+  bool case_sensitive{true};
+  Case_comparator(bool p_case_sensitive) : case_sensitive{p_case_sensitive} {}
+
+  bool operator()(const std::string &a, const std::string &b) const {
+    return case_sensitive ? Case_sensitive_comparator()(a, b)
+                          : Case_insensitive_comparator()(a, b);
+  }
+
+  bool operator()(const std::wstring &a, const std::wstring &b) const {
+    return case_sensitive ? Case_sensitive_comparator()(a, b)
+                          : Case_insensitive_comparator()(a, b);
+  }
+};
+
+struct Lexicographical_comparator {
+  bool operator()(const std::string &a, const std::string &b) const {
+    return std::lexicographical_compare(a.begin(), a.end(), b.begin(), b.end());
+  }
+
+  bool operator()(const std::wstring &a, const std::wstring &b) const {
+    return std::lexicographical_compare(a.begin(), a.end(), b.begin(), b.end());
+  }
+};
+
 namespace internal {
 
 template <typename Char>
@@ -650,18 +675,13 @@ std::wstring truncate(const wchar_t *str, const size_t length,
 bool is_valid_utf8(const std::string &s);
 
 /**
- * Generates a percent encoded string based on RFC-3986
+ * Generates a percent encoded string based on RFC-3986, only unreserved
+ * characters are not encoded.
  */
 std::string pctencode(const std::string &s);
 
 /**
- * Generates a percent encoded string based on RFC-3986, but does not encode
- * slashes.
- */
-std::string pctencode_path(const std::string &s);
-
-/**
- * Decodes a string that is percent encoded based on RFC-3986
+ * Decodes a string that is percent encoded based on RFC-3986.
  */
 std::string pctdecode(const std::string &s);
 
