@@ -152,32 +152,30 @@ PyObject *dict_update(PyShDictObject *self, PyObject *arg) {
   Py_RETURN_NONE;
 }
 
-PyObject *dict_get(PyShDictObject *self, PyObject *arg) {
-  if (!arg) {
-    Python_context::set_python_error(PyExc_ValueError,
-                                     "dict argument required for get()");
+PyObject *dict_get(PyShDictObject *self, PyObject *args) {
+  PyObject *key = nullptr;
+  PyObject *default_value = Py_None;
+
+  if (!PyArg_UnpackTuple(args, "get", 1, 2, &key, &default_value)) {
     return nullptr;
   }
 
-  PyObject *def = nullptr;
-  char *key;
-  if (!PyArg_ParseTuple(arg, "s|O", &key, &def)) return nullptr;
+  std::string key_to_find;
 
-  if (key) {
-    if (self->map->get()->has_key(key))
-      return py::convert((self->map->get()->find(key))->second).release();
-    else {
-      if (def) {
-        Py_INCREF(def);
-        return def;
-      } else {
-        std::string err = std::string("invalid key: ") + key;
-        Python_context::set_python_error(PyExc_IndexError, err.c_str());
+  if (Python_context::pystring_to_string(key, &key_to_find)) {
+    try {
+      const auto result = self->map->get()->find(key_to_find);
+      if (result != self->map->get()->end()) {
+        return py::convert(result->second).release();
       }
+    } catch (const std::exception &exc) {
+      Python_context::set_python_error(PyExc_RuntimeError, exc.what());
+      return nullptr;
     }
   }
 
-  Py_RETURN_NONE;
+  Py_INCREF(default_value);
+  return default_value;
 }
 
 PyObject *dict_setdefault(PyShDictObject *self, PyObject *arg) {
@@ -304,6 +302,10 @@ int dict_as_subscript(PyShDictObject *self, PyObject *key, PyObject *value) {
 }
 
 PyObject *dict_getattro(PyShDictObject *self, PyObject *attr_name) {
+  if (auto object = PyObject_GenericGetAttr(reinterpret_cast<PyObject *>(self),
+                                            attr_name))
+    return object;
+
   std::string attrname;
 
   if (Python_context::pystring_to_string(attr_name, &attrname)) {
@@ -316,7 +318,7 @@ PyObject *dict_getattro(PyShDictObject *self, PyObject *attr_name) {
       return py::convert((**self->map)[attrname]).release();
     } else {
       std::string err = std::string("unknown attribute: ") + attrname;
-      Python_context::set_python_error(PyExc_IndexError, err.c_str());
+      Python_context::set_python_error(PyExc_AttributeError, err.c_str());
       return nullptr;
     }
   }
