@@ -102,10 +102,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   instance->set_sysvar("require_secure_transport", true, Var_qualifier::GLOBAL);
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    auto resolved_member_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("REQUIRED", to_string(resolved_member_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("REQUIRED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE(
@@ -119,10 +118,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "REQUIRED"   ON
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::REQUIRED;
-    auto resolved_member_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("REQUIRED", to_string(resolved_member_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("REQUIRED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE(
@@ -136,10 +134,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "VERIFY_CA"   ON
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_CA;
-    auto resolved_member_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("VERIFY_CA", to_string(resolved_member_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("VERIFY_CA", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE(
@@ -153,11 +150,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "VERIFY_IDENTITY"   ON
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_IDENTITY;
-    auto resolved_member_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("VERIFY_IDENTITY",
-                 to_string(resolved_member_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("VERIFY_IDENTITY", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE(
@@ -173,10 +168,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
                        Var_qualifier::GLOBAL);
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    auto resolved_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("REQUIRED", to_string(resolved_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("REQUIRED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE(
@@ -190,7 +184,8 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "REQUIRED"   OFF
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::REQUIRED;
-    mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr);
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
     EXPECT_STREQ("REQUIRED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -205,7 +200,8 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "VERIFY_CA"   OFF
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_CA;
-    mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr);
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
     EXPECT_STREQ("VERIFY_CA", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -220,7 +216,8 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "VERIFY_IDENTITY"   OFF
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_IDENTITY;
-    mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr);
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
     EXPECT_STREQ("VERIFY_IDENTITY", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -235,7 +232,8 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_with_ssl) {
   // enabled     "DISABLED"    OFF
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::DISABLED;
-    mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr);
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
     EXPECT_STREQ("DISABLED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -265,10 +263,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_without_ssl) {
   // disabled    "AUTO"
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    auto resolved_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("DISABLED", to_string(resolved_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("DISABLED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE("Unexpected failure at resolve_cluster_ssl_mode_010");
@@ -281,10 +278,9 @@ TEST_F(Dba_common_test, resolve_cluster_ssl_mode_on_instance_without_ssl) {
 
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::DISABLED;
-    auto resolved_ssl_mode =
-        mysqlsh::dba::resolve_ssl_mode(*instance, member_ssl_mode, nullptr)
-            .get_safe();
-    EXPECT_STREQ("DISABLED", to_string(resolved_ssl_mode).c_str());
+    mysqlsh::dba::resolve_ssl_mode_option("memberSslMode", "", *instance,
+                                          &member_ssl_mode);
+    EXPECT_STREQ("DISABLED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
     SCOPED_TRACE("Unexpected failure at resolve_cluster_ssl_mode_009");
@@ -326,7 +322,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // REQUIRED    AUTO          enabled
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("REQUIRED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -341,7 +338,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // REQUIRED    REQUIRED      enabled
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::REQUIRED;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("REQUIRED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -356,7 +354,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // REQUIRED    VERIFY_CA      enabled
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_CA;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("VERIFY_CA", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -371,7 +370,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // REQUIRED    VERIFY_IDENTITY  enabled
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_IDENTITY;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("VERIFY_IDENTITY", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -391,9 +391,9 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // executed or not, we simply emplace the test in a try..catch block ensuring
   // the exception caught when running in 5.7 is about ssl_ca being read-only.
   try {
-    auto current_ssl_ca = instance->get_sysvar_string("ssl_ca").get_safe();
+    auto current_ssl_ca = instance->get_sysvar_string("ssl_ca").value_or("");
     auto current_ssl_capath =
-        instance->get_sysvar_string("ssl_capath").get_safe();
+        instance->get_sysvar_string("ssl_capath").value_or("");
 
     instance->set_sysvar_default("ssl_ca");
     instance->set_sysvar_default("ssl_capath");
@@ -402,8 +402,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
     // VERIFY_CA is used as memberSslMode
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_CA;
     EXPECT_THROW_MSG(
-        mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                                &member_ssl_mode),
+        mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                       &member_ssl_mode),
         std::runtime_error,
         "memberSslMode 'VERIFY_CA' requires Certificate Authority (CA) "
         "certificates to be supplied.");
@@ -417,8 +417,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
     // VERIFY_IDENTITY is used as memberSslMode
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_IDENTITY;
     EXPECT_THROW_MSG(
-        mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                                &member_ssl_mode),
+        mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                       &member_ssl_mode),
         std::runtime_error,
         "memberSslMode 'VERIFY_IDENTITY' requires Certificate Authority (CA) "
         "certificates to be supplied.");
@@ -440,13 +440,13 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   //----------- -------------
   // REQUIRED    DISABLED
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::DISABLED;
-  EXPECT_THROW_MSG(mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                                           &member_ssl_mode),
+  EXPECT_THROW_MSG(mysqlsh::dba::resolve_instance_ssl_mode_option(
+                       *instance, *peer, &member_ssl_mode),
                    std::runtime_error,
-                   "The cluster has SSL (encryption) enabled. "
+                   "The cluster has TLS (encryption) enabled. "
                    "To add the instance '" +
                        instance->descr() +
-                       "' to the cluster either disable SSL on the cluster, "
+                       "' to the cluster either disable TLS on the cluster, "
                        "remove the memberSslMode option or use it with any of "
                        "'AUTO', 'REQUIRED', 'VERIFY_CA' or "
                        "'VERIFY_IDENTITY'.");
@@ -457,7 +457,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   try {
     peer->execute("SET GLOBAL group_replication_ssl_mode=VERIFY_CA");
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("VERIFY_CA", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -473,7 +474,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   try {
     peer->execute("SET GLOBAL group_replication_ssl_mode=VERIFY_IDENTITY");
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("VERIFY_IDENTITY", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -491,27 +493,27 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   //----------- ------------- ------------
   // REQUIRED    AUTO          disabled
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-  EXPECT_THROW_MSG(mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                                           &member_ssl_mode),
+  EXPECT_THROW_MSG(mysqlsh::dba::resolve_instance_ssl_mode_option(
+                       *instance, *peer, &member_ssl_mode),
                    std::runtime_error,
                    "Instance '" + instance->descr() +
-                       "' does not support SSL and cannot join a cluster with "
-                       "SSL (encryption) enabled. Enable SSL support on the "
+                       "' does not support TLS and cannot join a cluster with "
+                       "TLS (encryption) enabled. Enable TLS support on the "
                        "instance and try again, otherwise it can only be added "
-                       "to a cluster with SSL disabled.");
+                       "to a cluster with TLS disabled.");
 
   // Cluster SSL memberSslMode Instance SSL
   //----------- ------------- ------------
   // REQUIRED    REQUIRED      disabled
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::REQUIRED;
   EXPECT_THROW_MSG(
-      mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                              &member_ssl_mode),
+      mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                     &member_ssl_mode),
       std::runtime_error,
       "Instance '" + instance->descr() +
-          "' does not support SSL and cannot join a cluster with SSL "
-          "(encryption) enabled. Enable SSL support on the instance and try "
-          "again, otherwise it can only be added to a cluster with SSL "
+          "' does not support TLS and cannot join a cluster with TLS "
+          "(encryption) enabled. Enable TLS support on the instance and try "
+          "again, otherwise it can only be added to a cluster with TLS "
           "disabled.");
 
   // Cluster SSL memberSslMode Instance SSL
@@ -519,13 +521,13 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // REQUIRED    VERIFY_CA      disabled
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_CA;
   EXPECT_THROW_MSG(
-      mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                              &member_ssl_mode),
+      mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                     &member_ssl_mode),
       std::runtime_error,
       "Instance '" + instance->descr() +
-          "' does not support SSL and cannot join a cluster with SSL "
-          "(encryption) enabled. Enable SSL support on the instance and try "
-          "again, otherwise it can only be added to a cluster with SSL "
+          "' does not support TLS and cannot join a cluster with TLS "
+          "(encryption) enabled. Enable TLS support on the instance and try "
+          "again, otherwise it can only be added to a cluster with TLS "
           "disabled.");
 
   // Cluster SSL memberSslMode    Instance SSL
@@ -533,13 +535,13 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
   // REQUIRED    VERIFY_IDENTITY   disabled
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::VERIFY_IDENTITY;
   EXPECT_THROW_MSG(
-      mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                              &member_ssl_mode),
+      mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                     &member_ssl_mode),
       std::runtime_error,
       "Instance '" + instance->descr() +
-          "' does not support SSL and cannot join a cluster with SSL "
-          "(encryption) enabled. Enable SSL support on the instance and try "
-          "again, otherwise it can only be added to a cluster with SSL "
+          "' does not support TLS and cannot join a cluster with TLS "
+          "(encryption) enabled. Enable TLS support on the instance and try "
+          "again, otherwise it can only be added to a cluster with TLS "
           "disabled.");
 
   testutil->destroy_sandbox(_mysql_sandbox_ports[0]);
@@ -578,13 +580,13 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_disabled) {
   // DISABLED    REQUIRED
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::REQUIRED;
   EXPECT_THROW_MSG(
-      mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                              &member_ssl_mode),
+      mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                     &member_ssl_mode),
       std::runtime_error,
-      "The cluster has SSL (encryption) disabled. "
+      "The cluster has TLS (encryption) disabled. "
       "To add the instance '" +
           instance->descr() +
-          "' to the cluster either enable SSL on the cluster, remove the "
+          "' to the cluster either enable TLS on the cluster, remove the "
           "memberSslMode option or use it with any of 'AUTO' or 'DISABLED'.");
 
   // Cluster SSL memberSslMode require_secure_transport
@@ -592,7 +594,8 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_disabled) {
   // DISABLED    AUTO          OFF
   try {
     member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
-    mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer, &member_ssl_mode);
+    mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                   &member_ssl_mode);
     EXPECT_STREQ("DISABLED", to_string(member_ssl_mode).c_str());
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -607,13 +610,13 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_disabled) {
   // DISABLED    ""            ON
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
   EXPECT_THROW_MSG(
-      mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                              &member_ssl_mode),
+      mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                     &member_ssl_mode),
       std::runtime_error,
       "The instance '" + instance->descr() +
           "' is configured to require a secure transport but the cluster has "
-          "SSL disabled. To add the instance to the cluster, either turn OFF "
-          "the require_secure_transport option on the instance or enable SSL "
+          "TLS disabled. To add the instance to the cluster, either turn OFF "
+          "the require_secure_transport option on the instance or enable TLS "
           "on the cluster.");
 
   // Cluster SSL memberSslMode require_secure_transport
@@ -621,13 +624,13 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_disabled) {
   // DISABLED    AUTO          ON
   member_ssl_mode = mysqlsh::dba::Cluster_ssl_mode::AUTO;
   EXPECT_THROW_MSG(
-      mysqlsh::dba::resolve_instance_ssl_mode(*instance, *peer,
-                                              &member_ssl_mode),
+      mysqlsh::dba::resolve_instance_ssl_mode_option(*instance, *peer,
+                                                     &member_ssl_mode),
       std::runtime_error,
       "The instance '" + instance->descr() +
           "' is configured to require a secure transport but the cluster has "
-          "SSL disabled. To add the instance to the cluster, either turn OFF "
-          "the require_secure_transport option on the instance or enable SSL "
+          "TLS disabled. To add the instance to the cluster, either turn OFF "
+          "the require_secure_transport option on the instance or enable TLS "
           "on the cluster.");
 
   disable_ssl_on_instance(_mysql_sandbox_ports[1], "unsecure");
@@ -1430,11 +1433,10 @@ TEST(mod_dba_common, validate_consistency_supported) {
   Version version(8, 0, 14);
   int canonical_port = 3306;
 
-  auto empty_fail_cons = mysqlshdk::utils::nullable<std::string>("  ");
-  auto null_fail_cons = mysqlshdk::utils::nullable<std::string>();
-  auto valid_fail_cons = mysqlshdk::utils::nullable<std::string>("1");
+  std::optional<std::string> empty_fail_cons{"  "};
+  std::optional<std::string> valid_fail_cons{"1"};
 
-  options.consistency = null_fail_cons;
+  options.consistency = std::nullopt;
   // if a null value was provided, it is as if the option was not provided,
   // so no error should be thrown
   options.check_option_values(version, canonical_port);
@@ -1492,13 +1494,12 @@ TEST(mod_dba_common, validate_expel_timeout_supported) {
   Version version(8, 0, 13);
   int canonical_port = 3306;
 
-  auto null_timeout = mysqlshdk::utils::nullable<int64_t>();
-  auto valid_timeout = mysqlshdk::utils::nullable<std::int64_t>(3600);
-  auto maybe_valid_timeout = mysqlshdk::utils::nullable<std::int64_t>(3601);
+  std::optional<std::int64_t> valid_timeout{3600};
+  std::optional<std::int64_t> maybe_valid_timeout{3601};
 
   // if a null value was provided, it is as if the option was not provided,
   // so no error should be thrown
-  options.expel_timeout = null_timeout;
+  options.expel_timeout = std::nullopt;
   options.check_option_values(version, canonical_port);
 
   // if a value non in the allowed range value was provided, an error should be
@@ -1742,16 +1743,16 @@ TEST(mod_dba_common, is_valid_identifier) {
 }
 
 TEST_F(Dba_common_test, resolve_gr_local_address) {
-  mysqlshdk::utils::nullable<std::string> local_address;
+  std::optional<std::string> local_address;
   std::string raw_report_host = "127.0.0.1";
-  mysqlshdk::utils::nullable<std::string> communication_stack;
+  std::optional<std::string> communication_stack;
   int port;
 
   // Tests for empty localAddress
 
   // Valid port, local_address null
   {
-    local_address = mysqlshdk::utils::nullable<std::string>();
+    local_address = std::nullopt;
     port = 3306;
     EXPECT_NO_THROW(mysqlsh::dba::resolve_gr_local_address(
         local_address, communication_stack, raw_report_host, port, true));
@@ -1767,7 +1768,7 @@ TEST_F(Dba_common_test, resolve_gr_local_address) {
 
   // Invalid port, local_address null
   {
-    local_address.reset();
+    local_address = std::nullopt;
     port = 13040;
 
     EXPECT_THROW_LIKE(
