@@ -10,6 +10,8 @@ if (testutil.versionCheck(__version, "<", "8.0.0")) {
   var mycnf3 = testutil.getSandboxConfPath(__mysql_sandbox_port3);
 }
 
+shell.options["dba.connectTimeout"]=1;
+
 shell.connect(__sandbox_uri1);
 
 var cluster;
@@ -28,6 +30,33 @@ EXPECT_SHELL_LOG_CONTAINS("Debug: Detected state of MD schema as OK");
 
 cluster.addInstance(__sandbox_uri2);
 
+//@<> status while primary is unreachable
+// Bug #34615265	cluster.status() fails if primary is unreachable
+
+// simulate unreachable primary by setting it's address in the MD to a bogus one
+orig_address = session.runSql("select address from mysql_innodb_cluster_metadata.instances where instance_id=1").fetchOne()[0];
+session.runSql("update mysql_innodb_cluster_metadata.instances set address='example.com:3306', addresses=json_set(addresses, '$.mysqlClassic', 'example.com:3306') where instance_id=1");
+
+shell.connect(__sandbox_uri2);
+c = dba.getCluster();
+s = c.status();
+
+EXPECT_STDOUT_NOT_CONTAINS("A connection to the PRIMARY instance at");
+
+EXPECT_EQ("ONLINE", s["defaultReplicaSet"]["topology"][hostname+":"+__mysql_sandbox_port1]["status"]);
+EXPECT_EQ("ONLINE", s["defaultReplicaSet"]["topology"][hostname+":"+__mysql_sandbox_port2]["status"]);
+EXPECT_TRUE(s["defaultReplicaSet"]["topology"][hostname+":"+__mysql_sandbox_port1]["shellConnectError"].startsWith("MySQL Error 2"));
+EXPECT_EQ(hostname+":"+__mysql_sandbox_port2, s["groupInformationSourceMember"]);
+
+shell.connect(__sandbox_uri1);
+session.runSql("update mysql_innodb_cluster_metadata.instances set address=?, addresses=json_set(addresses, '$.mysqlClassic', ?) where instance_id=1", [orig_address, orig_address]);
+
+s = c.status();
+EXPECT_EQ("ONLINE", s["defaultReplicaSet"]["topology"][hostname+":"+__mysql_sandbox_port1]["status"]);
+EXPECT_EQ("ONLINE", s["defaultReplicaSet"]["topology"][hostname+":"+__mysql_sandbox_port2]["status"]);
+EXPECT_EQ(undefined, s["defaultReplicaSet"]["topology"][hostname+":"+__mysql_sandbox_port1]["shellConnectError"]);
+EXPECT_EQ(hostname+":"+__mysql_sandbox_port1, s["groupInformationSourceMember"]);
+
 //@<> set recoveryAccount to empty user
 //BUG#32157182
 session.runSql("UPDATE mysql_innodb_cluster_metadata.instances SET attributes = json_remove(attributes, '$.recoveryAccountUser', '$.recoveryAccountHost')");
@@ -540,7 +569,41 @@ shell.connect(__sandbox_uri2);
 var cluster = dba.getCluster();
 cluster.status();
 
-//@<> Check that cluster.status() timeout is < 10s
+//@<> BUG#34395705: check for invalid "grLocal"
+status = cluster.status();
+EXPECT_FALSE("instanceErrors" in status["defaultReplicaSet"]["topology"]["zzLabel"]);
+
+//with empty value
+session.runSql(`UPDATE mysql_innodb_cluster_metadata.instances SET addresses = json_merge_patch(addresses, json_object('grLocal', "")) WHERE address='${hostname}:${__mysql_sandbox_port2}'`);
+
+status = cluster.status();
+EXPECT_TRUE("instanceErrors" in status["defaultReplicaSet"]["topology"]["zzLabel"]);
+EXPECT_EQ(1, status["defaultReplicaSet"]["topology"]["zzLabel"]["instanceErrors"].length);
+EXPECT_EQ("ERROR: Invalid or missing information of Group Replication's network address in metadata. Use Cluster.rescan() to update the metadata.", status["defaultReplicaSet"]["topology"]["zzLabel"]["instanceErrors"][0])
+
+cluster.rescan();
+EXPECT_OUTPUT_CONTAINS("Updating instance metadata..");
+
+status = cluster.status();
+EXPECT_FALSE("instanceErrors" in status["defaultReplicaSet"]["topology"]["zzLabel"]);
+
+//with incorrect value
+WIPE_STDOUT()
+
+session.runSql(`UPDATE mysql_innodb_cluster_metadata.instances SET addresses = json_merge_patch(addresses, json_object('grLocal', "-----")) WHERE address='${hostname}:${__mysql_sandbox_port2}'`);
+
+status = cluster.status();
+EXPECT_TRUE("instanceErrors" in status["defaultReplicaSet"]["topology"]["zzLabel"]);
+EXPECT_EQ(1, status["defaultReplicaSet"]["topology"]["zzLabel"]["instanceErrors"].length);
+EXPECT_EQ("ERROR: Invalid or missing information of Group Replication's network address in metadata. Use Cluster.rescan() to update the metadata.", status["defaultReplicaSet"]["topology"]["zzLabel"]["instanceErrors"][0])
+
+cluster.rescan();
+EXPECT_OUTPUT_CONTAINS("Updating instance metadata..");
+
+status = cluster.status();
+EXPECT_FALSE("instanceErrors" in status["defaultReplicaSet"]["topology"]["zzLabel"]);
+
+//@<> Check that cluster.status() timeout is < 11s
 // Bug #30884174   CLUSTER.STATUS() HANGS FOR TOO LONG WHEN CONNECTION/READ TIMEOUTS HAPPEN
 
 // force timeout by making cluster.status() try to connect to the GR port
@@ -552,8 +615,8 @@ cluster.status();
 
 var end = new Date();
 
-// time elapsed should be around 5000ms, but we give an extra 1s margin
-EXPECT_GT(6000, end-start);
+// time elapsed should be around 10000ms, but we give an extra 1s margin
+EXPECT_GT(11000, end-start);
 
 //@<> Finalization
 testutil.destroySandbox(__mysql_sandbox_port1);
