@@ -13,7 +13,7 @@ var singleSession = session;
 // Regression for BUG#270621122: Deprecate memberSslMode (ensure no warning is showed for createCluster)
 var single = dba.createCluster('single', {memberSslMode: 'REQUIRED', gtidSetIsComplete: true});
 
-//@ ipWhitelist deprecation error {VER(>=8.0.22)}
+//@ ipWhitelist deprecation error {VER(>=8.0.23)}
 testutil.callMysqlsh([__sandbox_uri1, "--", "cluster", "add-instance", __sandbox_uri2, "--ip-whitelist=AUTOMATIC", "--ip-allowlist=127.0.0.1"])
 
 //@ Success adding instance
@@ -37,8 +37,18 @@ session.runSql("UPDATE mysql_innodb_cluster_metadata.instances SET attributes =
 
 //@<> add new instance to the cluster {VER(>=8.0.17)}
 //BUG#32157182
+
+// check status during clone
+var pid = testutil.callMysqlshAsync(["--js", __sandbox_uri1, "--cluster", "-e", `os.sleep(1); s=cluster.status()['defaultReplicaSet']['topology']['${hostname}:${__mysql_sandbox_port3}']; print(s.address, '=', s.mode, '/', s.role, '/', s.status, '\\n');`]);
+
 single.addInstance(__sandbox_uri3, {label: '2node2', recoveryMethod: "clone"});
 EXPECT_STDOUT_CONTAINS("Unable to enable clone on the instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>': MetadataError: The replication recovery account in use by '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' is not stored in the metadata. Use cluster.rescan() to update the metadata.")
+
+testutil.waitMysqlshAsync(pid);
+
+// ensure cloned instance is not R/W (Bug #30902267	MEMBER SHOULD NOT BE REPORTED AS R/W DURING CLONE)
+EXPECT_STDOUT_CONTAINS(`${hostname}:${__mysql_sandbox_port3} = n/a / HA / RECOVERING`);
+
 WIPE_STDOUT()
 
 //@<> cleanup {VER(>=8.0.17)}
