@@ -62,10 +62,13 @@ The cluster still has the following registered instances:
 WARNING: You are about to dissolve the whole cluster and lose the high availability features provided by it. This operation cannot be reverted. All members will be removed from the cluster and replication will be stopped, internal recovery user accounts and the cluster metadata will be dropped. User data will be maintained intact in all instances.
 
 Are you sure you want to dissolve the cluster? [y/N]:
-* Waiting for instance '${hostname}:${__mysql_sandbox_port1}' to synchronize with the primary...
+* Waiting for instance '${hostname}:${__mysql_sandbox_port1}' to apply received transactions...
 
 
 * Dissolving the Cluster...
+* Waiting for instance '${hostname}:${__mysql_sandbox_port1}' to apply received transactions...
+
+
 * Instance '${hostname}:${__mysql_sandbox_port1}' is attempting to leave the cluster...
 
 The cluster was successfully dissolved.
@@ -91,10 +94,13 @@ The cluster still has the following registered instances:
 WARNING: You are about to dissolve the whole cluster and lose the high availability features provided by it. This operation cannot be reverted. All members will be removed from the cluster and replication will be stopped, internal recovery user accounts and the cluster metadata will be dropped. User data will be maintained intact in all instances.
 
 Are you sure you want to dissolve the cluster? [y/N]:
-* Waiting for instance '${hostname}:${__mysql_sandbox_port1}' to synchronize with the primary...
+* Waiting for instance '${hostname}:${__mysql_sandbox_port1}' to apply received transactions...
 
 
 * Dissolving the Cluster...
+* Waiting for instance '${hostname}:${__mysql_sandbox_port1}' to apply received transactions...
+
+
 * Instance '${hostname}:${__mysql_sandbox_port1}' is attempting to leave the cluster...
 WARNING: On instance '${hostname}:${__mysql_sandbox_port1}' configuration cannot be persisted since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please set the 'group_replication_start_on_boot' variable to 'OFF' in the server configuration file, otherwise it might rejoin the cluster upon restart.
 
@@ -489,31 +495,26 @@ session.runSql("CREATE USER 'replication_error_3'@'%' IDENTIFIED BY 'somepass';"
 c.dissolve({force: true});
 
 if (__version_num < 80011) {
-EXPECT_OUTPUT_CONTAINS_MULTILINE(`
-WARNING: An error occurred when trying to catch up with cluster transactions and instance '${hostname}:${__mysql_sandbox_port2}' might have been left in an inconsistent state that will lead to errors if it is reused.
+EXPECT_OUTPUT_CONTAINS_MULTILINE(`WARNING: An error occurred when trying to catch up with cluster transactions and instance '${hostname}:${__mysql_sandbox_port2}' might have been left in an inconsistent state that will lead to errors if it is reused.
 
 * Instance '${hostname}:${__mysql_sandbox_port2}' is attempting to leave the cluster...
 WARNING: On instance '${hostname}:${__mysql_sandbox_port2}' configuration cannot be persisted since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please set the 'group_replication_start_on_boot' variable to 'OFF' in the server configuration file, otherwise it might rejoin the cluster upon restart.
-* Waiting for instance '${hostname}:${__mysql_sandbox_port3}' to synchronize with the primary...
+* Waiting for instance '${hostname}:${__mysql_sandbox_port3}' to apply received transactions...
 
 
 * Instance '${hostname}:${__mysql_sandbox_port3}' is attempting to leave the cluster...
 WARNING: On instance '${hostname}:${__mysql_sandbox_port3}' configuration cannot be persisted since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please set the 'group_replication_start_on_boot' variable to 'OFF' in the server configuration file, otherwise it might rejoin the cluster upon restart.
-* Instance '${hostname}:${__mysql_sandbox_port1}' is attempting to leave the cluster...
-WARNING: On instance '${hostname}:${__mysql_sandbox_port1}' configuration cannot be persisted since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please set the 'group_replication_start_on_boot' variable to 'OFF' in the server configuration file, otherwise it might rejoin the cluster upon restart.
 
 WARNING: The cluster was successfully dissolved, but the following instance was unable to catch up with the cluster transactions: '${hostname}:${__mysql_sandbox_port2}'. Please make sure the cluster metadata was removed on this instance in order to be able to be reused.
 `);
 } else {
-EXPECT_OUTPUT_CONTAINS_MULTILINE(`
-WARNING: An error occurred when trying to catch up with cluster transactions and instance '${hostname}:${__mysql_sandbox_port2}' might have been left in an inconsistent state that will lead to errors if it is reused.
+EXPECT_OUTPUT_CONTAINS_MULTILINE(`WARNING: An error occurred when trying to catch up with cluster transactions and instance '${hostname}:${__mysql_sandbox_port2}' might have been left in an inconsistent state that will lead to errors if it is reused.
 
 * Instance '${hostname}:${__mysql_sandbox_port2}' is attempting to leave the cluster...
-* Waiting for instance '${hostname}:${__mysql_sandbox_port3}' to synchronize with the primary...
+* Waiting for instance '${hostname}:${__mysql_sandbox_port3}' to apply received transactions...
 
 
 * Instance '${hostname}:${__mysql_sandbox_port3}' is attempting to leave the cluster...
-* Instance '${hostname}:${__mysql_sandbox_port1}' is attempting to leave the cluster...
 
 WARNING: The cluster was successfully dissolved, but the following instance was unable to catch up with the cluster transactions: '${hostname}:${__mysql_sandbox_port2}'. Please make sure the cluster metadata was removed on this instance in order to be able to be reused.
 `);
