@@ -33,10 +33,10 @@ group_replication_enforce_update_everywhere_checks = OFF
 group_replication_exit_state_action = READ_ONLY
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = 
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = AUTOMATIC
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = AUTOMATIC
 ?{}
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
@@ -114,10 +114,10 @@ one server failure.
 group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = 62d73bbd-b830-11e7-a7b7-34e6d72fbd80
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = localhost:<<<__local_address_1>>>
@@ -199,10 +199,10 @@ group_replication_enforce_update_everywhere_checks = ON
 group_replication_exit_state_action = READ_ONLY
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = 
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = AUTOMATIC
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = AUTOMATIC
 ?{}
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
@@ -353,7 +353,7 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ||
 |Instance configuration is suitable.|
 |NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>'. Use the localAddress option to override.|
-|A new instance will be added to the InnoDB cluster. Depending on the amount of|
+|A new instance will be added to the InnoDB Cluster. Depending on the amount of|
 |data on the cluster this might take from a few seconds to several hours.|
 ||
 |WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' will not load the persisted cluster configuration upon reboot since 'persisted-globals-load' is set to 'OFF'. Please use the dba.configureLocalInstance() command locally to persist the changes or set 'persisted-globals-load' to 'ON' on the configuration file.|
@@ -416,10 +416,10 @@ group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = localhost:<<<__local_address_2>>>
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xcom>>>
@@ -441,10 +441,10 @@ group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xcom>>>
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = localhost:<<<__local_address_2>>>
@@ -494,10 +494,10 @@ group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xcom>>>
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = localhost:<<<__local_address_3>>>
@@ -523,10 +523,10 @@ group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xcom>>>
-?{VER(>=8.0.22)}
+?{VER(>=8.0.23)}
 group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
-?{VER(<8.0.22)}
+?{VER(<8.0.23)}
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = localhost:<<<__local_address_3>>>
@@ -918,9 +918,7 @@ group_replication_transaction_size_limit = 150000000
 ?{VER(>=8.0.25)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
-The instance will be removed from the InnoDB cluster. Depending on the instance
-being the Seed or not, the Metadata session might become invalid. If so, please
-start a new session to the Metadata Storage R/W instance.
+The instance will be removed from the InnoDB Cluster.
 
 * Waiting for instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' to synchronize with the primary...
 
@@ -998,9 +996,7 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ||
 
 //@<OUT> FR5-Extra Check that warning is shown when removeInstance is called {VER(<8.0.12)}
-The instance will be removed from the InnoDB cluster. Depending on the instance
-being the Seed or not, the Metadata session might become invalid. If so, please
-start a new session to the Metadata Storage R/W instance.
+The instance will be removed from the InnoDB Cluster.
 
 * Waiting for instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' to synchronize with the primary...
 
