@@ -58,6 +58,11 @@ The following operations are available at 'shell options':
       configuration file.
 
 //@<OUT> CLI util --help
+The following object provides command line operations at 'util':
+
+   debug
+      Debugging and diagnostic utilities.
+
 The following operations are available at 'util':
 
    check-for-server-upgrade
@@ -224,6 +229,37 @@ OPTIONS
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
 
+--dialect=<str>
+            Setup fields and lines options that matches specific data file
+            format. Can be used as base dialect and customized with
+            fieldsTerminatedBy, fieldsEnclosedBy, fieldsEscapedBy,
+            fieldsOptionallyEnclosed and linesTerminatedBy options. Must be one
+            of the following values: default, csv, tsv or csv-unix. Default:
+            "default".
+
+--fieldsTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: "\t".
+
+--fieldsEnclosedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: ''.
+
+--fieldsOptionallyEnclosed=<bool>
+            Set to true if the input values are not necessarily enclosed within
+            quotation marks specified by fieldsEnclosedBy option. Set to false
+            if all fields are quoted by character specified by fieldsEnclosedBy
+            option. Default: false.
+
+--fieldsEscapedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: '\'.
+
+--linesTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. See Section 13.2.10.1, "SELECT ... INTO
+            Statement". Default: "\n".
+
 --chunking=<bool>
             Enable chunking of the tables. Default: true.
 
@@ -254,6 +290,11 @@ OPTIONS
 --consistent=<bool>
             Enable or disable consistent data dumps. Default: true.
 
+--skipConsistencyChecks=<bool>
+            Skips additional consistency checks which are executed when running
+            consistent dumps and i.e. backup lock cannot not be acquired.
+            Default: false.
+
 --ocimds=<bool>
             Enable checks for compatibility with MySQL Database Service (MDS)
             Default: false.
@@ -275,6 +316,16 @@ OPTIONS
             schema.table (all triggers from the specified table) or
             schema.table.trigger (the individual trigger). Default: empty.
 
+--where=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a valid SQL condition expression used to filter the data being
+            exported. Default: not set.
+
+--partitions=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a list of valid partition names used to limit the data export to
+            just the specified partitions. Default: not set.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -305,21 +356,37 @@ OPTIONS
             Default: not set.
 
 --s3CredentialsFile=<str>
-            Use the specified AWS credentials file instead of the one at the
-            default location. Default: not set.
+            Use the specified AWS credentials file. Default: not set.
 
 --s3ConfigFile=<str>
-            Use the specified AWS config file instead of the one at the default
-            location. Default: not set.
+            Use the specified AWS config file. Default: not set.
 
 --s3Profile=<str>
-            Use the specified AWS profile instead of the default one. Default:
-            not set.
+            Use the specified AWS profile. Default: not set.
+
+--s3Region=<str>
+            Use the specified AWS region. Default: not set.
 
 --s3EndpointOverride=<str>
             Use the specified AWS S3 API endpoint instead of the default one.
             Default: not set.
 
+--azureContainerName=<str>
+            Name of the Azure container to use. The container must already
+            exist. Default: not set.
+
+--azureConfigFile=<str>
+            Use the specified Azure configuration file instead of the one at
+            the default location. Default: not set.
+
+--azureStorageAccount=<str>
+            The account to be used for the operation. Default: not set.
+
+--azureStorageSasToken=<str>
+            Azure Shared Access Signature (SAS) token, to be used for the
+            authentication of the operation, instead of a key. Default: not
+            set.
+
 --excludeTables=<str list>
             List of tables or views to be excluded from the dump in the format
             of schema.table. Default: empty.
@@ -401,6 +468,37 @@ OPTIONS
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
 
+--dialect=<str>
+            Setup fields and lines options that matches specific data file
+            format. Can be used as base dialect and customized with
+            fieldsTerminatedBy, fieldsEnclosedBy, fieldsEscapedBy,
+            fieldsOptionallyEnclosed and linesTerminatedBy options. Must be one
+            of the following values: default, csv, tsv or csv-unix. Default:
+            "default".
+
+--fieldsTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: "\t".
+
+--fieldsEnclosedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: ''.
+
+--fieldsOptionallyEnclosed=<bool>
+            Set to true if the input values are not necessarily enclosed within
+            quotation marks specified by fieldsEnclosedBy option. Set to false
+            if all fields are quoted by character specified by fieldsEnclosedBy
+            option. Default: false.
+
+--fieldsEscapedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: '\'.
+
+--linesTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. See Section 13.2.10.1, "SELECT ... INTO
+            Statement". Default: "\n".
+
 --chunking=<bool>
             Enable chunking of the tables. Default: true.
 
@@ -431,6 +529,11 @@ OPTIONS
 --consistent=<bool>
             Enable or disable consistent data dumps. Default: true.
 
+--skipConsistencyChecks=<bool>
+            Skips additional consistency checks which are executed when running
+            consistent dumps and i.e. backup lock cannot not be acquired.
+            Default: false.
+
 --ocimds=<bool>
             Enable checks for compatibility with MySQL Database Service (MDS)
             Default: false.
@@ -452,6 +555,16 @@ OPTIONS
             schema.table (all triggers from the specified table) or
             schema.table.trigger (the individual trigger). Default: empty.
 
+--where=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a valid SQL condition expression used to filter the data being
+            exported. Default: not set.
+
+--partitions=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a list of valid partition names used to limit the data export to
+            just the specified partitions. Default: not set.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -482,21 +595,37 @@ OPTIONS
             Default: not set.
 
 --s3CredentialsFile=<str>
-            Use the specified AWS credentials file instead of the one at the
-            default location. Default: not set.
+            Use the specified AWS credentials file. Default: not set.
 
 --s3ConfigFile=<str>
-            Use the specified AWS config file instead of the one at the default
-            location. Default: not set.
+            Use the specified AWS config file. Default: not set.
 
 --s3Profile=<str>
-            Use the specified AWS profile instead of the default one. Default:
-            not set.
+            Use the specified AWS profile. Default: not set.
+
+--s3Region=<str>
+            Use the specified AWS region. Default: not set.
 
 --s3EndpointOverride=<str>
             Use the specified AWS S3 API endpoint instead of the default one.
             Default: not set.
 
+--azureContainerName=<str>
+            Name of the Azure container to use. The container must already
+            exist. Default: not set.
+
+--azureConfigFile=<str>
+            Use the specified Azure configuration file instead of the one at
+            the default location. Default: not set.
+
+--azureStorageAccount=<str>
+            The account to be used for the operation. Default: not set.
+
+--azureStorageSasToken=<str>
+            Azure Shared Access Signature (SAS) token, to be used for the
+            authentication of the operation, instead of a key. Default: not
+            set.
+
 --excludeTables=<str list>
             List of tables or views to be excluded from the dump in the format
             of schema.table. Default: empty.
@@ -559,6 +688,37 @@ OPTIONS
 --defaultCharacterSet=<str>
             Character set used for the dump. Default: "utf8mb4".
 
+--dialect=<str>
+            Setup fields and lines options that matches specific data file
+            format. Can be used as base dialect and customized with
+            fieldsTerminatedBy, fieldsEnclosedBy, fieldsEscapedBy,
+            fieldsOptionallyEnclosed and linesTerminatedBy options. Must be one
+            of the following values: default, csv, tsv or csv-unix. Default:
+            "default".
+
+--fieldsTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: "\t".
+
+--fieldsEnclosedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: ''.
+
+--fieldsOptionallyEnclosed=<bool>
+            Set to true if the input values are not necessarily enclosed within
+            quotation marks specified by fieldsEnclosedBy option. Set to false
+            if all fields are quoted by character specified by fieldsEnclosedBy
+            option. Default: false.
+
+--fieldsEscapedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: '\'.
+
+--linesTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. See Section 13.2.10.1, "SELECT ... INTO
+            Statement". Default: "\n".
+
 --chunking=<bool>
             Enable chunking of the tables. Default: true.
 
@@ -589,6 +749,11 @@ OPTIONS
 --consistent=<bool>
             Enable or disable consistent data dumps. Default: true.
 
+--skipConsistencyChecks=<bool>
+            Skips additional consistency checks which are executed when running
+            consistent dumps and i.e. backup lock cannot not be acquired.
+            Default: false.
+
 --ocimds=<bool>
             Enable checks for compatibility with MySQL Database Service (MDS)
             Default: false.
@@ -610,6 +775,16 @@ OPTIONS
             schema.table (all triggers from the specified table) or
             schema.table.trigger (the individual trigger). Default: empty.
 
+--where=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a valid SQL condition expression used to filter the data being
+            exported. Default: not set.
+
+--partitions=<key>[:<type>]=<value>
+            A key-value pair of a table name in the format of schema.table and
+            a list of valid partition names used to limit the data export to
+            just the specified partitions. Default: not set.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -640,21 +815,37 @@ OPTIONS
             Default: not set.
 
 --s3CredentialsFile=<str>
-            Use the specified AWS credentials file instead of the one at the
-            default location. Default: not set.
+            Use the specified AWS credentials file. Default: not set.
 
 --s3ConfigFile=<str>
-            Use the specified AWS config file instead of the one at the default
-            location. Default: not set.
+            Use the specified AWS config file. Default: not set.
 
 --s3Profile=<str>
-            Use the specified AWS profile instead of the default one. Default:
-            not set.
+            Use the specified AWS profile. Default: not set.
+
+--s3Region=<str>
+            Use the specified AWS region. Default: not set.
 
 --s3EndpointOverride=<str>
             Use the specified AWS S3 API endpoint instead of the default one.
             Default: not set.
 
+--azureContainerName=<str>
+            Name of the Azure container to use. The container must already
+            exist. Default: not set.
+
+--azureConfigFile=<str>
+            Use the specified Azure configuration file instead of the one at
+            the default location. Default: not set.
+
+--azureStorageAccount=<str>
+            The account to be used for the operation. Default: not set.
+
+--azureStorageSasToken=<str>
+            Azure Shared Access Signature (SAS) token, to be used for the
+            authentication of the operation, instead of a key. Default: not
+            set.
+
 --all=<bool>
             Dump all views and tables from the specified schema. Default:
             false.
@@ -689,19 +880,18 @@ OPTIONS
 --dialect=<str>
             Setup fields and lines options that matches specific data file
             format. Can be used as base dialect and customized with
-            fieldsTerminatedBy, fieldsEnclosedBy, fieldsOptionallyEnclosed,
-            fieldsEscapedBy and linesTerminatedBy options. Must be one of the
-            following values: default, csv, tsv or csv-unix. Default:
+            fieldsTerminatedBy, fieldsEnclosedBy, fieldsEscapedBy,
+            fieldsOptionallyEnclosed and linesTerminatedBy options. Must be one
+            of the following values: default, csv, tsv or csv-unix. Default:
             "default".
 
 --fieldsTerminatedBy=<str>
-            These options have the same meaning as the corresponding clauses
-            for SELECT ... INTO OUTFILE. For more information use \? SQL
-            Syntax/SELECT, (a session is required). Default: "\t"),
-            fieldsEnclosedBy: char (default: ''), fieldsEscapedBy: char
-            (default: '\'), linesTerminatedBy: string (default: "\n".
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: "\t".
 
 --fieldsEnclosedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: ''.
 
 --fieldsOptionallyEnclosed=<bool>
             Set to true if the input values are not necessarily enclosed within
@@ -710,8 +900,21 @@ OPTIONS
             option. Default: false.
 
 --fieldsEscapedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. Default: '\'.
 
 --linesTerminatedBy=<str>
+            This option has the same meaning as the corresponding clause for
+            SELECT ... INTO OUTFILE. See Section 13.2.10.1, "SELECT ... INTO
+            Statement". Default: "\n".
+
+--where=<str>
+            A valid SQL condition expression used to filter the data being
+            exported. Default: not set.
+
+--partitions=<str list>
+            A list of valid partition names used to limit the data export to
+            just the specified partitions. Default: not set.
 
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
@@ -735,21 +938,37 @@ OPTIONS
             Default: not set.
 
 --s3CredentialsFile=<str>
-            Use the specified AWS credentials file instead of the one at the
-            default location. Default: not set.
+            Use the specified AWS credentials file. Default: not set.
 
 --s3ConfigFile=<str>
-            Use the specified AWS config file instead of the one at the default
-            location. Default: not set.
+            Use the specified AWS config file. Default: not set.
 
 --s3Profile=<str>
-            Use the specified AWS profile instead of the default one. Default:
-            not set.
+            Use the specified AWS profile. Default: not set.
+
+--s3Region=<str>
+            Use the specified AWS region. Default: not set.
 
 --s3EndpointOverride=<str>
             Use the specified AWS S3 API endpoint instead of the default one.
             Default: not set.
 
+--azureContainerName=<str>
+            Name of the Azure container to use. The container must already
+            exist. Default: not set.
+
+--azureConfigFile=<str>
+            Use the specified Azure configuration file instead of the one at
+            the default location. Default: not set.
+
+--azureStorageAccount=<str>
+            The account to be used for the operation. Default: not set.
+
+--azureStorageSasToken=<str>
+            Azure Shared Access Signature (SAS) token, to be used for the
+            authentication of the operation, instead of a key. Default: not
+            set.
+
 //@<OUT> CLI util import-json --help
 NAME
       import-json - Import JSON documents from file to collection or table in
@@ -952,21 +1171,37 @@ OPTIONS
             Default: not set.
 
 --s3CredentialsFile=<str>
-            Use the specified AWS credentials file instead of the one at the
-            default location. Default: not set.
+            Use the specified AWS credentials file. Default: not set.
 
 --s3ConfigFile=<str>
-            Use the specified AWS config file instead of the one at the default
-            location. Default: not set.
+            Use the specified AWS config file. Default: not set.
 
 --s3Profile=<str>
-            Use the specified AWS profile instead of the default one. Default:
-            not set.
+            Use the specified AWS profile. Default: not set.
+
+--s3Region=<str>
+            Use the specified AWS region. Default: not set.
 
 --s3EndpointOverride=<str>
             Use the specified AWS S3 API endpoint instead of the default one.
             Default: not set.
 
+--azureContainerName=<str>
+            Name of the Azure container to use. The container must already
+            exist. Default: not set.
+
+--azureConfigFile=<str>
+            Use the specified Azure configuration file instead of the one at
+            the default location. Default: not set.
+
+--azureStorageAccount=<str>
+            The account to be used for the operation. Default: not set.
+
+--azureStorageSasToken=<str>
+            Azure Shared Access Signature (SAS) token, to be used for the
+            authentication of the operation, instead of a key. Default: not
+            set.
+
 //@<OUT> CLI util load-dump --help
 NAME
       load-dump - Loads database dumps created by MySQL Shell.
@@ -1174,17 +1409,33 @@ OPTIONS
             Default: not set.
 
 --s3CredentialsFile=<str>
-            Use the specified AWS credentials file instead of the one at the
-            default location. Default: not set.
+            Use the specified AWS credentials file. Default: not set.
 
 --s3ConfigFile=<str>
-            Use the specified AWS config file instead of the one at the default
-            location. Default: not set.
+            Use the specified AWS config file. Default: not set.
 
 --s3Profile=<str>
-            Use the specified AWS profile instead of the default one. Default:
-            not set.
+            Use the specified AWS profile. Default: not set.
+
+--s3Region=<str>
+            Use the specified AWS region. Default: not set.
 
 --s3EndpointOverride=<str>
             Use the specified AWS S3 API endpoint instead of the default one.
             Default: not set.
+
+--azureContainerName=<str>
+            Name of the Azure container to use. The container must already
+            exist. Default: not set.
+
+--azureConfigFile=<str>
+            Use the specified Azure configuration file instead of the one at
+            the default location. Default: not set.
+
+--azureStorageAccount=<str>
+            The account to be used for the operation. Default: not set.
+
+--azureStorageSasToken=<str>
+            Azure Shared Access Signature (SAS) token, to be used for the
+            authentication of the operation, instead of a key. Default: not
+            set.
