@@ -250,14 +250,10 @@ function hasAuthEnvironment(context) {
                  'LDAP_KERBEROS_USER_SEARCH_ATTR',
                  'LDAP_KERBEROS_USER',
                  'LDAP_KERBEROS_PWD',
-                 'LDAP_KERBEROS_AUTH_STRING',
-                 'MYSQL_PLUGIN_DIR'];
+                 'LDAP_KERBEROS_AUTH_STRING'];
   } else if (context == 'KERBEROS') {
     variables = ['KERBEROS_USER',
-                 'KERBEROS_PWD',
-                 'MYSQL_PLUGIN_DIR'];
-  } else if (context == 'FIDO') {
-    variables = ['MYSQL_PLUGIN_DIR'];
+                 'KERBEROS_PWD'];
   }
 
   let missing=[];
@@ -491,6 +487,26 @@ function get_gr_recovery_user_passwd(session) {
   return ret;
 }
 
+function enable_auto_rejoin(session, port) {
+  var close_session = false;
+
+  // Check if the variable session is an int, if so it's the member_port and we need to establish a session
+  if (typeof session == "number") {
+    var port = session;
+    session = shell.connect("mysql://root:root@localhost:" + session);
+    close_session = true;
+  }
+
+   testutil.changeSandboxConf(port, "group_replication_start_on_boot", "ON");
+
+  if (__version_num > 80011)
+    session.runSql("RESET PERSIST group_replication_start_on_boot");
+
+  // Close the session if established in this function
+  if (close_session)
+    session.close();
+}
+
 function disable_auto_rejoin(session, port) {
   var close_session = false;
 
@@ -672,6 +688,17 @@ function json_find_key(json, key) {
   return undefined;
 }
 
+function EXPECT_REPLICAS_USE_SSL(session, num_replicas) {
+  var res = session.runSql("SELECT t.thread_id, t.processlist_id, s.variable_value FROM performance_schema.threads t JOIN performance_schema.status_by_thread s ON t.thread_id = s.thread_id WHERE t.processlist_command = 'Binlog Dump GTID' AND s.variable_name = 'Ssl_cipher'");
+  var count = 0;
+  for (row = res.fetchOne(); row; row = res.fetchOne()) {
+    print(row);
+    EXPECT_NE("", row[2] || "", "Replication thread " + row[1] + " not using Ssl");
+    count += 1;
+  }
+  EXPECT_EQ(num_replicas, count, "# of replicas");
+}
+
 function wait(timeout, wait_interval, condition) {
   if (__replaying) wait_interval = 0;
   waiting = 0;
@@ -828,7 +855,7 @@ function EXPECT_JSON_EQ(expected, actual, note) {
   if (typeof expected == "object" && typeof actual == "object" && !Array.isArray(expected) && !Array.isArray(actual)) {
     diffs = compare_objects(expected, actual, "$");
     if (diffs > 0) {
-      var context = "<b>Context:</b> " + __test_context + "\n<red>Tested values don't match as expected.</red> "+note;
+      var context = "<b>Context:</b> " + __test_context + "\n<red>Tested values don't match as expected.</red> "+note+"\n\t<yellow>Actual:</yellow> " + JSON.stringify(actual, undefined, 2) + "\n\t<yellow>Expected:</yellow> " + JSON.stringify(expected, undefined, 2);
       testutil.fail(context);
     }
   } else {
@@ -1250,7 +1277,7 @@ function EXPECT_STDOUT_CONTAINS_MULTILINE_ONE_OF(t) {
     if (!ret.found) {
         var context = "<b>Context:</b> " + __test_context + "\n<red>Missing output:</red>\n";
         if (typeof(t) === "string") {
-            context += text.str;
+            context += t;
         } else {
             for (i in t) {
                 context += t[i] + "\n";
@@ -1596,6 +1623,31 @@ function validate_crud_functions(crud, expected) {
   }
 }
 
+function validateMembers(obj, expected) {
+    var actual = dir(obj);
+    // Ensures expected members are on the actual list
+    var missing = [];
+    for(exp of expected) {
+        var pos = actual.indexOf(exp);
+        if(pos == -1){
+            missing.push(exp);
+        } else {
+            actual.splice(pos, 1);
+        }
+    }
+    var errors = [];
+    if(missing.length) {
+        errors.push("Missing Members: " + missing.join(", "));
+    }
+    // help is ignored cuz it's always available
+    if (actual.length > 1  || (actual.length == 1 && actual[0] != 'help')) {
+      errors.push("Extra Members: " + actual.join(", "));
+    }
+    if (errors.length) {
+      testutil.fail(errors.join("\n"));
+    }
+}
+
 function WARNING_SKIPPED_TEST(reason) {
   return false;
 }
