@@ -248,6 +248,8 @@ class Testutils : public mysqlsh::Extensible_object {
 
   void restart_sandbox(int port);
 
+  void stop_group(const shcore::Array_t &ports);
+
   void wait_sandbox_alive(const shcore::Value &port_or_uri);
   void wait_sandbox_alive(
       const std::function<std::shared_ptr<mysqlshdk::db::ISession>()> &connect,
@@ -298,6 +300,8 @@ class Testutils : public mysqlsh::Extensible_object {
 
   bool wait_member_transactions(int dest_port, int source_port);
 
+  void inject_gtid_set(int dest_port, const std::string &gtid_set);
+
  public:
   // Misc utility stuff
   int make_file_readonly(const std::string &path);
